@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -114,6 +114,7 @@ DOC_FILES = listTree(
         'Description',
         'COPYING',
         'ReleaseNotes',
+        'p3.rst',
         ],
     )
 
@@ -202,6 +203,7 @@ DIST_FILES = [
 #    'Makefile',
     'ReleaseNotes',
     'manifest.py',
+    'p3.rst',
     'setup.py',
     'setup.cfg',
     ] + \
