@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -34,7 +34,7 @@ import os, sys
 import time, datetime
 
 __prog__ = "pyformex"
-__version__ = "1.0.5"
+__version__ = "1.0.6"
 __revision__ = __version__
 
 Copyright = 'Copyright (C) 2004-2019 Benedict Verhegghe'
@@ -53,21 +53,24 @@ executable = sys.executable
 
 #########  Check Python version #############
 
-# A single variable to flag Python 3+
-PY3 = sys.hexversion >= 0x03000000
+# A single variable to flag Python2
+PY2 = sys.hexversion < 0x03000000
+PY3 = not PY2
 
 # intended Python version
-if PY3:
-    # We only support 3.4+
-    minimal_version = 0x03040000
-    target_version = 0x03060000
-    future_version = 0x03070000
-else:
-    # Dropping support for pre 2.7 will help migration to 3.x
+# We only support 3.4+
+minimal_version = 0x03040000
+target_version = 0x03070000
+future_version = 0x03080000
+
+if PY2:
+    # No more support for pre 2.7
+    # 2.7 support will end on Jan 1, 2020
     minimal_version = 0x02070000
     target_version = 0x02070000
     future_version = 0x03000000
 
+
 def major(v):
     """Return the major component of version"""
     return v >> 24
@@ -106,15 +109,28 @@ if sys.hexversion & 0xFFFF0000 > target_version:
 """ % (human_version(sys.hexversion), human_version(minimal_version))
     #print(startup_warnings)
 
+if PY2:
+    if datetime.date.today() >= datetime.date(2020,1,1):
+        startup_warnings += """
+#######################################################################
+##  Your are running pyFormex with Python version %s, but pyFormex  ##
+##  support for Python 2.x has ended as of Jan 1, 2020.              ##
+##  Consider running pyFormex on Python 3.6 or higher, so you can    ##
+##  enjoy continued support and updates.                             ##
+#######################################################################
+""" % (human_version(sys.hexversion), )
+
+
 # Compatibility between Python2 and Python3
 # We keep these in separate modules, because the ones for 2k might
 # not compile in 3k and vice-versa.
 
-if PY3:
+if PY2:
+    from pyformex.compat_2k import *
+    startup_messages += py2_warning
+else:
     from pyformex.compat_3k import *
     startup_messages += py3_warning
-else:
-    from pyformex.compat_2k import *
 
 
 #### Detect install type ########
@@ -187,10 +203,10 @@ if installtype in 'SG':
     if msg:
         # Try rebyuilding
         print("Rebuilding pyFormex libraries, please wait")
-        if PY3:
-            target = 'lib3'
-        else:
+        if PY2:
             target = 'lib'
+        else:
+            target = 'lib3'
         cmd = "cd %s/..; make %s" % (pyformexdir,target)
         os.system(cmd)
         msg = checkLibraries()
@@ -301,8 +317,8 @@ class DebugLevels(object):
     NONE = 0
     INFO, WARNING, OPTION, CONFIG, DETECT, MEM, SCRIPT, GUI, MENU, DRAW, \
           CANVAS, OPENGL, LIB, MOUSE, APPS, IMAGE, MISC, ABQ, WIDGET, \
-          PROJECT, WEBGL, MULTI, LEGACY, OPENGL2, PLUGIN, UNICODE, FONT, \
-          VTK, DOCTEST = \
+          PROJECT, WEBGL, MULTI, LEGACY, PLUGIN, UNICODE, FONT, \
+          PGF, VTK, DOCTEST = \
           [ 2 ** i for i in range(29) ]
 
 try:
@@ -315,6 +331,11 @@ except:
 DEBUG = DebugLevels
 
 
+def debugItems():
+    """Return all existing debug items"""
+    return [ k.lower() for k in dir(DebugLevels) if not k.startswith('_') ]
+
+
 def debugLevel(sl):
     lev = 0
     for l in sl:
