@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -189,7 +189,7 @@ class Adjacency(np.ndarray):
 
     Parameters
     ----------
-    data: int array-like
+    data: int :term:
         Data to initialize the Connectivity. The data should be 2-dim with
         shape ``(nelems,ncon)``, where ``nelems`` is the number of elements and
         ``ncon`` is the maximum number of connections per element.
