@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -81,7 +81,7 @@ class Connectivity(np.ndarray):
 
     Parameters
     ----------
-    data: int array-like
+    data: int :term:
         Data to initialize the Connectivity. The data should be 2-dim with
         shape ``(nelems,nplex)``, where ``nelems`` is the number of elements and
         ``nplex`` is the plexitude of the elements.
@@ -178,6 +178,8 @@ class Connectivity(np.ndarray):
         ## # Other data
         ar.eltype = eltype  # ! this may be a string!!!!!!!!!!!
         ar.inv = None   # inverse index
+        ar.eadj = None  # element adjacency
+        ar.nadj = None  # node adjacency
         return ar
 
 
@@ -186,6 +188,8 @@ class Connectivity(np.ndarray):
         # all extra attributes added in __new__ should be reset here
         self.eltype = getattr(obj, 'eltype', None)
         self.inv = getattr(obj, 'inv', None)
+        self.eadj = getattr(obj, 'eadj', None)
+        self.nadj = getattr(obj, 'nadj', None)
 
 
     def __reduce__(self):
@@ -229,6 +233,8 @@ class Connectivity(np.ndarray):
 
         """
         res = np.ndarray.__repr__(self)
+        # This is not needed for doctests, but is needed for
+        # normal output
         if self.dtype == at.Int:
             res = res.replace(', dtype=int32','')
         if self.eltype is not None:
@@ -324,7 +330,7 @@ class Connectivity(np.ndarray):
         Examples
         --------
         >>> Connectivity([[0,1,2],[0,1,1],[0,3,2]]).testDegenerate()
-        array([False,  True, False], dtype=bool)
+        array([False,  True, False])
 
         """
         srt = np.asarray(self.copy())
@@ -802,7 +808,7 @@ class Connectivity(np.ndarray):
                [-1,  0,  1],
                [-1,  0,  2],
                [-1, -1, -1],
-               [-1,  1,  2]], dtype=int32)
+               [-1,  1,  2]])
         >>> Connectivity([[0,1,2],[0,1,4],[0,4,2]]).inverse(expand=False)
         Varray([[0, 1, 2], [0, 1], [0, 2], [], [1, 2]])
         """
@@ -811,6 +817,7 @@ class Connectivity(np.ndarray):
                 self.inv = at.inverseIndex(self,expand=expand)
             else:
                 self.inv = Connectivity()
+            self.flags.writeable = False
         return self.inv
 
 
@@ -838,7 +845,7 @@ class Connectivity(np.ndarray):
 
         Parameters
         ----------
-        nodes: int or int array-like
+        nodes: int or int :term:
             One or more node numbers to check for connections in the table.
         return_ncon: bool, optional
             If True, also return the number of connections for each element.
@@ -858,7 +865,7 @@ class Connectivity(np.ndarray):
         >>> print(A.connectedTo(2))
         [0 2 3]
         >>> A.connectedTo([0,1,3],True)
-        (array([0, 1, 2, 3], dtype=int32), array([2, 3, 2, 2]))
+        (array([0, 1, 2, 3]), array([2, 3, 2, 2]))
 
         """
         nodes = at.checkArray1D(nodes, kind='i')
@@ -947,12 +954,12 @@ class Connectivity(np.ndarray):
         Adjacency([[ 1,  2,  3],
                    [-1,  0,  3],
                    [-1, -1,  0],
-                   [-1,  0,  1]], dtype=int32)
+                   [-1,  0,  1]])
         >>> Connectivity([[0,1],[0,2],[1,3],[0,5]]).adjacency('e',mask=[1,2,3,5])
         Adjacency([[ 2],
                    [-1],
                    [ 0],
-                   [-1]], dtype=int32)
+                   [-1]])
         >>> Connectivity([[0,1],[0,2],[1,3],[0,5]]).adjacency('n')
         Adjacency([[ 1,  2,  5],
                    [-1,  0,  3],
@@ -975,6 +982,12 @@ class Connectivity(np.ndarray):
                    [-1, -1,  2,  5],
                    [-1, -1,  2,  4]])
         """
+        adj = getattr(self,kind+'adj')
+        if adj is not None:
+            # We already computed it
+            return adj
+
+
         inv = self.inverse()
         if kind == 'e':
             if mask is not None:
@@ -985,28 +998,31 @@ class Connectivity(np.ndarray):
                 adj = _elem_adj(inv,self,True)
             else:
                 # use multiprocessing
-                # it saves a bit of memory, but not too much
-                # as we process in parallel
                 adj = _elem_adj_multi(inv,self,nproc=4)
                 maxcols = max([a.shape[1] for a in adj])
                 adj = [at.growAxis(a,maxcols-a.shape[1],axis=1,fill=-1)
                        for a in adj]
                 adj = np.concatenate(adj,axis=0)
-                adj = Adjacency(adj)
 
         elif kind == 'n':
             adj = np.concatenate([np.where(inv>=0, self[:, i][inv], inv)
                                   for i in range(self.nplex())], axis=1)
-            adj = Adjacency(adj)
         else:
             raise ValueError("kind should be 'e' or 'n', got %s" % str(kind))
+
+        adj = Adjacency(adj)
+        # Store the adjacency, because it is expensive to compute
+        # True for eadj, don'tknow for nadj
+        self.flags.writeable = True
+        setattr(self,kind+'adj',adj)
+        self.flags.writeable = False
         return adj
 
 
     def adjacentElements(self,els,mask=None):
         """Compute adjacent elements.
 
-        This creates an element adjacency table or node adjacency table
+        This creates an element adjacency table or node adjacency table.
         An element `i` is said to be adjacent to element `j`, if the two
         elements have at least one common node.
         A node `i` is said to be adjacent to node `j`, if there is at least
@@ -1039,22 +1055,22 @@ class Connectivity(np.ndarray):
         array([[ 1,  2,  3],
                [-1,  0,  3],
                [-1, -1,  0],
-               [-1,  0,  1]], dtype=int32)
+               [-1,  0,  1]])
         >>> Connectivity([[0,1],[0,2],[1,3],[0,5]]).adjacentElements([0,1,2])
         array([[ 1,  2,  3],
                [-1,  0,  3],
-               [-1, -1,  0]], dtype=int32)
+               [-1, -1,  0]])
         >>> Connectivity([[0,1],[0,2],[1,3],[0,5]]).adjacentElements([1,2,3])
         array([[ 0,  3],
                [-1,  0],
-               [ 0,  1]], dtype=int32)
+               [ 0,  1]])
         >>> Connectivity([[0,1],[0,2],[1,3],[0,5]]).adjacentElements([0,2])
         array([[ 1,  2,  3],
-               [-1, -1,  0]], dtype=int32)
+               [-1, -1,  0]])
         >>> Connectivity([[0,1],[0,2],[1,3],[0,5]]).adjacentElements([2])
-        array([[0]], dtype=int32)
+        array([[0]])
         >>> Connectivity([[0,1],[0,2],[1,3],[0,5]]).adjacentElements(1)
-        array([[0, 3]], dtype=int32)
+        array([[0, 3]])
         """
         els = at.checkArray1D(els,kind='i')
         nels = els.shape[0]
@@ -1106,7 +1122,7 @@ class Connectivity(np.ndarray):
         >>> C = Connectivity([[2,8,7],[2,3,8],[3,9,8],[4,10,9],[5,6,11],
         ...                   [6,12,11]])
         >>> C.adjacentElements([0])
-        array([[1, 2]], dtype=int32)
+        array([[1, 2]])
         >>> for p in C.frontGenerator(): print(p)
         [ 0 -1 -1 -1 -1 -1]
         [ 0  1  1 -1 -1 -1]
@@ -1129,7 +1145,6 @@ class Connectivity(np.ndarray):
 
         # Compute inverse once, then lock array
         self.inv = self.inverse()
-        self.flags.writeable = False
 
         # Remember current elements front
         elems = np.clip(np.asarray(startat), 0, self.nelems())
@@ -1160,10 +1175,6 @@ class Connectivity(np.ndarray):
                 elems = elems[[0]]
                 prop += partinc
 
-        # Free array
-        self.inv = None
-        self.flags.writeable = True
-
 
     def frontWalk(self,startat=0,frontinc=1,partinc=1,maxval=-1):
         """Walks through the elements by their node front.
@@ -1258,7 +1269,7 @@ class Connectivity(np.ndarray):
 
         Parameters
         ----------
-        selector: int array-like
+        selector: int :term:
             An object that can be converted to a 1-dim or 2-dim
             int array. Examples are a tuple of local node numbers, or a list
             of such tuples all having the same length.
@@ -1314,7 +1325,7 @@ class Connectivity(np.ndarray):
 
         Parameters
         ----------
-        selector: int array-like
+        selector: int :term:
             An object that can be converted to a 1-dim or 2-dim
             int array. Examples are a tuple of local node numbers, or a list
             of such tuples all having the same length.
@@ -1543,7 +1554,7 @@ class Connectivity(np.ndarray):
 
         Parameters
         ----------
-        elist: int array-like
+        elist: int :term:
             List of element numbers. If not specified,
             all elements are considered.
 
@@ -1671,10 +1682,10 @@ class Connectivity(np.ndarray):
         ----------
         clist: list of Connectivity objects
             The Connectivities to connect.
-        nodid: int array-like, optional
+        nodid: int :term:`array_like`, optional
             List of node indices, same length as ``clist``. This specifies
             which node of the elements will be used in the connect operation.
-        bias: int array-like, optional
+        bias: int :term:`array_like`, optional
             List of element bias values, same length as ``clist``. If provided,
             then element looping will start at this number instead of at zero.
         loop: bool
@@ -1908,7 +1919,7 @@ def connectedLineElems(elems,disconnect=None,return_indices=False):
         single line segment. This can e.g.be the ``elems`` Connectivity
         table of a :class:`~mesh.Mesh` with eltype 'line2' (nplex=2).
         But it will work as well for higher order elements like 'line3'
-    disconnect: int array-like, optional
+    disconnect: int :term:`array_like`, optional
         List of vertex numbers where the resulting polylines should be split.
         None of the resulting polylines will have any of the listed vertex
         numbers as an interior vertex. A polyline may start and end
@@ -1985,8 +1996,8 @@ def connectedLineElems(elems,disconnect=None,return_indices=False):
                   [0, 2]]), \
     Connectivity([[4, 5]]), Connectivity([[0, 3]])], \
     [array([[ 0, -1],
-           [ 1,  1]], dtype=int32), array([[3, 1]], dtype=int32), \
-    array([[2, 1]], dtype=int32)])
+           [ 1,  1]]), array([[3, 1]]), \
+    array([[2, 1]])])
     >>> connectedLineElems([[0,1,2],[2,0,3],[0,3,1],[4,5,2]])
     [Connectivity([[3, 0, 2],
                   [2, 1, 0],
