@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -60,21 +60,21 @@ class CoordSys(object):
 
     Parameters
     ----------
-    oab: float array-like (3,3), optional
+    oab: float :term:`array_like` (3,3), optional
         Three non-collinear points O, A and B, that define the CoordSys
         in the following way: O is the origin of the coordinate system,
         A is a point along the positive first axis and B is a point B in
         the plane of the first two axes.
-    points: float array-like (4,3), optional
+    points: float :term:`array_like` (4,3), optional
         The CoordSys is specified by four points: the first three are
         points on the three coordinate axes, at distance +1 from the
         origin; the fourth point is the origin. The use of this parameter
         is deprecated. It can be replaced with `oab=points[3,0,1]`.
-    rot: float array-like (3,3), optional
+    rot: float :term:`array_like` (3,3), optional
         Rotation matrix that transforms the global global axes to be
         parallel to the constructed CoordSys. The user is responsible to
         make sure that `rot` is a proper orthonormal rotation matrix.
-    trl: float array-like (3,)
+    trl: float :term:`array_like` (3,)
         Translation vector that moves the global origin to the origin of the
         CoordSys, in other words, this is the origin of the new CoordSys
         in global coordinates.
@@ -237,7 +237,7 @@ class CoordSys(object):
         Examples
         --------
         >>> CoordSys().rotate(30).axis(1)
-        array([-0.5 ,  0.87,  0.  ], dtype=float32)
+        array([-0.5 ,  0.87,  0.  ])
         """
         return self.rot[i]
 
