@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -149,7 +149,7 @@ def drawCurve(*args,**kargs):
 def run():
     global y0
     clear()
-    wireframe()
+    flatwire()
     linewidth(3)
     delay(1)
     y0=80
