@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -40,7 +40,6 @@ from pyformex.elements import *
 
 def atExit():
     pf.cfg['gui/autozoomfactor'] = saved_autozoomfactor
-    pf.GUI.setBusy(False)
 
 
 def drawMesh(M):
@@ -54,7 +53,6 @@ def run():
     global saved_autozoomfactor
     saved_autozoomfactor = pf.cfg['gui/autozoomfactor']
 
-    pf.GUI.setBusy()
     pf.cfg['gui/autozoomfactor'] = 2.0
 
     clear()
@@ -112,36 +110,37 @@ def run():
     transparent(False)
 
     if pf.interactive:
-        canvasSize(nx*200, ny*200)
-        #canvasSize(720,576)
-        print("running interactively")
-        res = askItems([
-            _I('n',1,text='Number of carpets'),
-            _I('save',False,text='Save images'),
-            ])
-        if not res:
-            return
+        with busyCursor():
+            canvasSize(nx*200, ny*200)
+            #canvasSize(720,576)
+            print("running interactively")
+            res = askItems([
+                _I('n',1,text='Number of carpets'),
+                _I('save',False,text='Save images'),
+                ])
+            if not res:
+                return
 
-        n = res['n']
-        save = res['save']
-        if save:
-            from pyformex.gui import image
-            image.save(filename='Carpetry-000.jpg', window=False, multi=True, hotkey=False, autosave=False, border=False, format=None, quality=95, verbose=False)
-
-        A = None
-        for i in range(n):
-            carpet(M)
-            B = pf.canvas.actors[-1:]
-            if A:
-                undraw(A)
-            A = B
+            n = res['n']
+            save = res['save']
             if save:
-                image.saveNext()
+                from pyformex.gui import image
+                image.save(filename='Carpetry-000.jpg', window=False, multi=True, hotkey=False, autosave=False, border=False, format=None, quality=95, verbose=False)
 
-        if save:
-            files = image.multisave[0].files()
-            image.createMovie(files, encoder='convert', delay=1, colors=256)
-            image.save()   # reset the multisave mode, disabling further saves
+            A = None
+            for i in range(n):
+                carpet(M)
+                B = pf.canvas.actors[-1:]
+                if A:
+                    undraw(A)
+                A = B
+                if save:
+                    image.saveNext()
+
+            if save:
+                files = image.multisave[0].files()
+                image.createMovie(files, encoder='convert', delay=1, colors=256)
+                image.save()   # reset the multisave mode, disabling further saves
 
     else:
         import sys
