@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -39,40 +39,43 @@ from pyformex.gui.colorscale import ColorScale, Palette
 from pyformex.opengl.decors import ColorLegend
 
 input_data = [
-    _I('valrange', text='Value range type', itemtype='select', choices=['Minimum-Medium-Maximum', 'Minimum-Maximum']),
-    _I('maxval', 12.0, text='Maximum value'),
-    _I('medval', 0.0, text='Medium value'),
-    _I('minval', -6.0, text='Minimum value'),
-    _I('palet', text='Predefined color palette', value='RAINBOW', choices=list(Palette.keys())),
-    _G('custom', text='Custom color palette', items=[
-        _I('paltype', text='Palette type', itemtype='select', choices=['3-color', '2-color']),
-        _I('maxcol', [1., 0., 0.], text='Maximum color', itemtype='color'),
-        _I('medcol', [1., 1., 0.], text='Medium color', itemtype='color'),
-        _I('mincol', [1., 1., 1.], text='Minimum color', itemtype='color'),
-        ], checked=False),
-    _I('maxexp', 1.0, text='High exponent'),
-    _I('minexp', 1.0, text='Low exponent'),
-    _I('ncolors', 200, text='Number of colors'),
-    _T('Grid/Label', [
-        _I('ngrid', -1, text='Number of grid intervals'),
-        _I('linewidth', 1.5, text='Line width'),
-        _I('nlabel', -1, text='Number of label intervals'),
-        _I('dec', 2, text='Decimals'),
-        _I('scale', 0, text='Scaling exponent'),
-        _I('lefttext', True, text='Text left of colorscale'),
-        _I('textsize', 18, text='Text height'),
-        _I('textcolor', pf.canvas.settings['fgcolor'], text='Text color', itemtype='color'),
-        _I('header', 'Currently not displayed', text='Header', enabled=False),
-        _I('gravity', 'Notused', text='Gravity', enabled=False),
-        ]),
-    _T('Position/Size', [
-        _I('autosize', True, text='Autosize'),
-        _I('size', (100, 600), text='Size'),
-        _I('autopos', True, text='Autoposition'),
-        _I('position', [100, 50], text='Position'),
+    _H('',[
+        _I('valrange', text='Value range type', itemtype='select', choices=['Minimum-Medium-Maximum', 'Minimum-Maximum']),
+        _I('maxval', 12.0, text='Maximum value'),
+        _I('medval', 0.0, text='Medium value'),
+        _I('minval', -6.0, text='Minimum value'),
+        _I('palet', text='Predefined color palette', value='RAINBOW', choices=list(Palette.keys())),
+        _G('custom', text='Custom color palette', items=[
+            _I('paltype', text='Palette type', itemtype='select', choices=['3-color', '2-color']),
+            _I('maxcol', [1., 0., 0.], text='Maximum color', itemtype='color'),
+            _I('medcol', [1., 1., 0.], text='Medium color', itemtype='color'),
+            _I('mincol', [1., 1., 1.], text='Minimum color', itemtype='color'),
+            ], checked=False),
+        _I('maxexp', 1.0, text='High exponent'),
+        _I('minexp', 1.0, text='Low exponent'),
+        _I('ncolors', 200, text='Number of colors'),
+    ]),
+    _H('',[
+        _T('Grid/Label', [
+            _I('ngrid', -1, text='Number of grid intervals'),
+            _I('linewidth', 1.5, text='Line width'),
+            _I('nlabel', -1, text='Number of label intervals'),
+            _I('dec', 2, text='Decimals'),
+            _I('scale', 0, text='Scaling exponent'),
+            _I('lefttext', True, text='Text left of colorscale'),
+            _I('textsize', 18, text='Text height'),
+            _I('textcolor', pf.canvas.settings['fgcolor'], text='Text color', itemtype='color'),
+            _I('header', 'Currently not displayed', text='Header', enabled=False),
+            _I('gravity', 'Notused', text='Gravity', enabled=False),
+            ]),
+        _T('Position/Size', [
+            _I('autosize', True, text='Autosize'),
+            _I('size', (100, 600), text='Size'),
+            _I('autopos', True, text='Autoposition'),
+            _I('position', [100, 50], text='Position'),
+            ]),
         ]),
     ]
-
 input_enablers = [
     ('valrange', 'Minimum-Medium-Maximum', 'medval'),
     ('custom', False, 'palet'),
