@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -46,9 +46,9 @@ from __future__ import absolute_import, division, print_function
 
 
 _status = 'checked'
-_level = 'beginner'
-_topics = []
-_techniques = ['color', 'text', 'random', 'animation']
+_level = 'normal'
+_topics = ['text']
+_techniques = ['color', 'random', 'animation']
 
 from pyformex.gui.draw import *
 from pyformex.opengl.textext import *
