@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -749,15 +749,15 @@ stop
 
     if ack("Shall I run the Calix analysis?"):
         # Run the analysis
-        outfile = utils.changeExt(filnam, 'res')
+        outfile = utils.changeExt(filnam, '.res')
         cmd = "calix %s %s" % (filnam, outfile)
         utils.command(cmd)
         showFile(outfile, mono=True)
 
         if ack("Shall I read the results for postprocessing?"):
             from pyformex.plugins import flavia
-            meshfile = utils.changeExt(filnam, 'flavia.msh')
-            resfile = utils.changeExt(filnam, 'flavia.res')
+            meshfile = utils.changeExt(filnam, '.flavia.msh')
+            resfile = utils.changeExt(filnam, '.flavia.res')
             DB = flavia.readFlavia(meshfile, resfile)
             postproc_menu.setDB(DB)
             export({name:DB})
@@ -1197,6 +1197,7 @@ def run():
     resetData()
     reset()
     reload_menu()
+    showInfo("You can now use the FeEx menu")
 
 if __name__ == '__draw__':
     run()
