@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -66,10 +66,11 @@ def run():
     zoomAll()
     n = 100
     delay(0.05)
-    for i in arange(n+1)/float(n):
-        B = draw(I.scale(a0+i*a1), color='yellow', bbox='last')
-        undraw(A)
-        A = B
+    with busyCursor():
+        for i in arange(n+1)/float(n):
+            B = draw(I.scale(a0+i*a1), color='yellow', bbox='last')
+            undraw(A)
+            A = B
 
     delay(2)
     wait()
