@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -37,7 +37,6 @@ _techniques = ['dialog']
 
 from pyformex.gui.draw import *
 
-
 # BV
 # not working correctly:
 # - itemtype = 'label'
@@ -54,15 +53,19 @@ input_text = [
     ]
 
 input_select = [
-    _I('bool', False, text="itemtype bool", stretch='ba', tooltip="This is a boolean field that can only get the values True or False, by checking or unchecking the box"),
-    _I('list', ['First', 'Third'], text="itemtype 'list'", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="This is a an input field allowing you to select one or more of a set of predefined values"),
-    _I('slist', ['First', 'Third'], text="itemtype 'list' with single=True", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], single=True, tooltip="This is like 'list', bu allowing only a single value to be selected"),
-    _I('clist', ['First', 'Third'], text="itemtype 'list' with check=True", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], check=True, tooltip="This is a an input field allowing you to select one of a set of predefined values"),
-    _I('select', 'Third', text="itemtype 'select'", choices=['First', 'Second', 'Third', 'Fourth'], tooltip="This is a an input field allowing you to select one of a set of predefined values"),
-    _I('radio', 'Third', text="itemtype (h)radio", itemtype='radio', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="Like 'select', this allows selecting one of a set of predefined values"),
-    _I('vradio', 'Third', text="itemtype vradio", itemtype='vradio', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="Like 'radio', but items are placed vertically"),
-#    _I('push','Third',text="itemtype (h)push",itemtype='push',choices=['First','Second','Third','Fourth'],tooltip="Yet another method to select one of a set of predefined values"),
-#    _I('vpush','Third',text="itemtype vpush",itemtype='vpush',choices=['First','Second','Third','Fourth'],tooltip="Like 'push', but items are placed vertically"),
+    _H('sel', [
+        _I('bool', False, text="itemtype bool", stretch='ba', tooltip="This is a boolean field that can only get the values True or False, by checking or unchecking the box"),
+        _I('list', ['First', 'Third'], text="itemtype 'list'", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="This is a an input field allowing you to select one or more of a set of predefined values"),
+        _I('slist', ['First', 'Third'], text="itemtype 'list' with single=True", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], single=True, tooltip="This is like 'list', bu allowing only a single value to be selected"),
+        _I('clist', ['First', 'Third'], text="itemtype 'list' with check=True", itemtype='list', choices=['First', 'Second', 'Third', 'Fourth'], check=True, tooltip="This is a an input field allowing you to select one of a set of predefined values"),
+    ], maxwidth=500),
+    _H('sel', [
+        _I('select', 'Third', text="itemtype 'select'", choices=['First', 'Second', 'Third', 'Fourth'], tooltip="This is a an input field allowing you to select one of a set of predefined values"),
+        _I('radio', 'Third', text="itemtype (h)radio", itemtype='radio', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="Like 'select', this allows selecting one of a set of predefined values"),
+        _I('vradio', 'Third', text="itemtype vradio", itemtype='vradio', choices=['First', 'Second', 'Third', 'Fourth'], tooltip="Like 'radio', but items are placed vertically"),
+    #    _I('push','Third',text="itemtype (h)push",itemtype='push',choices=['First','Second','Third','Fourth'],tooltip="Yet another method to select one of a set of predefined values"),
+    #    _I('vpush','Third',text="itemtype vpush",itemtype='vpush',choices=['First','Second','Third','Fourth'],tooltip="Like 'push', but items are placed vertically"),
+    ], maxwidth=500),
     ]
 
 input_numerical = [
@@ -79,6 +82,16 @@ input_special = [
     _I('color', colors.pyformex_pink, itemtype='color', text="Color", tooltip="An inputfield allowing to select a color. The current color is pyFormex pink."),
     _I('font', '', itemtype='font'),
     _I('point', [0., 0., 0.], itemtype='point'),
+    _H('column1', [
+        _I('point1', [0., 0., 0.], itemtype='point'),
+        _I('point2', [0., 0., 0.], itemtype='point'),
+        _I('point3', [0., 0., 0.], itemtype='point'),
+       ], maxwidth=500),
+    _H('column2', [
+        _I('point4', [0., 0., 0.], itemtype='point'),
+        _I('point5', [0., 0., 0.], itemtype='point'),
+       ], maxwidth=500),
+    _I('final text',''),
     ]
 
 input_tabgroup = [
@@ -90,15 +103,15 @@ input_tabgroup = [
     ]
 
 input_data = [
-    _T('Text', input_text),
-    _T('Selection', input_select),
-    _T('Numerical', input_numerical),
-    _T('Special', input_special),
-    _T('tabgroup', input_tabgroup, text="Tabs and Groups"),
+    _T('Text', input_text, width=600),
+    _T('Selection', input_select, width=600),
+    _T('Numerical', input_numerical, width=600),
+    _T('Special', input_special, width=600),
+    _T('tabgroup', input_tabgroup, text="Tabs and Groups", width=600),
     ]
 
 input_enablers = [
-    ('tabgroup/enable1', True, 'tabgroup/group1', 'tabgroup/group2/radio'),
+    ('tabgroup/enable1', True, 'tabgroup/group1', 'tabgroup/group2/sel/radio'),
     ('tabgroup/enable2', True, 'tabgroup/group2', 'tabgroup/group3', 'tabgroup/group1/info'),
     ]
 
@@ -142,7 +155,12 @@ def run():
         pass
 
     # Create the modeless dialog widget
-    dialog = Dialog(input_data, enablers=input_enablers, autoprefix=True, caption='InputDialog', actions = [('Close', close), ('Show', show)], default='Show')
+    dialog = Dialog(input_data, enablers=input_enablers, autoprefix=True,
+                    caption='InputDialog',
+                    actions = [('Close', close), ('Show', show)],
+                    default='Show',
+                    scroll=True, size=(0.75,0.85)
+    )
 
     # Examples style requires a timeout action
     dialog.timeout = timeOut
@@ -155,4 +173,5 @@ def run():
 
 if __name__ == '__draw__':
     run()
+
 # End
