@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -33,7 +33,7 @@ In a sequence of steps, the example then draws the following geometries with
 element numbers included:
 
 - the extruded geometry,
-- all the edges of all elments,
+- all the edges of all elements,
 - the unique edges,
 - all the faces of all elements,
 - the unique faces,
@@ -67,9 +67,6 @@ _topics = ['geometry', 'mesh']
 _techniques = ['extrude', 'border', 'pause']
 
 from pyformex.gui.draw import *
-def atExit():
-    #print "THIS IS THE EXIT FUNC"
-    pf.GUI.setBusy(False)
 
 
 def run():
