@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -40,6 +40,8 @@ from pyformex import simple
 from pyformex.plugins.curve import *
 from pyformex.plugins.nurbs import *
 
+AN = utils.autoName('Nurbscurve')
+
 
 def drawThePoints(N,n,color=None):
     umin = N.knots[N.degree]
@@ -119,6 +121,7 @@ def drawNurbs(points,pointtype,degree,strategy,closed,blended,weighted=False,Cle
     else:
         N = globalInterpolationCurve(X, degree=degree, strategy=strategy)
     draw(N, color=red)
+    pf.PF[AN.next()] = N
     if showpoints:
         drawThePoints(N, npoints, color=black)
     if showcurv:
