@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -58,6 +58,8 @@ _techniques = ['nurbs']
 from pyformex.gui.draw import *
 from pyformex.plugins.nurbs import *
 
+AN = utils.autoName('nurbssurface')
+
 # Default data
 
 draw_points = True
@@ -75,7 +77,7 @@ def run():
     global options
 
     clear()
-    smooth()
+    smoothwire()
 
     createView('myview', angles=(0, -15, 0), addtogui=True)
     view('myview')
@@ -140,6 +142,7 @@ def run():
 
     # create the Nurbs surface
     S = NurbsSurface(X, degree=(px, py))
+    pf.PF[AN.next()] = S
 
     if draw_surf:
         # draw the Nurbs surface, with random colors
