@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -49,12 +49,12 @@ def ParallelLines():
     they are strictly parallel.
     """
     resetview([0.8, 0.8, 0.8])
-    lines = Formex([[[0, 0, 0], [14, 0, 0]]]).replic(13, 1, dir=1)
+    lines = Formex([[[0, 0, 0], [14, 0, 0]]]).rep(13, step=1, dir=1)
     draw(lines, color=[0.8, 0.8, 0.8], linewidth=1.0)
-    F = Formex('4:0123').replic(13, 1)
+    F = Formex('4:0123').rep(13, step=1)
     F.setProp([0, 7])
     F += F.translate([0.2, 1, 0]) + F.translate([0.4, 2, 0]) + F.translate([0.2, 3, 0])
-    F = F.replic(3, 4, dir=1)
+    F = F.rep(3, step=4, dir=1)
     draw(F)
 
 
@@ -82,11 +82,12 @@ def RotatingCircle():
     draw(shape('plus'), bbox=box)
     F = sector(r, 360., 1, 16).trl(0, R).rosette(N-1, 360./N)
     delay(sl)
-    for i in range(n*N):
-        F = F.rotate(-360./N)
-        dr = draw(F, color=col, bbox=box)
-        if i>0: undraw(DR)
-        DR=dr
+    with busyCursor():
+        for i in range(n*N):
+            F = F.rotate(-360./N)
+            dr = draw(F, color=col, bbox=box)
+            if i>0: undraw(DR)
+            DR=dr
 
 
 def SquaresAndCircles():
@@ -154,22 +155,25 @@ def RunningInCircles():
     F = Formex([[C[i], C[i+1], O] for i in arange(0, 2*N, 2)]).scale([R, R, 0])
     F.setProp([0, 7])
     p = circle(a1=360./N).points()
-    centre = Formex([add(p[0:len(p):2], p[-1])]).translate([-1, 0, 0])
+    centre = simple.polygonSector(N).rosette(N,360./N).scale(R/3)
     centre.setProp(1)
-    draw(centre, bbox=box)
-    draw(F, bbox=box)
+    draw(centre)
+    draw(F)
+    zoom(2.)
     b1 = Formex('4:0123').scale([1.5, 0.8, 0]).translate([0, 8.5, 0.1])
     b1.setProp(3)
     b2 = Formex('4:0123').scale([1.5, 0.8, 0]).translate([0, 7, 0.1])
     b2.setProp(6)
     b = b1+b2
     col = [random.rand(3)/3, [1, 1, 1]-random.rand(3)/8]
-    for i in range(4*N):
-        b = b.rotate(360./N/4)
-        dr = draw(b, bbox=box, color=col)
-        if i>0:
-            undraw(DR)
-        DR = dr
+    with busyCursor():
+        n = 8*N
+        for i in range(n):
+            b = b.rotate(4*360./n)
+            dr = draw(b, color=col)
+            if i>0:
+                undraw(DR)
+            DR = dr
 
 
 def HowManyColors():
@@ -205,9 +209,9 @@ def AlignedLines():
     """
     resetview()
     a = 60.
-    lines = Formex('l:1').scale([20, 1, 0]).rotate(a).translate([-20.*cos(a*pi/180.), 0, 0]).replic(32, 1)
+    lines = Formex('l:1').scale([20, 1, 0]).rotate(a).translate([-20.*cos(a*pi/180.), 0, 0]).rep(32, step=1)
     lines = lines.cutWithPlane([-1, 0, 0], [1, 0, 0], side='+').cutWithPlane([22, 0, 0], [1, 0, 0], side='-')
-    mask = Formex('4:0123').scale([1, 20.*sin(a*pi/180.), 1]).replic(11, 2)
+    mask = Formex('4:0123').scale([1, 20.*sin(a*pi/180.), 1]).rep(11, step=2)
     mask.setProp(6)
     savedelay = pf.GUI.drawwait
     draw(mask, color=random.rand(3))
@@ -252,7 +256,13 @@ def MotionInducedBlindness():
     Cool huh?
     """
     resetview('black')
-    res = askItems([('Number of static points', 10), ('Background', None, 'radio', {'choices':['Tiles', 'Structured points', 'Random points']}), ('Revolutions', 2), ('Resolution', 180), ('Number of random points', 300)])
+    res = askItems([
+        _I('Number of static points', 10),
+        _I('Background', None, itemtype='radio',
+           choices=['Tiles', 'Structured points', 'Random points']),
+        _I('Revolutions', 2),
+        _I('Resolution', 180),
+        _I('Number of random points', 300)])
     if not res:
         return
     nr, res, rot, back, n = res['Number of random points'], res['Resolution'], res['Revolutions'], res['Background'], res['Number of static points']
@@ -261,11 +271,11 @@ def MotionInducedBlindness():
     draw(points, color=random.rand(3), marksize=10)
     col=random.rand(3)
     if back=='Tiles':
-        F = shape('plus').replic((11, 11), (3, 3)).translate([-15, -15, 0])
+        F = shape('plus').replicm((11,11), (3, 3)).translate([-15, -15, 0])
     elif back=='Structured points':
-        F = Formex([[0, 0, 0]]).replic((30, 30)).translate([-15, -15, 0])
+        F = Formex([[0, 0, 0]]).replicm((30, 30)).translate([-15, -15, 0])
     else:
-        F = Formex(random.rand((nr, 3))).scale([30, 30, 0]).translate([-15, -15, 0])
+        F = Formex(random.rand(nr, 3)).scale([30, 30, 0]).translate([-15, -15, 0])
     # TODO: fix this example to get an integer value here
     # perhaps use # of revolutions and # of steps per revolution
     a = 360. / res
@@ -319,7 +329,7 @@ def SineWave():
     if not res: return
     shift, per, amp = res['Spacing between lines'], res['Periods'], res['Amplitude']
     n = int(2*pi/shift*per)
-    F = Formex('l:2').replic(n, shift)
+    F = Formex('l:2').rep(n, step=shift)
     for i in F:
         i[0, 1] = amp*sin(i[0, 0])
         i[1, 1] = i[0, 1] + 1
@@ -357,7 +367,7 @@ def Crater():
     deg, rot, col = 5, 3, random.rand(2, 3)
     r1, r2, r3, r4, r5, r6, r7, r8 = 1, 1.9, 2.9, 4, 5.1, 6.1, 7, 7.8
     p = circle(a1=5).points()
-    C = Formex([p[0:len(p):2]])
+    C = PolyLine(p[0:len(p):2])
     C1 = C.scale(r1).translate([0, r1, 0])
     C2 = C.scale(r2).translate([0, r2, 0])
     C3 = C.scale(r3).translate([0, r3, 0])
@@ -367,7 +377,7 @@ def Crater():
     C7 = C.scale(r7).translate([0, 2*r4-r7, 0])
     C8 = C.scale(r8).translate([0, 2*r4-r8, 0])
     fig = C1+C2+C3+C4+C5+C6+C7+C8
-    for i in range(rot*360/deg):
+    for i in range(rot*360//deg):
         fig = fig.rotate(deg)
         dr = draw(fig, color=col)
         #dr = draw(fig,color=[[0.8,0.8,0.8],[0.2,0.2,0.2]])
@@ -527,6 +537,7 @@ def next():
 
 def timeOut():
     """What to do when the dialog receives a timeout signal"""
+    #TODO: we should have a showall()
     show()
     wait()
     close()
@@ -536,7 +547,7 @@ def openDialog():
     """Create and display the dialog"""
     global dialog, explanation, Illusion, Explain
     data_items = [
-        _I('Illusion', Illusion, choices=method.keys()),
+        _I('Illusion', Illusion, choices=list(method.keys())),
         _I('Explain', Explain, text='Show explanation'),
         ]
 
