@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -66,7 +66,7 @@ of how easily Python can handle huge numbers.
 from __future__ import absolute_import, division, print_function
 
 
-_status = 'checked'
+_status = 'failed'
 _level = 'normal'
 _topics = ['illustration', 'game']
 _techniques = ['color', 'dialog', 'draw', 'persistence', 'random']
@@ -104,7 +104,10 @@ def turn(x=0,y=0,action=0):
         pf.canvas.setCursorShape('pick')
         x1, y1 = x, y
         busy = False
-        element = selectElement(pf.canvas, x, y, 2, 2)
+        #element = selectElement(pf.canvas, x, y, 2, 2)
+        C = pick(mode='element',filter='single',oneshot=True)
+        print(C)
+        element = C[0]
         if element == [-1]:
             print('No element selected.\nPlease select an element of the cube.')
 #        else:
@@ -139,7 +142,7 @@ def selectElement(self, x, y, w, h):
     self.selection.setType('element')
     self.selection_filter = None
     self.pick_window = (x, y, w, h, GL.glGetIntegerv(GL.GL_VIEWPORT))
-    self.pick_parts('element', 54, store_closest=True)
+    self.pick_parts('element', store_closest=True)
     if len(self.picked) != 0:
         self.selection_front = self.closest_pick
         self.selection.set([self.closest_pick[0]])
