@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -82,7 +82,7 @@ def run():
 
     print("Create a dome from the circular layout")
     f2.setProp(3)
-    pf.canvas.camera.setAngles([0., -45., 0.])
+    viewAngles(0., -45., 0.)
     show(scallop(6, 1, 2, 0), None, False)
 
 
