@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -89,7 +89,7 @@ def run():
                  }
 
     res = askItems([
-        _I('example', text='Select an example', choices=examples.keys()),
+        _I('example', text='Select an example', choices=list(examples.keys())),
         ])
     if res:
         F = examples[res['example']]()
