@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -122,11 +122,12 @@ def run():
     n = 100
     delay(10./n)
     setDrawOptions({'bbox':None})
-    sun.hide()
-    for y in range(n):
-        sun.move(0, sqrt(0.4*(n-y)/n))
-        sun.move(1, -100./n)
-        sun.redraw()
+    with busyCursor():
+        sun.hide()
+        for y in range(n):
+            sun.move(0, sqrt(0.4*(n-y)/n))
+            sun.move(1, -100./n)
+            sun.redraw()
 
 
     sun.hide()
