@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -24,7 +24,7 @@
 """Text rendering on the OpenGL canvas.
 
 This example illustrates some of the possibilities of text drawing
-using textures. Yuo
+using textures.
 """
 from __future__ import absolute_import, division, print_function
 
@@ -35,31 +35,33 @@ _techniques = ['texture']
 
 import pyformex as pf
 from pyformex.gui.draw import *
-
 from pyformex.opengl.textext import *
 
 def run():
     #
     # TODO: RESETALL does not properly layout the canvas in the viewport
+    # caused by reset Viewport
+    # add a viewport + reset layout does fix it
     #resetAll()
     clear()
     view('front')
     smooth()
     fonts = utils.listMonoFonts()
     ft = FontTexture.default()
+    ftrows, ftcols = FontTexture.layout
 
-    # - draw a square
+    # - draw a rectangle with shape like the FontTexture.layout
     # - use the full character set in the default font as a texture
     # - the font textures are currently upside down, therefore we need
     #   to specify texcoords to flip the image
-    F = Formex('4:0123').scale(200).toMesh()
-    A = draw(F,color=yellow,texture=ft,texcoords=array([[0,1],[1,1],[1,0],[0,0]]),texmode=2)
+    F = Formex('4:0123').centered().scale(10).scale([ftcols,ftrows,1]).toMesh()
+    A = draw(F, color=yellow, texture=ft,
+             texcoords=array([[0,1],[1,1],[1,0],[0,0]]), texmode=2)
 
-
-    # - draw 20 squares
+    # - draw 10x2 squares
     # - fill with specific text
     # - put this object on top
-    G = Formex('4:0123').replicm((10,2)).scale(20).rot(30).trl([150,50,0])
+    G = Formex('4:0123').replicm((10,2)).scale(10).rot(30).trl([10,10,0])
     text = [ ' pyFormex ','  rules!  ' ]
     text = text[1] + text[0]
     tc = FontTexture.default().texCoords(text)
@@ -68,21 +70,20 @@ def run():
 
     # draw a cross at the center of the square
     # pos is 3D, therefore values are world coordinates
-    decorate(Text('+',pos=(100,100,0),gravity='',size=100,color=red))
+    decorate(Text('+',pos=(0,0,0),gravity='',size=40,color=red))
 
     # draw a string using the default_font texture
     # pos is 2D, therefore values are pixel coordinates
-    decorate(Text("Hegemony!",pos=(100,100),size=50,offset=(0.0,0.0,1)))
-
-    # the text is currently adjusted horizontally left, vertically centered
-    # on the specified point. Adjustement using gravity will be added later.
-    # Also, the color is currently not honoured.
-    decorate(Text("Hegemony!",(0,10),size=20,color=red))
+    decorate(Text("Hegemony!",pos=(40,60),size=30,offset=(0.0,0.0,1)))
+    decorate(Text("Hegemony!",(0,0),size=20,color=red,gravity='NE'))
     decorate(Text("Hegemony!",(10,30),size=20,color=red))
 
     # use a TextArray to draw text at the corners of the square
-    U = TextArray(["Lower left corner","Lower right corner","Upper right corner","Upper left corner"],pos=F.coords[F.elems[0]],size=30,gravity='NE')
+    corners = F.coords[F.elems[0]]
+    U = TextArray(["Lower left corner","Lower right corner"],pos=corners[:2],size=18,gravity='S')
     decorate(U)
+    V = TextArray(["Upper right corner","Upper left corner"],pos=corners[2:],size=18,gravity='N')
+    decorate(V)
 
     #drawViewportAxes3D((0.,0.,0.),color=blue)
 
@@ -92,9 +93,9 @@ def run():
     image = qimage2numpy(image, indexed=False)
     X = Formex('4:0123').scale(40).toMesh().align('000')
     # at the right corner using direct texture drawing techniques
-    draw(X,texture=image,texcoords=array([[0,1],[1,1],[1,0],[0,0]]),texmode=0,rendertype=-1,opak=False,ontop=True,offset3d=[(200.,200.,0.),(200.,200.,0.),(200.,200.,0.),(200.,200.,0.),])
+    draw(X,texture=image,texcoords=array([[0,1],[1,1],[1,0],[0,0]]),texmode=0,rendertype=-1,opak=False,ontop=True,offset3d=[corners[3],corners[3],corners[3],corners[3]])
     # at the left corner, using a Mark
-    drawActor(Mark((0,200,0),image,size=40,color=red))
+    drawActor(Mark(corners[2],image,size=40,color=red))
 
 if __name__ == '__draw__':
     run()
