@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -125,21 +125,21 @@ class Field(object):
     >>> d = M.coords.distanceFromPlane([0.,0.,0.],[1.,0.,0.])
     >>> f1 = Field(M,'node',d)
     >>> print(f1)
-    Field 'Field-0', type 'node', shape (6,), nnodes=6, nelems=2, nplex=4
+    Field 'field-0', type 'node', shape (6,), nnodes=6, nelems=2, nplex=4
     [ 0. 0. 1. 1. 2. 2.]
     >>> f2 = f1.convert('elemn')
     >>> print(f2)
-    Field 'Field-1', type 'elemn', shape (2, 4), nnodes=6, nelems=2, nplex=4
+    Field 'field-1', type 'elemn', shape (2, 4), nnodes=6, nelems=2, nplex=4
     [[ 0. 1. 1. 0.]
      [ 1. 2. 2. 1.]]
     >>> f3 = f2.convert('elemc')
     >>> print(f3)
-    Field 'Field-2', type 'elemc', shape (2,), nnodes=6, nelems=2, nplex=4
+    Field 'field-2', type 'elemc', shape (2,), nnodes=6, nelems=2, nplex=4
     [ 0.5 1.5]
     >>> d1 = M.coords.distanceFromPlane([0.,0.,0.],[0.,1.,0.])
     >>> f4 = Field(M,'node',at.column_stack([d,d1]))
     >>> print(f4)
-    Field 'Field-3', type 'node', shape (6, 2), nnodes=6, nelems=2, nplex=4
+    Field 'field-3', type 'node', shape (6, 2), nnodes=6, nelems=2, nplex=4
     [[ 0. 0.]
      [ 0. 1.]
      [ 1. 0.]
@@ -148,7 +148,7 @@ class Field(object):
      [ 2. 1.]]
     >>> f5 = f4.convert('elemn')
     >>> print(f5)
-    Field 'Field-4', type 'elemn', shape (2, 4, 2), nnodes=6, nelems=2, nplex=4
+    Field 'field-4', type 'elemn', shape (2, 4, 2), nnodes=6, nelems=2, nplex=4
     [[[ 0. 0.]
       [ 1. 0.]
       [ 1. 1.]
@@ -160,15 +160,15 @@ class Field(object):
       [ 1. 1.]]]
     >>> f6 = f5.convert('elemc')
     >>> print(f6)
-    Field 'Field-5', type 'elemc', shape (2, 2), nnodes=6, nelems=2, nplex=4
+    Field 'field-5', type 'elemc', shape (2, 2), nnodes=6, nelems=2, nplex=4
     [[ 0.5 0.5]
      [ 1.5 0.5]]
     >>> print(f3.convert('elemn'))
-    Field 'Field-6', type 'elemn', shape (2, 4), nnodes=6, nelems=2, nplex=4
+    Field 'field-6', type 'elemn', shape (2, 4), nnodes=6, nelems=2, nplex=4
     [[ 0.5 0.5 0.5 0.5]
      [ 1.5 1.5 1.5 1.5]]
     >>> print(f3.convert('node'))
-    Field 'Field-8', type 'node', shape (6, 1), nnodes=6, nelems=2, nplex=4
+    Field 'field-8', type 'node', shape (6, 1), nnodes=6, nelems=2, nplex=4
     [[ 0.5]
      [ 0.5]
      [ 1. ]
@@ -176,7 +176,7 @@ class Field(object):
      [ 1.5]
      [ 1.5]]
     >>> print(f6.convert('elemn'))
-    Field 'Field-9', type 'elemn', shape (2, 4, 2), nnodes=6, nelems=2, nplex=4
+    Field 'field-9', type 'elemn', shape (2, 4, 2), nnodes=6, nelems=2, nplex=4
     [[[ 0.5 0.5]
       [ 0.5 0.5]
       [ 0.5 0.5]
@@ -187,7 +187,7 @@ class Field(object):
       [ 1.5 0.5]
       [ 1.5 0.5]]]
     >>> print(f6.convert('node'))
-    Field 'Field-11', type 'node', shape (6, 2), nnodes=6, nelems=2, nplex=4
+    Field 'field-11', type 'node', shape (6, 2), nnodes=6, nelems=2, nplex=4
     [[ 0.5 0.5]
      [ 0.5 0.5]
      [ 1.  0.5]
@@ -196,7 +196,7 @@ class Field(object):
      [ 1.5 0.5]]
     """
 
-    _autoname = utils.NameSequence('Field-0')
+    _autoname = utils.autoName('Field')
 
 
     def __init__(self,geometry,fldtype,data,fldname=None):
@@ -264,7 +264,9 @@ class Field(object):
         Returns a Field of type `totype`.
         """
         data = None
-        if totype in self.geometry.fieldtypes:
+        if totype == self.fldtype:
+            data = self.data
+        elif totype in self.geometry.fieldtypes:
             if self.fldtype == 'node':
                 if totype == 'elemn':
                     data = self.data[self.geometry.elems]
