@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -42,7 +42,7 @@ from pyformex import utils
 
 
 if pf.PY3:
-    # We can not use the accelerated functions yet
+    # We can not use the accelerated functions
     from pyformex.lib.misc_e import tofile_int32, tofile_float32
 else:
     from pyformex.lib import misc
@@ -87,7 +87,9 @@ def writeData(fil,data,sep='',fmt=None,end=''):
       value is a newline character.
     """
     kind = data.dtype.kind
-    if fmt is None:
+    if isinstance(fmt,dict):
+        fmt = fmt.get(kind,None)
+    if not fmt or  '%' not in fmt:
         data.tofile(fil, sep)
     else:
         val = data.reshape(-1, data.shape[-1])
