@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -34,11 +34,11 @@ import numpy as np
 import pyformex as pf
 
 from abc import ABCMeta, abstractmethod
+if pf.PY2:
+     abstractbaseclass = object
 if pf.PY3:
      from abc import ABC
      abstractbaseclass = ABC
-else:
-     abstractbaseclass = object
 
 from pyformex import utils
 from pyformex.coords import Coords, Int
@@ -219,7 +219,7 @@ class Geometry(abstractbaseclass):
     #
     ##########################################################################
 
-    if not pf.PY3:
+    if pf.PY2:
          __metaclass__ = ABCMeta
 
 
@@ -608,8 +608,6 @@ class Geometry(abstractbaseclass):
 
     rot = rotate
     trl = translate
-    # TODO: activate late? since we have renamed Formex.rep to repm
-    #rep = replicate
 
 
     ##########################################################################
@@ -635,7 +633,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int, int array-like or 'range'
+        prop: int, int :term:`array_like` or 'range'
             The property number(s) to assign to the elements. If a single int,
             all elements get the same property value.
             If the number of passed values is less than the number of elements,
@@ -680,7 +678,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int or int array-like
+        prop: int or int :term:
             The property values to turn into a valid set for the object.
             If a single int, all elements get the same property value.
             If the number of passed values is less than the number of elements,
@@ -747,7 +745,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int or int array-like
+        prop: int or int :term:
             The property value(s) to be found.
 
         Returns
@@ -919,7 +917,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int or int array-like
+        prop: int or int :term:
             The property value(s) for which the elements should be selected.
 
         Returns
@@ -949,7 +947,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int or int array-like
+        prop: int or int :term:
             The property value(s) of the elements that should be left out.
 
         Returns
@@ -979,7 +977,7 @@ class Geometry(abstractbaseclass):
 
         Parameters
         ----------
-        prop: int array-like, optional
+        prop: int :term:`array_like`, optional
             A 1-dim int array with length ``self.nelems()`` to be used in place
             of the objects own :attr:`prop` attribute. If None (default),
             the latter will be used.
@@ -1037,7 +1035,7 @@ class Geometry(abstractbaseclass):
         ----------
         fldtype: str
             The field type. See :class:`~field.Field` for details.
-        data: array-like
+        data: :term:
             The field data. See :class:`~field.Field` for details.
         fldname: str
             The field name. See :class:`~field.Field` for details. This name
