@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -89,11 +89,11 @@ class GeometryFile(object):
     - `filename`: string: the name of the file to open.
       If the file name ends with '.gz' or '.bz2', transparent (de)compression
       will be used, as provided by the :class:`utils.File` class.
-    - `mode`: one of 'r', 'w' or 'a': specifies that the file should be
+    - `mode`: one of 'rb', 'wb' or 'ab': specifies that the file should be
       opened in read, write or append mode. If omitted, an
       existing file will be opened in read mode and a non-existing in write
-      mode. Opening an existing file in 'w' mode will overwrite the file,
-      while opening it in 'a' mode will allow to append to the file.
+      mode. Opening an existing file in 'wb' mode will overwrite the file,
+      while opening it in 'ab' mode will allow to append to the file.
     - `compr`: string, one of 'gz' or 'bz2': identifies the compression
       algorithm to be used: gzip or bzip2. If the file name is ending with
       '.gz' or '.bz2', `compr` is set automatically from the extension.
@@ -110,26 +110,37 @@ class GeometryFile(object):
     - `ifmt` and `ffmt` are present for historical and development reasons,
       but currently inactive.
     - `version`: if specified, write according to old version standard.
-      Available: '1.9', '2.0'(default)
+      Available: '1.9', '2.0', '2.1'(default)
     """
 
-    _version_ = '2.0'
+    _version_ = '2.1'
+
+    # Changes in 2.1:
+    # Always read/write in binary mode
 
     def __init__(self,filename,mode=None,compr=None,level=5,delete_temp=True,
-                 sep=' ',ifmt=' ',ffmt=' ',version=None):
+                 sep=' ',ifmt='',ffmt='',version=None):
         """Create the GeometryFile object."""
         if version is None:
             version = GeometryFile._version_
-        if not version in [ '1.9', '2.0' ]:
-            raise ValueError("Can not write GeometryFile of version %s" % version)
+        if not version in [ '1.9', '2.0', '2.1' ]:
+            raise ValueError("Can not read/write GeometryFile of version %s" % version)
         self.version = version
 
         if mode is None:
             if os.path.exists(filename):
-                mode = 'r'
+                mode = 'rb'
             else:
-                mode = 'w'
+                mode = 'wb'
+        # Always force binary mode
+        if not 'b' in mode:
+            mode += 'b'
 
+        # Check final mode
+        if mode not in [ 'rb', 'wb', 'ab' ]:
+            raise ValueError("Invalid file  open mode %s " % mode)
+
+        pf.debug("Opening PGF file %s in %s mode" % (filename,mode),pf.DEBUG.PGF)
         self.file = utils.File(filename,mode,compr,level,delete_temp)
         self._autoname = None
 
@@ -140,6 +151,23 @@ class GeometryFile(object):
         self.open()
 
 
+    def readline(self):
+        """Read a line from the file"""
+        s = self.fil.readline()
+        if pf.PY3:
+            s = s.decode('latin1')  # accepts all 256 bytes as chars
+        return s
+
+
+    def writeline(self,s):
+        """Write a text line to the file"""
+        if not s.endswith('\n'):
+            s += '\n'
+        if pf.PY3:
+            s = s.encode('latin1')  # accepts all 256 bytes as chars
+        self.fil.write(s)
+
+
     @property
     def writing(self):
         return self.file.mode[0:1] in 'wa'
@@ -148,7 +176,7 @@ class GeometryFile(object):
     @property
     def autoname(self):
         if self._autoname is None:
-            self._autoname = utils.NameSequence(utils.projectName(self.file.name)+'-0')
+            self._autoname = utils.autoName(utils.projectName(self.file.name))
         return self._autoname
 
 
@@ -160,10 +188,10 @@ class GeometryFile(object):
             self.readHeader()
 
 
-    def reopen(self,mode='r'):
+    def reopen(self,mode='rb'):
         """Reopen the file, possibly changing the mode.
 
-        The default mode for the reopen is 'r'
+        The default mode for the reopen is 'rb'
         """
         self.fil = self.file.reopen(mode)
         if self.writing:
@@ -196,11 +224,11 @@ class GeometryFile(object):
         - `sep`: the default separator to be used when not specified in
           the data block
         """
-        self.fil.write("# pyFormex Geometry File (http://pyformex.org) version='%s'; sep='%s'\n" % (self.version, self.sep))
+        self.writeline("# pyFormex Geometry File (http://pyformex.org) version='%s'; sep='%s'" % (self.version, self.sep))
         self.header_done = True
 
 
-    def writeData(self,data,sep,fmt=None):
+    def writeData(self,data,sep):
         """Write an array of data to a pyFormex geometry file.
 
         If fmt is None, the data are written using numpy.tofile, with
@@ -210,10 +238,8 @@ class GeometryFile(object):
         """
         if not self.writing:
             raise RuntimeError("File is not opened for writing")
-        #kind = data.dtype.kind
-        #if fmt is None:
-        #    fmt = self.fmt[kind]
-        filewrite.writeData(self.fil, data, sep, end='\n')
+        filewrite.writeData(self.fil, data, sep, fmt=self.fmt)
+        self.writeline('') # Add a '\n'
 
 
     def write(self,geom,name=None,sep=None):
@@ -282,7 +308,7 @@ class GeometryFile(object):
             writefunc = getattr(self, 'write'+geom.__class__.__name__)
         except:
             pf.warning("Can not (yet) write objects of type %s to geometry file: skipping" % type(geom))
-            return 1
+            return 0
 
         if name is None:
             name = geom.attrib.name
@@ -293,16 +319,16 @@ class GeometryFile(object):
             writefunc(geom, name, sep)
         except:
             pf.warning("Error while writing objects of type %s to geometry file: skipping" % type(geom))
-            raise
+            return 0
 
         if geom.attrib and Version(self.version) >= Version('2.0'):
             try:
                 self.writeAttrib(geom.attrib)
             except:
                 pf.warning("Error while writing objects of type %s to geometry file: skipping" % type(geom))
-                raise
+                return 0
 
-        return 0
+        return 1
 
 
     def writeAttrib(self,attrib):
@@ -344,7 +370,7 @@ class GeometryFile(object):
             # dtypes are supported, and type is obvious from the stored values)
             s = re.sub(', *dtype=[^)]*\)',')',s)
             # Write the result to the file
-            self.fil.write("# attrib = %s\n" % s)
+            self.writeline("# attrib = %s" % s)
 
 
     def writeMesh(self,F,name=None,sep=None,objtype='Mesh'):
@@ -396,7 +422,7 @@ class GeometryFile(object):
         if colormap:
             head += "; colormap='%s'" % colormap
 
-        self.fil.write(head+'\n')
+        self.writeline(head)
 
         # Apply a fix to avoid a fewgl bug
         #
@@ -428,7 +454,7 @@ class GeometryFile(object):
         for field in F.fields:
             fld = F.fields[field]
             head = "# field='%s'; fldtype='%s'; shape=%r; sep='%s'" % (fld.fldname, fld.fldtype,fld.data.shape, sep)
-            self.fil.write(head+'\n')
+            self.writeline(head)
             self.writeData(fld.data, sep)
 
 
@@ -465,7 +491,7 @@ class GeometryFile(object):
             head += "; name='%s'" % name
         if extra:
             head += extra
-        self.fil.write(head+'\n')
+        self.writeline(head)
         self.writeData(F.coords, sep)
 
 
@@ -501,7 +527,7 @@ class GeometryFile(object):
             head += "; name='%s'" % name
         if extra:
             head += extra
-        self.fil.write(head+'\n')
+        self.writeline(head)
         self.writeData(F.coords, sep)
         self.writeData(F.knots, sep)
 
@@ -522,7 +548,7 @@ class GeometryFile(object):
             head += "; name='%s'" % name
         if extra:
             head += extra
-        self.fil.write(head+'\n')
+        self.writeline(head)
         self.writeData(F.coords, sep)
         self.writeData(F.uknots, sep)
         self.writeData(F.vknots, sep)
@@ -564,7 +590,7 @@ class GeometryFile(object):
 
 
         while True:
-            s = self.fil.readline()
+            s = self.readline()
 
             if len(s) == 0:   # end of file
                 break
@@ -623,8 +649,9 @@ class GeometryFile(object):
         a header line.
         """
         if s is None:
-            s = self.fil.readline()
+            s = self.readline()
 
+        pf.debug("PGF header line: %s" % s,pf.DEBUG.PGF)
         pos = s.rfind(')')
         s = s[pos+1:].strip()
         kargs = self.decode(s)
@@ -873,7 +900,7 @@ class GeometryFile(object):
             closed = None
             nparts = None
             nknots = None
-            s = self.fil.readline()
+            s = self.readline()
 
             if len(s) == 0:   # end of file
                 break
