@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -90,6 +90,21 @@ else:
 if not bindings:
     raise ValueError("\n"+"*"*40+"\nThe pyFormex GUI requires PySide, PySide2 or PyQt4.\nI could not find neither of them, so I can not continue.\nInstall PySide, PySide2 or PyQt4 (including its OpenGL component)\nand then retry."+"\n"+"*"*40)
 
+
+# Add conversion of QByteArray to str
+if pf.PY3 and bindings=='pyside2':
+    def QByteArrayToStr(self):
+        """Convert a QByteArray to a Python3 str"""
+        return str(self)[2:-1]
+if pf.PY2:
+    def QByteArrayToStr(self):
+        """Convert a QByteArray to a Python2 str"""
+        return str(self)
+QtCore.QByteArray.toStr = QByteArrayToStr
+
+
+# Load X11 color names
+
 def loadX11Colors(filename):
     """Load the X11 colors"""
     x11colors = {}
