@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -47,7 +47,7 @@ from __future__ import absolute_import, division, print_function
 from pyformex import zip
 
 from pyformex.opengl.colors import *
-from pyformex.utils import stuur
+from pyformex.arraytools import stuur
 import numpy as np
 
 # predefined color palettes
@@ -123,7 +123,8 @@ class ColorScale(object):
       user wants a nonlinear mapping, e.g. to have more visual accuracy in the
       higher or lower (absolute) values of the (sub)range(s). Therefore, the
       values are first linearly scaled to the -1..1 range, and then mapped
-      through the nonlinear function `util.stuur`. The effect is that with
+      through the nonlinear function :func:`arraytools.stuur`.
+      The effect is that with
       both exp > 1.0, more colors are used in the neighbourhood of the lowest
       value, while with exp < 1.0, more colors are use around the highest
       value. When both `exp` and `exp2`, the first one holds for the upper
