@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -393,17 +393,10 @@ class Gui(QtWidgets.QMainWindow):
         else:
             self.viewsMenu = None
 
-        defviews = pf.cfg['gui/defviews']
-        views = [ v[0] for v in defviews ]
-        viewicons = [ v[1] for v in defviews ]
-
-        self.viewbtns = menu.ActionList(
-            views, self.setView,
-            menu=self.viewsMenu,
-            toolbar=self.viewbar,
-            icons = viewicons
-            )
-
+        # Save front orientation
+        self.frontview = None
+        self.setViewButtons(pf.cfg['gui/defviews']
+)
         ## TESTING SAVE CURRENT VIEW ##
 
         self.saved_views = {}
@@ -505,6 +498,58 @@ class Gui(QtWidgets.QMainWindow):
             self.doc_dialog = None
 
 
+    def clearViewButtons(self):
+        """Clear the view buttons in views toolbar and views menu.
+
+        This is typically use from setViewButtons to change the
+        current buttons to a new set.
+        """
+        viewbtns = getattr(self,'viewbtns',None)
+        if viewbtns:
+            viewbtns.removeAll()
+            self.viewbtns = None
+            self.update()
+
+
+    def setViewButtons(self,defviews):
+        """Set view buttons in views toolbar and views menu.
+
+        defviews can be on of 'xy' or 'xz', or else it is
+        a list of tuple (viewname, viewicon)
+        """
+        if isinstance(defviews,str):
+            self.frontview = defviews
+            viewnames, realnames, viewicons = views.setOrientation(defviews)
+        else:
+            viewnames = [ v[0] for v in defviews ]
+            viewicons = [ v[1] for v in defviews ]
+
+        self.clearViewButtons()
+
+        self.viewbtns = menu.ActionList(
+            viewnames, self.setView,
+            menu=self.viewsMenu,
+            toolbar=self.viewbar,
+            icons = viewicons
+            )
+        self.update()
+
+
+    def createView(self, name, angles):
+        """Create a new view and add it to the list of predefined views.
+
+        This creates a named view with specified angles or, if the name
+        already exists, changes its angles to the new values.
+
+        It adds the view to the views Menu and Toolbar, if these exist and
+        do not have the name yet.
+        """
+        if name not in self.viewbtns.names():
+            iconpath = utils.findIcon('userview')
+            self.viewbtns.add(name, iconpath)
+        views.setAngles(name,angles)
+
+
     def saveView(self,name=None,addtogui=True):
         """Save the current view and optionally create a button for it.
 
@@ -531,21 +576,6 @@ class Gui(QtWidgets.QMainWindow):
             self.viewports.current.camera.setModelview(m)
 
 
-    def createView(self, name, angles):
-        """Create a new view and add it to the list of predefined views.
-
-        This creates a named view with specified angles or, if the name
-        already exists, changes its angles to the new values.
-
-        It adds the view to the views Menu and Toolbar, if these exist and
-        do not have the name yet.
-        """
-        if name not in self.viewbtns.names():
-            iconpath = utils.findIcon('userview')
-            self.viewbtns.add(name, iconpath)
-        views.view_angles[name] = angles
-
-
     def setView(self, view):
         """Change the view of the current GUI viewport, keeping the bbox.
 
@@ -698,7 +728,12 @@ class Gui(QtWidgets.QMainWindow):
                     self.canEdit = False
             else:
                 self.canPlay = hasattr(app, 'run')
-                self.canEdit = os.path.exists(apps.findAppSource(app))
+                appsource = apps.findAppSource(app)
+                if appsource:
+                    self.canEdit = os.path.exists(apps.findAppSource(app))
+                else:
+                    print("Could not find source of app '%s'" % app)
+                    self.canEdit = False
         else:
             # script file
             label = 'Script:'
@@ -728,7 +763,6 @@ class Gui(QtWidgets.QMainWindow):
 
     def setBusy(self,busy=True,force=False):
         if busy:
-            #pf.app.setOverrideCursor(QtGui.QCursor(QtCore.Qt.WaitCursor))
             pf.app.setOverrideCursor(QtCore.Qt.WaitCursor)
         else:
             pf.app.restoreOverrideCursor()
@@ -966,8 +1000,7 @@ class Gui(QtWidgets.QMainWindow):
         pf.canvas.cancel_selection()
         pf.canvas.cancel_draw()
         draw.clear_canvas()
-        #draw.wakeup()
-        self.setBusy(False)
+        self.resetCursor()
 
 
     def onExit(self, func):
@@ -1500,11 +1533,8 @@ pyFormex comes with ABSOLUTELY NO WARRANTY. This is free software, and you are w
     # cleanup
     if splash is not None:
         splash.showMessage("Set status bar");
-    pf.GUI.setBusy(False)         # HERE
     pf.GUI.addStatusBarButtons()
 
-    pf.GUI.setBusy(False)        # OR HERE
-
     pf.debug("Showing the GUI", pf.DEBUG.GUI)
     if splash is not None:
         splash.showMessage("Show the GUI");
@@ -1605,6 +1635,8 @@ def runGUI():
             pass
 
     pf.debug("Start main loop", pf.DEBUG.INFO)
+    # if pf.Path is None:
+    #     utils.warn("I could not import pathlib!\nPlease install python-pathlib2, as this will become a required dependency in the near future.\nOr use the Python3 version: pathlib is part of its standard library.")
     res = pf.app.exec_()
     pf.debug("Exit main loop with value %s" % res, pf.DEBUG.INFO)
     return res
