@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -78,8 +78,8 @@ def initialize():
     utils.hasExternal('imagemagick')
     # Set some globals
     pf.debug("Loading Image Formats", pf.DEBUG.IMAGE)
-    image_formats_qt = [str(f) for f in QtGui.QImageWriter.supportedImageFormats()]
-    image_formats_qtr = [str(f) for f in QtGui.QImageReader.supportedImageFormats()]
+    image_formats_qt = [f.toStr() for f in QtGui.QImageWriter.supportedImageFormats()]
+    image_formats_qtr = [f.toStr() for f in QtGui.QImageReader.supportedImageFormats()]
     ## if pf.cfg.get('imagesfromeps',False):
     ##     pf.image_formats_qt = []
 
