@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -32,14 +32,11 @@ import os
 from gettext import gettext as _
 
 import pyformex as pf
-from pyformex import zip
 from pyformex import utils
 from pyformex import script
+from pyformex.odict import OrderedDict
 
 from pyformex.gui import QtGui, QtCore, QtWidgets, Signal
-from pyformex.gui import toolbar, image, draw
-
-from pyformex.odict import OrderedDict
 
 # TODO: this should be removed!
 from pyformex.gui import *
@@ -437,7 +434,7 @@ class ActionList(object):
         action names. Icons will be taken from the installed icon directory.
         If you want to specify other icons, use the add() method.
         """
-        self.actions = []
+        self.actions = OrderedDict()
         self.function = function
         self.menu = menu
         self.toolbar = toolbar
@@ -469,24 +466,41 @@ class ActionList(object):
         a = DAction(text, icon, name)
         if self.function:
             a.signal.connect(self.function)
-        self.actions.append([name, a])
+        self.actions[name] = a
         if self.menu:
             self.menu.addAction(a)
         if self.toolbar:
             self.toolbar.addAction(a)
 
 
+    def remove(self,name):
+        """Remove an action by name"""
+        if name in self.actions:
+            action = self.actions[name]
+            if self.menu:
+                self.menu.removeAction(action)
+            if self.toolbar:
+                 self.toolbar.removeAction(action)
+            del self.actions[name]
+
+
+    def removeAll(self):
+        """Remove all actions from self"""
+        for name in self.actions:
+            self.remove(name)
+
+
     def names(self):
         """Return an ordered list of names of the action items."""
-        return [ i[0] for i in self.actions ]
+        return list(self.actions.keys())
 
 
     def toolbar(self, name):
         """Create a new toolbar corresponding to the menu."""
         # TODO: Fix this error!
         tb = QtWidgets.QToolBar(name)
-        for n, a in self.actions:
-            self.toolbar.addAction(a)
+        for n in self.actions:
+            self.toolbar.addAction(self.actions[a])
 
 
 
