@@ -1,11 +1,11 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.2  (Thu Jun 18 15:35:31 CEST 2015)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2015 (C) Benedict Verhegghe (benedict.verhegghe@feops.com)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -101,6 +101,12 @@ def zoomAll(*args,**kargs):
 @viewport_function
 def zoomRectangle(*args,**kargs):
         pass
+@viewport_function
+def saveCamera(*args,**kargs):
+        pass
+@viewport_function
+def loadCamera(*args,**kargs):
+        pass
 
 
 MenuData = (_('&Camera'),[
@@ -137,6 +143,8 @@ MenuData = (_('&Camera'),[
     ('---', None),
     (_('&Report'), reportCamera),
     (_('&Settings'), showCameraTool),
+    (_('&Save'), saveCamera),
+    (_('&Load'), loadCamera),
     ])
 
 
