@@ -1,11 +1,11 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.2  (Thu Jun 18 15:35:31 CEST 2015)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2015 (C) Benedict Verhegghe (benedict.verhegghe@feops.com)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,15 +26,15 @@
 """
 from __future__ import absolute_import, division, print_function
 
+import os, shutil
+from gettext import gettext as _
+
 import pyformex as pf
 from pyformex import utils, project
 
 from .Settings import updateSettings
 from .. import widgets, draw, image
-from ..draw import _I, _G
-
-import os, shutil
-from gettext import gettext as _
+from ..draw import _I, _G, busyCursor
 
 
 ##################### handle project files ##########################
@@ -73,22 +73,17 @@ def openProject(fn=None,exist=False,access=['wr', 'rw', 'w', 'r'],default=None):
     if not fn.endswith('.pyf'):
         fn += '.pyf'
     access = res.acc
+    protocol = res.pro
     compression = res.cpr
     convert = res.cvt
     signature = pf.fullVersion()
 
     # OK, we have all data, now create/open the project
     print("Opening project %s" % fn)
-    pf.GUI.setBusy() # loading  may take a while
-    try:
-        proj = project.Project(fn, access=access, convert=convert, signature=signature, compression=compression)
-        if proj.signature != signature:
-            pf.warning("The project was written with %s, while you are now running %s. If the latter is the newer one, this should probably not cause any problems. Saving is always done in the current format of the running version. Save your project and this message will be avoided on the next reopening." % (proj.signature, signature))
-    except:
-        proj = None
-        raise
-    finally:
-        pf.GUI.setBusy(False)
+    with busyCursor(): # loading  may take a while
+        proj = project.Project(fn, access=access, convert=convert, signature=signature, compression=compression, protocol=protocol)
+    if proj.signature != signature:
+        pf.warning("The project was written with %s, while you are now running %s. If the latter is the newer one, this should probably not cause any problems. Saving is always done in the current format of the running version. Save your project and this message will be avoided on the next reopening." % (proj.signature, signature))
 
     proj.hits = 0
     pf.debug("START COUNTING HITS", pf.DEBUG.PROJECT)
@@ -282,23 +277,30 @@ def saveProject():
     """
     if pf.PF.filename is not None:
         print("Saving Project contents: %s" % pf.PF.contents())
-        pf.GUI.setBusy()
         # Always put the current version is projects saved from file menu!
         pf.PF.signature = pf.fullVersion()
-        pf.PF.save()
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            pf.PF.save()
 
 
 def saveAsProject():
     """Save the current project under a new name.
 
-    A new project file is created, with the contents of the  current project.
-    The new project file becaomes the current one.
+    A new project file is created, with the contents of the current project.
+    The new project file becomes the current one.
     """
     proj = openProject(pf.PF.filename, exist=False, access=['w'], default='w')
+    #
+    #
+    # TODO: can we do proj.update(pf.PF) and pf.PF = proj instead ?
+    #
     if proj is not None: # even if empty
         pf.PF.filename = proj.filename
         pf.PF.gzip = proj.gzip
+        pf.PF.access = proj.access
+        pf.PF.signature = proj.signature
+        pf.PF.mode = proj.mode
+        pf.PF.protocol = proj.protocol
         saveProject()
     if pf.PF.filename is not None:
         updateSettings({
@@ -542,31 +544,29 @@ def createMovieInteractive():
     if not res:
         return
 
-    pf.GUI.setBusy()
-    image.createMovie(**res)
-    pf.GUI.setBusy(False)
+    with busyCursor():
+        image.createMovie(**res)
 
 
 
 #
 # TODO: this no longer works with the new webgl; should redo
 #
-## def exportPGF():
-##     """Export the current scene to PGF"""
-##     from pyformex.plugins.webgl import WebGL
-##     fn = draw.askNewFilename(pf.cfg['workdir'], ['pgf', 'all'])
-##     if fn:
-##         pf.GUI.setBusy()
-##         print("Exporting current scene to %s" % fn)
-##         fn = os.path.basename(fn)
-##         if not fn.endswith('.pgf'):
-##             fn += '.pgf'
-##         name = utils.projectName(fn)
-##         W = WebGL(name)
-##         W.addScene()
-##         res = W.exportPGF(fn, sep='')
-##         print("Contents: %s" % res)
-##         pf.GUI.setBusy(False)
+# def exportPGF():
+#     """Export the current scene to PGF"""
+#     from pyformex.plugins.webgl import WebGL
+#     fn = draw.askNewFilename(pf.cfg['workdir'], ['pgf', 'all'])
+#     if fn:
+#         with busyCursor():
+#             print("Exporting current scene to %s" % fn)
+#             fn = os.path.basename(fn)
+#             if not fn.endswith('.pgf'):
+#                 fn += '.pgf'
+#             name = utils.projectName(fn)
+#             W = WebGL(name)
+#             W.addScene()
+#             res = W.exportPGF(fn, sep='')
+#             print("Contents: %s" % res)
 
 
 last_exported_webgl = None
