@@ -1,11 +1,11 @@
-# $Id$ -*- coding: utf-8 -*-
+#    -*- coding: utf-8 -*-
 ##
-##  This file is part of pyFormex 1.0.2  (Thu Jun 18 15:35:31 CEST 2015)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2015 (C) Benedict Verhegghe (benedict.verhegghe@feops.com)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -254,15 +254,16 @@ MenuData = (_('&Help'),[
 def DevLinksMenuData():
     """Define extra help items for developer version"""
     pyformexdir = pf.cfg['pyformexdir']
+    dev2to3 = os.path.join(pyformexdir, "..", "p3.rst")
     devtodo = os.path.join(pyformexdir, "..", "TODO")
     devhowto = os.path.join(pyformexdir, "..", "HOWTO-dev.rst")
     devapp = os.path.join(pyformexdir, "..", "scripts-apps.rst")
     devextra = os.path.join(pyformexdir, "..", "install-extra.rst")
-    devopengl = os.path.join(pyformexdir, "..", "OPENGL-dev.rst")
+    #devopengl = os.path.join(pyformexdir, "..", "OPENGL-dev.rst")
     #print pf.refcfg.help['developer']
     developer = [
         ('Developer HOWTO', devhowto),
-        ('New OPENGL engine', devopengl),
+        ('Migration to Python3', dev2to3),
         ('Scripts versus Apps', devapp),
         ('pyFormex TODO list', devtodo),
         ('Installation of extra software', devextra),
