@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.2  (Thu Jun 18 15:35:31 CEST 2015)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2015 (C) Benedict Verhegghe (benedict.verhegghe@feops.com)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -34,7 +34,7 @@ from pyformex import gui
 from pyformex import zip,utils
 from pyformex.gui import widgets, toolbar, draw
 from pyformex.main import savePreferences
-from pyformex.gui.draw import _I, _G, _T
+from pyformex.gui.draw import _I, _G, _H, _T
 
 
 def updateSettings(res,save=None):
@@ -211,6 +211,9 @@ def settings():
     dia = widgets.InputDialog(
         caption='pyFormex Settings',
         store=pf.cfg,
+        scroll=True,        # This has huge input pages
+        size=(0.6,0.9),
+        buttonsattop=True,  # Put buttons at top
         items=[
             _T('General', [
                 _I('syspath', tooltip="If you need to import modules from a non-standard path, you can supply additional paths to search here."),
@@ -238,7 +241,9 @@ def settings():
                 ]),
             _T('GUI', [
                 _G('Appearance', appearance),
-                _G('Components', toolbars+actionbuttons+[
+                _G('Components', toolbars + [
+                    _I('gui/defviews', pf.cfg['gui/defviews'], itemtype='hradio', choices=['xy','xz'],tooltip="Axes defining the front view"),
+                ] + actionbuttons + [
                     _I('gui/console', gui_console_options[pf.cfg['gui/console']], itemtype='hradio', choices=list(gui_console_options.values()), text="Board"),
                     _I('gui/redirect', pf.cfg['gui/redirect']),
                     _I('gui/coordsbox'),
@@ -278,10 +283,10 @@ def settings():
             ('Accept', accept),
             ],
         )
-    #dia.resize(800,400)
     dia.show()
 
 
+
 def askConfigPreferences(items,prefix=None,store=None):
     """Ask preferences stored in config variables.
 
@@ -349,10 +354,11 @@ def setRendering():
         dia['material'].setEnabled(on)
 
     def updateLightParams(matname):
+        if dia is None:
+            return
         matname=str(matname)
         mat = pf.GUI.materials[matname]
         val = utils.prefixDict(mat.dict(), 'material/')
-        print("UPDATE", val)
         dia.updateData(val)
 
     def close():
@@ -549,7 +555,9 @@ def setDebug():
     options.remove('NONE')
     values = [ getattr(pf.DEBUG, o) for o in options ]
     items = [ _I(o, bool(pf.options.debuglevel & v)) for o, v in zip(options, values) ]
-    res = draw.askItems(items)
+    n = (len(options)+1) // 2
+    cols = [ _H('col',items[:n]), _H('col',items[n:]), ]
+    res = draw.askItems(cols)
     if res:
         print(res)
         debug = 0
@@ -589,6 +597,9 @@ def resetFactory():
 def updateConsole():
     pf.GUI.createConsole(pf.cfg['gui/console'])
 
+def updateDefViews():
+    pf.GUI.setViewButtons(pf.cfg['gui/defviews'])
+
 def coordsbox():
     """Toggle the coordinate display box on or off"""
     pf.GUI.coordsbox.setVisible(pf.cfg['gui/coordsbox'])
@@ -629,6 +640,7 @@ _activate_settings = {
 #    'gui/interpreter':updateInterpreter,
     'gui/console': updateConsole,
     'gui/coordsbox': coordsbox,
+    'gui/defviews': updateDefViews,
     'gui/timeoutbutton': timeoutbutton,
     'gui/showfocus': updateCanvas,
     'gui/style': updateStyle,
