@@ -1,11 +1,11 @@
 #
 ##
-##  This file is part of pyFormex 1.0.2  (Thu Jun 18 15:35:31 CEST 2015)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2015 (C) Benedict Verhegghe (benedict.verhegghe@feops.com)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,7 @@ from gettext import gettext as _
 
 import pyformex as pf
 from pyformex import utils
-from pyformex.gui import widgets, draw
+from pyformex.gui import widgets, draw, views
 from pyformex.opengl import canvas
 from pyformex.gui.draw import _I
 from .Settings import updateSettings
@@ -54,17 +54,37 @@ def setTriade():
 
 
 def setGrid():
-    res = draw.askItems([
-        _I('grid', True, text='Show grid'),
-        _I('d', 100, text='Distance between grid lines'),
-        _I('s', 0, text='Total grid size (0=canvas size)'),
-        _I('lw',1, text='Line width'),
-        _I('lc','black',itemtype='color',text='Line color'),
-        _I('ontop', False),
+    canvasgrid_settings = dict([
+        (k,pf.cfg['canvasgrid/'+k]) for k in ['showgrid','spacing','size',
+                'linewidth','color','twocolor','color2','ontop']])
+    res = draw.askItems(store=canvasgrid_settings,items=[
+        _I('showgrid',True, text='Show grid'),
+        _I('spacing', text='Distance between grid lines'),
+        _I('size', text='Total grid size (0=canvas size)'),
+        _I('linewidth',text='Line width'),
+        _I('color', itemtype='color',text='Line color'),
+        _I('twocolor',),
+        _I('color2', itemtype='color',text='Second line color'),
+        _I('ontop', ),
+        _I('_save_', False, text='Save as my defaults'),
+        ],enablers=[
+            ('twocolor',True,'color2')
         ])
     if res:
-        s = res['s'] if res['s'] >= 1 else None
-        draw.setGrid(on=res['grid'],d=res['d'],s=s,linewidth=res['lw'],ontop=res['ontop'],color=res['lc'],lighting=False)
+        if res['twocolor']:
+            color = (res['color'],res['color2'])
+        else:
+            color = res['color']
+        s = res['size'] if res['size'] >= 1 else None
+        if res['showgrid']:
+            draw.setGrid(on=res['showgrid'],d=res['spacing'],s=s,linewidth=res['linewidth'],ontop=res['ontop'],color=color,lighting=False)
+        save = res['_save_']
+        del res['showgrid']
+        del res['_save_']
+        res = utils.prefixDict(res,prefix='canvasgrid/')
+        res['_save_'] = save
+        print(res)
+        updateSettings(res)
 
 
 def setBgColor():
@@ -305,7 +325,7 @@ def drawOptions(d={}):
     draw.setDrawOptions(d)
     print(pf.canvas.drawoptions)
     res = draw.askItems(store=pf.canvas.drawoptions, items=[
-        _I('view', choices=['None']+[k for k in pf.canvas.view_angles], tooltip="Camera viewing direction"),
+        _I('view', choices=['None']+views.viewNames(), tooltip="Camera viewing direction"),
         _I('bbox', choices=['auto', 'last'], tooltip="Automatically focus/zoom on the last drawn object(s)"),
         _I('clear_', tooltip="Clear the canvas on each drawing action"),
         _I('shrink', tooltip="Shrink all elements to make their borders better visible"),
@@ -414,6 +434,8 @@ MenuData = (_('&Viewport'), [
     (_('&Change viewport layout'), viewportLayout),
     (_('&Add new viewport'), draw.addViewport),
     (_('&Remove last viewport'), draw.removeViewport),
+    (_('&Save'), draw.saveCanvas),
+    (_('&Load'), draw.loadCanvas),
     ])
 
 
