@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -34,7 +34,7 @@ import pyformex as pf
 from pyformex.gui import QtGui, QtCore, QtWidgets
 from pyformex.gui.guimain import Board
 
-if not pf.PY3:
+if pf.PY2:
     range = xrange
 
 
