@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -39,17 +39,18 @@ from numpy import *
 
 
 import pyformex as pf
-from pyformex import zip, round, utils
+from pyformex import round, utils
 
 from pyformex.opengl import canvas
 from pyformex.gui import (
     QtCore, QtGui, QtOpenGL, QtWidgets,
-    image, toolbar,
+    image, toolbar, qtutils,
     )
 
 from pyformex.collection import Collection
+from pyformex.config import Config
 from pyformex.coords import Coords
-from pyformex.arraytools import isInt,unitVector
+from pyformex.arraytools import isInt,unitVector,stuur,checkInt
 from pyformex.gui.signals import *
 
 
@@ -367,7 +368,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         QtOpenGL.QGLWidget.__init__(self,*args)
         if pf.options.debuglevel & pf.DEBUG.OPENGL:
             pf.debug("QtCanvas.__init__:\n"+OpenGLFormat(self.format()),pf.DEBUG.OPENGL)
-        # Define our privatee signals
+        # Define our private signals
         self.signals = self.Communicate()
         self.CANCEL = self.signals.CANCEL
         self.DONE   = self.signals.DONE
@@ -421,8 +422,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
 
     def getSize(self):
         """Return the size of this canvas"""
-        from pyformex.gui.guimain import Size
-        return Size(self)
+        return qtutils.Size(self)
 
 
     def saneSize(self, width=0, height=0):
@@ -756,11 +756,13 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         pf.debug("START SELECTION DONE", pf.DEBUG.GUI)
 
 
-    def wait_selection(self):
+    def wait_selection(self,events=[]):
         """Wait for the user to interactively make a selection."""
         pf.debug("WAIT SELECTION", pf.DEBUG.GUI)
         self.selection_timer = QtCore.QThread
         self.selection_busy = True
+        for event in events:
+            pf.app.sendEvent(self,event)
         while self.selection_busy:
             self.selection_timer.msleep(20)
             pf.app.processEvents()
@@ -799,7 +801,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.accept_selection(clear=True)
 
 
-    def pick(self,mode='actor',oneshot=False,func=None,filter=None,pickable=None):
+    def pick(self,mode='actor',oneshot=False,func=None,filter=None,pickable=None,_rect=None):
         """Interactively pick objects from the viewport.
 
         - `mode`: defines what to pick : one of
@@ -836,8 +838,15 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.setFocus()
         self.selection_canceled = False
         self.start_selection(mode, filter, pickable)
+        if _rect:
+            events = self.mouse_pick_simulate(*_rect)
+        else:
+            events = []
         while not self.selection_canceled:
-            self.wait_selection()
+            if events:
+                self.wait_selection(events.pop(0))
+            else:
+                self.wait_selection()
             if not self.selection_canceled:
                 # selection by mouse_picking
                 self.pick_func[self.pick_mode]()
@@ -898,6 +907,17 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         """Go into number picking mode and return the selection."""
         return self.pick('numbers',*args,**kargs)
 
+
+    def mouse_pick_simulate(self,x0,y0,x1,y1):
+        """Emit the mouse button events to simulate picking rectangle"""
+        event1 = QtGui.QMouseEvent(QtCore.QEvent.MouseButtonPress,QtCore.QPoint(x0,y0),QtCore.Qt.LeftButton,QtCore.Qt.LeftButton,QtCore.Qt.NoModifier)
+        event2 = QtGui.QMouseEvent(QtCore.QEvent.MouseMove,QtCore.QPoint(x1,y1),QtCore.Qt.NoButton,QtCore.Qt.LeftButton,QtCore.Qt.NoModifier)
+        event3 = QtGui.QMouseEvent(QtCore.QEvent.MouseButtonRelease,QtCore.QPoint(x1,y1),QtCore.Qt.LeftButton,QtCore.Qt.NoButton,QtCore.Qt.NoModifier)
+        event4 = QtGui.QMouseEvent(QtCore.QEvent.MouseButtonPress,QtCore.QPoint(x1,y1),QtCore.Qt.RightButton,QtCore.Qt.RightButton,QtCore.Qt.NoModifier)
+        event5 = QtGui.QMouseEvent(QtCore.QEvent.MouseButtonRelease,QtCore.QPoint(x1,y1),QtCore.Qt.RightButton,QtCore.Qt.NoButton,QtCore.Qt.NoModifier)
+        return [ [event1,event2,event3], [ event4, event5] ]
+
+
 #################### Interactive drawing ####################################
 
     def idraw(self,mode='point',npoints=-1,zplane=0.,func=None,coords=None,preview=False):
@@ -1183,7 +1203,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
                 a0 = math.atan2(x0[0], x0[1])
                 a1 = math.atan2(x1[0], x1[1])
                 an = (a1-a0) / math.pi * 180
-                ds = utils.stuur(d, [-h/4, h/8, h/4], [-1, 0, 1], 2)
+                ds = stuur(d, [-h/4, h/8, h/4], [-1, 0, 1], 2)
                 twist = - an*ds
                 self.camera.rotate(twist, 0., 0., 1.)
                 self.state = x1
@@ -1194,7 +1214,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
             dx = [x-self.statex, y-self.statey]        # movement
             b = projection(dx, x0)
             if abs(b) > 5:
-                val = utils.stuur(b, [-2*h, 0, 2*h], [-180, 0, +180], 1)
+                val = stuur(b, [-2*h, 0, 2*h], [-180, 0, +180], 1)
                 rot =  [ abs(val), -dx[1], dx[0], 0 ]
                 self.camera.rotate(*rot)
                 self.statex, self.statey = (x, y)
@@ -1244,7 +1264,7 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
                     f = exp(4*d)
                     self.camera.zoomArea(f, area=asarray(self.state[1]).reshape(2, 2))
                 elif method == 'dolly':
-                    d = utils.stuur(value, [0, state, size], [5, 1, 0.2], 1.2)
+                    d = stuur(value, [0, state, size], [5, 1, 0.2], 1.2)
                     self.camera.dist = d*self.state[0]
 
             self.update()
@@ -1432,9 +1452,11 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         else:
             e.ignore()
 
-################# Multiple Viewports ###############
 
-class NewMultiCanvas(QtWidgets.QGridLayout):
+###########################################################################
+#####    Multiple Viewports    #######
+
+class MultiCanvas(QtWidgets.QGridLayout):
     """An OpenGL canvas with multiple viewports and QT interaction.
 
     The MultiCanvas implements a central QT widget containing one or more
@@ -1443,9 +1465,15 @@ class NewMultiCanvas(QtWidgets.QGridLayout):
     def __init__(self,parent=None):
         """Initialize the multicanvas."""
         QtWidgets.QGridLayout.__init__(self)
+        self.setContentsMargins(0, 0, 0, 0)
         self.all = []
+        self.links = {}
         self.current = None
+        self.ncols = 2
         self.rowwise = True
+        self.pos = None
+        self.rstretch = None
+        self.cstretch = None
         self.parent = parent
 
 
@@ -1463,232 +1491,46 @@ class NewMultiCanvas(QtWidgets.QGridLayout):
         available space)
         Each of this parameters is optional.
 
-        If pos is given, it specifies all viewports and nvps, nrows and ncols
-        are disregarded.
-
-        Else:
-
-        If nvps is given, it specifies the number of viewports in the layout.
-        Else, nvps will be set to the current number of viewports.
+        If a number of viewports is given, viewports will be added
+        or removed to match the requested number.
+        By default they are laid out rowwise over two columns.
 
         If ncols is an int, viewports are laid out rowwise over ncols
         columns and nrows is ignored. If ncols is None and nrows is an int,
-        viewports are laid out columnwise over nrows rows.
-
-        If nvps is not equal to the current number of viewports, viewports
-        will be added or removed to match the requested number.
-
-        By default they are laid out rowwise over two columns.
+        viewports are laid out columnwise over nrows rows. Alternatively,
+        the pos argument can be used to specify the layout of the viewports.
         """
-        if pos is None:
-            # get the new layout definition
-            if nvps is None:
-                nvps = len(self.all)
-            if ncols is None:
-                if nrows is None:
-                    ncols = self.ncols()
-            if isInt(ncols):
-                pos = [ divmod(i, ncols) for i in range(nvps) ]
-            elif isInt(nrows):
-                pos = [ divmod(i, nrows)[::-1] for i in range(nvps) ]
-            else:
-                return
+        # add or remove viewports to match the requested number
+        if isInt(nvps):
+            while len(self.all) > nvps:
+                self.removeView()
+            while len(self.all) < nvps:
+                self.addView()
+        # get the new layout definition
+        if isInt(ncols):
+            rowwise = True
+            pos = None
+        elif isInt(nrows):
+            ncols = nrows
+            rowwise = False
+            pos = None
+        elif isinstance(pos, list) and len(pos) == len(self.all):
+            ncols = None
+            rowwise = None
         else:
-            nvps = len(pos)
-
-        while len(self.all) < nvps:
-            # create new viewports
-            view = self.createView()
-            self.all.append(view)
-
-        while len(self.all) > nvps:
-            # remove viewports
-            self.removeView()
-
-        # remove all views from the canvas
+            return
+        # remove the viewport widgets
         for w in self.all:
             self.removeWidget(w)
-           # w.hide()
-
-        # create the new layout
-        for view, args in zip(self.all, pos):
-            self.addView(view,*args)
-        self.setCurrent(self.all[-1])
-
-
-    def createView(self,shared=None):
-        """Create a new viewport
-
-        If another QtCanvas instance is passed, both will share the same
-        display lists and textures.
-        """
-        if shared is not None:
-            pf.debug("SHARING display lists WITH %s" % shared, pf.DEBUG.DRAW)
-        view = QtCanvas(self.parent, shared)
-        if len(self.all) > 0:
-            # copy default settings from previous
-            view.resetDefaults(self.all[-1].settings)
-        return(view)
-
-
-    def addView(self,view,row,col,rowspan=1,colspan=1):
-        """Add a new viewport and make it visible"""
-        self.addWidget(view, row, col, rowspan, colspan)
-        view.raise_()
-        view.initializeGL()   # Initialize OpenGL context and camera
-
-
-    def removeView(self,view=None):
-        """Remove a view from the canvas
-
-        If view is None, the last one is removed.
-        You can not remove a view when there is only one left.
-        """
-        if len(self.all) > 1:
-            if view is None:
-                view = self.all.pop()
-            else:
-                i = self.all.find(view)
-                if i < 0:
-                    return
-                view = self.all.pop(i)
-                if self.current == view:
-                    self.setCurrent(self.all[i-1])
-                self.removeWidget(view)
-                view.close()
-
-
-    def setCurrent(self, view):
-        """Make the specified viewport the current one.
-
-        view can be either a viewport or viewport number.
-        The current viewport is the one that will be used for drawing
-        operations. This may be different from the viewport having GUI
-        focus (pf.canvas).
-        """
-        #print "NEWCANVAS SETTING CURRENT VIEWPORT"
-        if isInt(view) and view in range(len(self.all)):
-            view = self.all[view]
-        if view == self.current:
-            return  # already current
-
-        if view in self.all:
-            if self.current:
-                self.current.focus = False
-                self.current.updateGL()
-            self.current = view
-            self.current.focus = True
-            self.current.updateGL()
-
-        pf.canvas = pf.GUI.viewports.current
-
-
-
-    def currentView(self):
-        return self.all.index(self.current)
-
-
-    def nrows(self):
-        return self.rowCount()
-
-
-    def ncols(self):
-        return self.columnCount()
-
-
-    def setStretch(self, rowstretch, colstretch):
-        """Set the row and column stretch factors.
-
-        rowstretch and colstretch are lists of stretch factors to be applied
-        on the subsequent rows/columns. If the lists are shorter than the
-        number of rows/columns, the
-        """
-        if rowstretch:
-            for i in range(min(len(rowstretch), self.nrows())):
-                self.setRowStretch(i, rowstretch[i])
-        if colstretch:
-            for i in range(min(len(colstretch), self.ncols())):
-                self.setColumnStretch(i, colstretch[i])
-
-
-    def updateAll(self):
-         pf.debug("UPDATING ALL VIEWPORTS", pf.DEBUG.GUI)
-         for v in self.all:
-             v.update()
-         pf.GUI.processEvents()
-
-
-    def printSettings(self):
-        for i, v in enumerate(self.all):
-            print("""
-## VIEWPORTS ##
-Viewport %s;  Current:%s;  Settings:
-%s
-""" % (i, v == self.current, v.settings))
-
-
-    def link(self, vp, to):
-        """Link viewport vp to to"""
-        print("LINK %s to %s" % (vp, to))
-        print("LINKING CURRENTLY DISABLED")
-        return
-        nvps = len(self.all)
-        if vp in range(nvps) and to in range(nvps) and vp != to:
-            to = self.all[to]
-            oldvp = self.all[vp]
-            utils.warn('warn_viewport_linking')
-            newvp = self.newView(to)
-            self.all[vp] = newvp
-            self.removeWidget(oldvp)
-            oldvp.close()
-            self.showWidget(newvp)
-            vp = newvp
-            vp.scene = to.scene
-            vp.show()
-            vp.setCamera()
-            vp.redrawAll()
-            #vp.updateGL()
-            pf.GUI.processEvents()
-
-
-
-class FramedGridLayout(QtWidgets.QGridLayout):
-    """A QtWidgets.QGridLayout where each added widget is framed."""
-
-    def __init__(self,parent=None):
-        """Initialize the multicanvas."""
-        QtWidgets.QGridLayout.__init__(self)
-        self.setContentsMargins(0, 0, 0, 0)
-#       self.frames = []
-
-
-    def addWidget(*args):
-#        f = QtWidgets.QFrame(w)
-#        self.frames.append(f)
-        QtWidgets.QGridLayout.addWidget(*args)
-
-
-    def removeWidget(self, w):
-        QtWidgets.QGridLayout.removeWidget(self, w)
-
-
-class MultiCanvas(FramedGridLayout):
-    """An OpenGL canvas with multiple viewports and QT interaction.
-
-    The MultiCanvas implements a central QT widget containing one or more
-    QtCanvas widgets.
-    """
-    def __init__(self,parent=None):
-        """Initialize the multicanvas."""
-        FramedGridLayout.__init__(self)
-        self.all = []
-        self.current = None
-        self.ncols = 2
-        self.rowwise = True
-        self.pos = None
-        self.rstretch = None
-        self.cstretch = None
-        self.parent = parent
+        # assign the new layout arguments
+        self.ncols = ncols
+        self.rowwise = rowwise
+        self.pos = pos
+        self.rstretch = rstretch
+        self.cstretch = cstretch
+        # add the viewport widgets
+        for w in self.all:
+            self.showWidget(w)
 
 
     def newView(self,shared=True,settings=None):
@@ -1748,19 +1590,17 @@ class MultiCanvas(FramedGridLayout):
 
         canv can be either a viewport or viewport number.
         """
-        #print "SETTING CURRENT VIEWPORT"
         if isInt(canv) and canv in range(len(self.all)):
             canv = self.all[canv]
         if canv == self.current:
-            #print "ALREADY CURRENT"
             pass
         elif canv in self.all:
-            #print "CHANGING CURRENT"
             if self.current:
                 self.current.focus = False
                 self.current.updateGL()
             self.current = canv
-            self.current.focus = True
+            # Only show focus if more than 1
+            self.current.focus = len(pf.GUI.viewports.all) > 1 and pf.cfg['gui/showfocus']
             self.current.updateGL()
             toolbar.updateViewportButtons(self.current)
 
@@ -1773,6 +1613,7 @@ class MultiCanvas(FramedGridLayout):
 
 
     def currentView(self):
+        """Return the index of the current view"""
         return self.all.index(self.current)
 
 
@@ -1804,14 +1645,21 @@ class MultiCanvas(FramedGridLayout):
 
 
     def removeView(self):
+        """Remove the last view"""
         if len(self.all) > 1:
             w = self.all.pop()
+            lastnr = len(self.all)
+            if lastnr in self.links:
+                del self.links[lastnr]
             if self.pos is not None:
                 self.pos = self.pos[:-1]
             if self.current == w:
                 self.setCurrent(self.all[-1])
             self.removeWidget(w)
             w.close()
+            # Remove focus rectangle if only one left
+            if len(self.all) == 1:
+                self.current.focus = False
             # set the stretch factors
             pos = [self.getItemPosition(self.indexOf(w)) for w in self.all]
             if self.rstretch is not None:
@@ -1844,92 +1692,111 @@ Viewport %s;  Current:%s;  Settings:
 """ % (i, v == self.current, v.settings))
 
 
-    def changeLayout(self,nvps=None,ncols=None,nrows=None,pos=None,rstretch=None,cstretch=None):
-        """Change the lay-out of the viewports on the OpenGL widget.
-
-        nvps: number of viewports
-        ncols: number of columns
-        nrows: number of rows
-        pos: list holding the position and span of each viewport
-        [[row,col,rowspan,colspan],...]
-        rstretch: list holding the stretch factor for each row
-        cstretch: list holding the stretch factor for each column
-        (rows/columns with a higher stretch factor take more of the
-        available space)
-        Each of this parameters is optional.
-
-        If a number of viewports is given, viewports will be added
-        or removed to match the requested number.
-        By default they are laid out rowwise over two columns.
-
-        If ncols is an int, viewports are laid out rowwise over ncols
-        columns and nrows is ignored. If ncols is None and nrows is an int,
-        viewports are laid out columnwise over nrows rows. Alternatively,
-        the pos argument can be used to specify the layout of the viewports.
-        """
-        # add or remove viewports to match the requested number
-        if isInt(nvps):
-            while len(self.all) > nvps:
-                self.removeView()
-            while len(self.all) < nvps:
-                self.addView()
-        # get the new layout definition
-        if isInt(ncols):
-            rowwise = True
-            pos = None
-        elif isInt(nrows):
-            ncols = nrows
-            rowwise = False
-            pos = None
-        elif isinstance(pos, list) and len(pos) == len(self.all):
-            ncols = None
-            rowwise = None
-        else:
-            return
-        # remove the viewport widgets
-        for w in self.all:
-            self.removeWidget(w)
-        # assign the new layout arguments
-        self.ncols = ncols
-        self.rowwise = rowwise
-        self.pos = pos
-        self.rstretch = rstretch
-        self.cstretch = cstretch
-        # add the viewport widgets
-        for w in self.all:
-            self.showWidget(w)
-
-
+    # TODO: We should probably limit linking to the changelayout case
     def link(self, vp, to):
         """Link viewport vp to to"""
-        print("LINK %s to %s" % (vp, to))
         nvps = len(self.all)
-        if vp in range(nvps) and to in range(nvps) and vp != to:
-            to = self.all[to]
-            oldvp = self.all[vp]
-            utils.warn('warn_viewport_linking')
-            newvp = self.newView(shared=True)
-            self.all[vp] = newvp
-            self.removeWidget(oldvp)
-            oldvp.close()
-            self.showWidget(newvp)
-            vp = newvp
-            vp.scene.actors = to.scene.actors
-            vp.show()
-            vp.setCamera()
-            vp.redrawAll()
-            #vp.updateGL()
-            pf.GUI.processEvents()
+        vp = checkInt(vp,0,nvps-1)
+        to = checkInt(to,0,nvps-1)
+        # resolve links
+        while to != vp and to in self.links:
+            to = self.links[to]
+        if to == vp:
+            raise ValueError("Can not link viewport to itself")
+        print("Link viewport %s to %s" % (vp, to))
+        self.links[vp] = to
+        tovp = self.all[to]
+        oldvp = self.all[vp]
+        utils.warn('warn_viewport_linking')
+        newvp = self.newView(shared=True)
+        self.all[vp] = newvp
+        self.removeWidget(oldvp)
+        oldvp.close()
+        self.showWidget(newvp)
+        newvp.scene = tovp.scene
+        #newvp.scene.actors = to.scene.actors
+        newvp.show()
+        newvp.setCamera()
+        newvp.redrawAll()
+        #newvp.updateGL()
+        pf.GUI.processEvents()
 
 
-def _auto_initialize():
-    global MultiCanvas
-    try:
-        if pf.options.newviewports:
-            MultiCanvas = NewMultiCanvas
-    except:
-        pass
+    def config(self):
+        """Return the full configuration needed to restore this MultiCanvas.
+
+        Currently only works on single viewport.
+        """
+        from pyformex.plugins.saveload import dict2Config
+        C = Config()
+        C['nvps'] = len(self.all)
+        if len(self.all) > 1:
+            C['current'] = self.viewIndex(self.current)
+            C['canvas'] = self.viewIndex(pf.canvas)
+        if self.rowwise:
+            C['ncols'] = self.ncols
+        else:
+            C['nrows'] = self.ncols
+        for i,vp in enumerate(self.all):
+            Ci = dict2Config(vp.settings)
+            Ci['rendermode'] = vp.rendermode
+            C.update(Ci,name='canvas%s'%i)
+            Ci = dict2Config(vp.camera.settings)
+            C.update(Ci,name='camera%s'%i)
+
+        # GUI settings:
+        #C['canvas_size'] = pf.canvas.getSize()
+        C['central_size'] = qtutils.Size(pf.GUI.central)
+        C['gui_size'] = qtutils.Size(pf.GUI)
+        return C
+
+
+    def save(self,filename):
+        """Save the canvas settings to file
+
+        Currently only works on single viewport.
+        """
+        C = self.config()
+        C.write(filename,header="#Canvas settings saved from pyFormex\n",trailer="#End\n")
+
+
+    def loadConfig(self,config):
+        """Reset the viewports size, layout and cameras from a Config dict"""
+        d = utils.selectDict(config,['nvps','ncols','nrows'],remove=True)
+        size = config.pop('gui_size',None)
+        if size:
+            pf.GUI.resize(*size)
+        size = config.pop('central_size',None)
+        if size:
+            pf.GUI.central.resize(*size)
+        self.changeLayout(**d)
+        # size = config.pop('canvas_size',None)
+        # if size:
+        #     pf.canvas.changeSize(*size)
+        for i in range(len(self.all)):
+            Ci = config['canvas%s'%i]
+            mode = Ci.pop('rendermode',None)
+            canvas = self.all[i]
+            canvas.settings.update(Ci)
+            if mode:
+                canvas.setRenderMode(mode)
+            Ci = config['camera%s'%i]
+            canvas.camera.loadConfig(Ci)
+
+        current = config.pop('current',None)
+        if current:
+            self.setCurrent(current)
+
+        self.update()
+
+
+    def load(self,filename):
+        """Load the canvas settings from file"""
+        try:
+            C = Config(filename)
+        except:
+            raise ValueError("Invalid Camera save file: %s" % filename)
+        self.loadConfig(C)
 
-_auto_initialize()
 
 # End
