@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -60,7 +60,7 @@ class Tensor(np.ndarray):
 
     Parameters:
 
-    - `data`: array-like (float) of shape (3,3) or (6,)
+    - `data`: :term:`array_like` (float) of shape (3,3) or (6,)
     - `symmetric`: bool. If True (default), the tensor is forced to be
       symmetric by averaging the off-diagonal elements.
     - `cs`: CoordSys. The coordinate system of the tensor.
