@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -97,8 +97,11 @@ def nodalSum(val, elems, nnod):
 def tofile_int32(val, fil, fmt):
     fmt = fmt * val.shape[-1]
     for row in val:
-        fil.write(fmt % tuple(row))
-        fil.write('\n')
+        s = fmt % tuple(row) + '\n'
+        if pf.PY3:
+            if 'b' in fil.mode:
+                s = s.encode('latin1')  # accepts all 256 bytes as chars
+        fil.write(s)
 
 tofile_float32 = tofile_int32
 
