@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -38,6 +38,8 @@ from pyformex.config import Config
 from pyformex import utils
 from pyformex import software
 
+# Note: noe of the above import numpy
+
 ###########################  main  ################################
 
 def filterWarnings():
@@ -98,6 +100,27 @@ def remove_pyFormex(pyformexdir, executable):
     egginfo = glob.glob(egginfo)
     #print("egginfo = %s" % egginfo)
     script = os.path.join(bindir, 'pyformex')
+
+    #
+    # TEST FOR OTHER PYTHON VERSION
+    if pf.PY2:
+        this = '2'
+        other = '3'
+    if pf.PY3:
+        this = '3'
+        other = '2'
+    cmd = '%s -%s --whereami' % (script,other)
+    P = utils.system(cmd)
+    if P.sta==0:
+        out = P.out.split('\n')
+        if out[0]==pf.fullVersion() and '(R)' in out[2]:
+            # Also remove other?
+            pass
+        else:
+            other = ''
+    else:
+        other = ''
+
     scripts = [ script ] + glob.glob(script+'-*')
     gtsexe = ['gtscoarsen', 'gtsinside', 'gtsrefine', 'gtsset', 'gtssmooth' ]
     scripts += [ os.path.join(bindir, g) for g in gtsexe ]
@@ -116,37 +139,53 @@ def remove_pyFormex(pyformexdir, executable):
     data = [ p for p in data if os.path.exists(p) ]
     other_files = scripts + egginfo + data
     #print(other_files)
+
+    if other:
+        print("""
+############ NOTE!
+I found a Python2 and a Python3 installation of %s
+If you continue with the removal, I will only remove the Python%s version.
+Afterwards, your Python%s version will still run. You can remove that
+with the command 'pyformex -%s --remove'.
+""" % (pf.fullVersion(),this,other,other))
+        do_other = 'KEEP'
+    else:
+        do_other = 'REMOVE'
+
     print("""
-BEWARE!
-This procedure will remove:
-- the complete pyFormex installation in %s,
-- the pyFormex executable(s) (%s) in %s,
-- some pyFormex data files (%s) in %s.
+############ BEWARE!
+This procedure will:
+- %s the complete Python%s pyFormex installation in %s,
+- %s the pyFormex executable(s) (%s) in %s,
+- %s some pyFormex data files (%s) in %s.
+
 You should only use this on a pyFormex installed from a source .tar.gz release
-with the command 'python setup.py install'.
+with the command 'python(2/3) setup.py install'.
 You need proper permissions to actually delete the files.
 After succesful removal, you will not be able to run this pyFormex again,
 unless you re-install it.
 """ % (
-    pyformexdir,
-    ', '.join([ os.path.basename(p) for p in scripts ]), bindir,
-    ', '.join([ os.path.basename(p) for p in data ]), datadir
+    'REMOVE', this, pyformexdir,
+    do_other, ', '.join([ os.path.basename(p) for p in scripts ]), bindir,
+    do_other, ', '.join([ os.path.basename(p) for p in data ]), datadir
     ))
 
     s = pf.userInput("Are you sure you want to remove pyFormex? yes/NO: ")
     if s == 'yes':
         print("Removing pyformex tree: %s" % pyformexdir)
-        print("Removing other files: %s" % other_files)
         utils.removeTree(pyformexdir)
-        for f in other_files:
-            if os.path.exists(f):
-                print("Removing %s" % f)
-                try:
-                    os.remove(f)
-                except:
-                    print("Could not remove %s" % f)
-            else:
-                print("No such file: %s" % f)
+
+        if other == '':
+            print("Removing other files: %s" % other_files)
+            for f in other_files:
+                if os.path.exists(f):
+                    print("Removing %s" % f)
+                    try:
+                        os.remove(f)
+                    except:
+                        print("Could not remove %s" % f)
+                else:
+                    print("No such file: %s" % f)
 
         print("\nBye, bye! I won't be back until you reinstall me!")
     elif s.startswith('y') or s.startswith('Y'):
@@ -352,6 +391,8 @@ def run_doctest(modules):
         numpy.set_printoptions(precision=2,suppress=True)
     else:
         numpy.set_printoptions(precision=2,suppress=True,legacy='1.13')
+    from pyformex import arraytools
+    numpy.set_string_function(arraytools.array2str)
     if not modules:
         modules = ['all']
     for mod in modules:
@@ -445,7 +486,7 @@ def loadUserConfig():
     userprefs = list(filter(os.path.exists, userprefs))
 
     if pf.options.config:
-        userprefs.append(utils.tildeExpand(pf.options.config))
+        userprefs.append(os.path.expanduser(pf.options.config))
 
     if len(userprefs) == 0:
         # We should always have a place to store the user preferences
@@ -564,12 +605,16 @@ def parseArguments(args):
        )
     MO("--debug",
        action="store", dest="debug", default='',
-       help="Display debugging information to sys.stdout. The value is a comma-separated list of (case-insensitive) strings corresponding with the attributes of the DebugLevels class. The individual values are OR-ed together to produce a final debug value. The special value 'all' can be used to switch on all debug info.",
+       help="Display debugging information to sys.stdout. The value is a comma-separated list of (case-insensitive) debgu items. Use option --debugitems to list  them. The special value 'all' can be used to switch on all debug info.",
        )
     MO("--debuglevel",
        action="store", dest="debuglevel", type=int, default=0,
        help="Display debugging info to sys.stdout. The value is an int with the bits of the requested debug levels set. A value of -1 switches on all debug info. If this option is used, it overrides the --debug option.",
        )
+    MO("--debugitems",
+       action="store_true", dest="debugitems", default=False,
+       help="Show all available debug items. Each of these can be used with the -debug option.",
+       )
     MO("--mesa",
        action="store_true", dest="mesa", default=False,
        help="Force the use of software 3D rendering through the mesa libs. The default is to use hardware accelerated rendering whenever possible. This flag can be useful when running pyFormex remotely on another host. The hardware accelerated version will not work over remote X.",
@@ -594,10 +639,6 @@ def parseArguments(args):
        action="store", dest="vtk", default='default',
        help="Specify which version of python-vtk to use in vtk_itf plugin. The value can be one of: 'standard', 'light', or 'default'. 'standard' is the version as distributed from python-vtk. 'light' is the trimmed vtk6 version as distributed with pyFormex.",
        )
-    MO("--newviewports",
-       action="store_true", dest="newviewports", default=False,
-       help="Use the new multiple viewport canvas implementation. This is an experimental feature only intended for developers.",
-       )
     MO("--testcamera",
        action="store_true", dest="testcamera", default=False,
        help="Print camera settings whenever they change.",
@@ -610,6 +651,10 @@ def parseArguments(args):
        action="store_true", dest="fastnurbs", default=False,
        help="Test C library nurbs drawing: only for developers!",
        )
+    MO("--pathlib",
+       action="store_true", dest="pathlib", default=False,
+       help="In Python2 version, use pathlib2 library if installed. This is only for development and testing purposes.",
+       )
     MO("--bindings",
        action="store", dest="bindings", default=None,
        help="Override the configuration setting for the Qt bindings to be used. Available bindings are 'pyside', 'pyside2', 'pyqt4', 'pyqt5'. A value 'any' may be given to let pyFormex find out which are available and use one of these.",
@@ -726,6 +771,10 @@ def processReportOptions():
         print('\n'.join(list_modules(pf.options.listmodules)))
         ret = True
 
+    if pf.options.debugitems:
+        print(pf.debugItems())
+        ret = True
+
     if pf.options.pytest is not None:
         run_pytest(pf.options.pytest)
         ret = True
@@ -878,6 +927,12 @@ def run(args=[]):
     if processReportOptions2():
         return
 
+    if pf.options.pathlib and pf.PY2:
+        import pathlib2 as pathlib
+        from pathlib2 import Path
+        pf.Path = Path
+        print(pf.Path)
+
     ## Process options that override the config ##
 
     if pf.options.bindings is not None:
