@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -34,21 +34,19 @@ the current OpenGL framework in pyFormex.
 """
 from __future__ import absolute_import, division, print_function
 
+import numpy as np
+import OpenGL.GL as GL
 
 from pyformex.opengl.matrix import Matrix4, Vector4
 from pyformex import arraytools as at
 from pyformex.coords import Coords
 from pyformex.plugins.nurbs import Coords4
-
-import numpy as np
+from pyformex.config import Config
 
 #
 # DEVS: collect all GL calls here, so we can easily move them somewhere else
 #
 
-import OpenGL.GL as GL
-
-
 def gl_projection():
     """Get the OpenGL projection matrix"""
     return GL.glGetDoublev(GL.GL_PROJECTION_MATRIX)
@@ -155,58 +153,6 @@ def pick_matrix(x, y, w, h, viewport):
     return m
 
 
-
-
-built_in_views = {
-    'front': (0., 0., 0.),
-    'back': (180., 0., 0.),
-    'right': (90., 0., 0.),
-    'left': (270., 0., 0.),
-    'top': (0., 90., 0.),
-    'bottom': (0., -90., 0.),
-    'iso0': (45., 45., 0.),
-    'iso1': (45., 135., 0.),
-    'iso2': (45., 225., 0.),
-    'iso3': (45., 315., 0.),
-    'iso4': (-45., 45., 0.),
-    'iso5': (-45., 135., 0.),
-    'iso6': (-45., 225., 0.),
-    'iso7': (-45., 315., 0.),
-    }
-
-
-
-
-
-
-class ViewAngles(dict):
-    """A dict to keep named camera angle settings.
-
-    This class keeps a dictionary of named angle settings. Each value is
-    a tuple of (longitude, latitude, twist) camera angles.
-    This is a static class which should not need to be instantiated.
-
-    There are seven predefined values: six for looking along global
-    coordinate axes, one isometric view.
-    """
-
-    def __init__(self,data = built_in_views):
-       dict.__init__(self, data)
-       self['iso'] = self['iso0']
-
-
-    def get(self, name):
-        """Get the angles for a named view.
-
-        Returns a tuple of angles (longitude, latitude, twist) if the
-        named view was defined, or None otherwise
-        """
-        return dict.get(self, name, None)
-
-
-view_angles = ViewAngles()
-
-
 class Camera(object):
     """A camera for 3D model rendering.
 
@@ -302,32 +248,58 @@ class Camera(object):
     #    and afterwards back to Modelview should be performed.
 
 
-    def __init__(self,focus=[0., 0., 0.],angles=[0., 0., 0.],dist=1.):
+    def __init__(self, focus=(0.,0.,0.), angles=(0.,0.,0.), dist=1.,
+                 fovy=45., aspect=4./3., clip=(0.01,100.), perspective=True,
+                 area=(0.,0.,1.,1.),
+                 locked=False, keep_aspect=True, tracking=False,
+    ):
         """Create a new camera.
 
         The default camera is positioned at (0.,0.,1.) looking along the -z
         axis in the direction of the point (0.,0.,0.) and with the upvector
         in the direction of the y-axis.
         """
-        self.locked = False
-
-        self._modelview = Matrix4()
+        self.locked = locked     # this needs to be before focus setter!
         self.focus = focus
         self.dist = dist
-        self.viewChanged = True
-
-        self._projection = Matrix4()
-        self._perspective = True
-        self.lensChanged = True
-
-        self.setModelview(angles=angles)
-        self.setLens(45., 4./3.)
-        self.setClip(0.1, 10.)
-        self.area = None
-        self.resetArea()
         self.keep_aspect = True
         self.tracking = False
+
+        self._modelview = Matrix4()
+        self._projection = Matrix4()
         self.p = self.v = None
+        self.viewChanged = True
+        self.lensChanged = True
+
+        self._perspective = perspective
+        self.setAngles(angles)
+        self.setLens(fovy, aspect)
+        self.setClip(*clip)
+        self.area = None
+        self.setArea(*area,relative=False)
+
+
+    @property
+    def settings(self):
+        """Dict to allow save/load of camera
+
+        This dict contains all data that allow save and restore
+        of the camera to exactly the same settings (on the same
+        size of Canvas).
+        """
+        return {
+            'focus' : self.focus.tolist(),
+            'angles': self.angles,
+            'dist': self.dist,
+            'fovy': self.fovy,
+            'aspect': self.aspect,
+            'clip': (self.near, self.far),
+            'area': self.area.ravel().tolist(),
+            'perspective' : self.perspective,
+            'locked': self.locked,
+            'tracking': self.tracking,
+            'keep_aspect': self.keep_aspect,
+            }
 
 
     @property
@@ -454,6 +426,19 @@ class Camera(object):
         return self.modelview.rot
 
 
+    @property
+    def angles(self):
+        """Return the camera angles.
+
+        Returns a tuple (longitude, latitude, twist) in local camera axes.
+        """
+        R = self.modelview.rot.T
+        R = R[[2,0,1]]
+        R = R[:,[2,0,1]]
+        a = [ at.Float(angle) for angle in at.cardanAngles(R) ]
+        return ( a[2], -a[1], a[0] )
+
+
     @property
     def upvector(self):
         """Return the camera up vector"""
@@ -470,21 +455,26 @@ class Camera(object):
         return self.modelview.rot[:, 2].reshape((3,))
 
 
-    def setAngles(self, angles):
+    def setAngles(self, angles, axes=None):
         """Set the rotation angles.
 
-        angles is either:
+        Parameters
+        ----------
+        angles: tuple of floats
+            A tuple of three angles (long,lat,twist) in degrees.
+            A value None is also accepted, but has no effect.
 
-        - a tuple of angles (long,lat,twist)
-        - a named view corresponding to angles in view_angles
-        - None
+        axes: if specified, any number of rotations can be applied.
         """
         if not self.locked:
-            if isinstance(angles, str):
-                angles = view_angles.get(angles)
             if angles is None:
                 return
-            self.setModelview(angles=angles)
+            if isinstance(angles, str):
+                raise ValueError("Invalid value for camera angles: %s" % angles)
+                #angles = view_angles.get(angles)
+            if axes is None:
+                axes = ((0., -1., 0.), (1., 0., 0.), (0., 0., -1.))
+            self.setModelview(angles=list(zip(angles,axes))[::-1])
 
 
     @property
@@ -520,6 +510,7 @@ class Camera(object):
   Eye: %s
   Focus: %s
   Distance: %s
+  Angles: %s
   Axis: %s
   UpVector: %s
   Rotation Matrix:
@@ -528,7 +519,7 @@ class Camera(object):
   Aspect Ratio: %s
   Area: %s, %s
   Near/Far Clip: %s, %s
-""" % (self.eye, self.focus, self.dist, self.axis, self.upvector, self.rot, self.fovy, self.aspect, self.area[0], self.area[1], self.near, self.far)
+""" % (self.eye, self.focus, self.dist, self.angles, self.axis, self.upvector, self.rot, self.fovy, self.aspect, self.area[0], self.area[1], self.near, self.far)
 
 
     def dolly(self, val):
@@ -757,7 +748,7 @@ class Camera(object):
         """Enable/disable coordinate tracking using the camera"""
         if onoff:
             self.tracking = True
-            #self.set3DMatrices()
+            #self.set3Datrices()
         else:
             self.tracking = False
 
@@ -924,10 +915,11 @@ class Camera(object):
           Modelview transformation. It will be set as the current camera
           Modelview matrix.
 
-        - else, if `angles` is specified, it is a sequence of the three
-          camera angles (latitude, longitude and twist). The camera
-          Modelview matrix is set from the current camera focus,
-          the current camera distance, and the specified angles.
+        - else, if `angles` is specified, it is a sequence of tuples
+          (angle, axis) each of which define a rotation of the camera
+          around an axis through the focus point.
+          The camera Modelview matrix is set from the current camera focus,
+          the current camera distance, and the specified angles/axes.
           This option is typically used to change the viewing direction
           of the camera, while keeping the focus point and camera distance.
 
@@ -945,16 +937,17 @@ class Camera(object):
         if self.locked:
             return
 
-        if m is None and (self.viewChanged or angles is not None):
+        if m is None and angles is not None:
             m = Matrix4()
             m.translate([0, 0, -self.dist])
-            if angles is None:
-                m.rotate(self._modelview.rot)
-            else:
-                long, lat, twist = angles
-                m.rotate(-twist % 360, [0.0, 0.0, 1.0])
-                m.rotate(lat % 360, [1.0, 0.0, 0.0])
-                m.rotate(-long % 360, [0.0, 1.0, 0.0])
+            #print(list(angles))
+            for angle, axis in angles:
+                m.rotate(angle,axis)
+            m.translate(-self.focus)
+        elif m is None and self.viewChanged:
+            m = Matrix4()
+            m.translate([0, 0, -self.dist])
+            m.rotate(self._modelview.rot)
             m.translate(-self.focus)
 
         if m is not None:
@@ -1132,15 +1125,43 @@ class Camera(object):
             return inside
 
 
+    def config(self):
+        """Return a Config with the settings to be saved for a restore"""
+        from pyformex.plugins.saveload import dict2Config
+        C = dict2Config(self.settings)
+        return C
+
+
+    def save(self,filename):
+        """Save the camera settings to file"""
+        C = self.config()
+        C.write(filename,header="#Camera settings saved from pyFormex\n",trailer="#End\n")
+
+
+    def loadConfig(self,config):
+        """Load the camera settings from a Config or dict"""
+        from pyformex.gui import toolbar
+        self.__init__(**config)
+        # Since this might have changed the perspective state
+        # of the current camera, updat the gui perspective button
+        toolbar.updatePerspectiveButton()
+
+    apply = loadConfig
+
+
+    def load(self,filename):
+        """Load the camera settings from file"""
+        config = Config()
+        try:
+            config.read(filename)
+        except:
+            raise ValueError("Invalid Camera save file: %s" % filename)
+        self.loadConfig(config)
+
+
 #################################
     # Compatibility: should be removed after complete conversion
 
-    def getGLmodelview(self):
-        return Matrix4(GL.glGetDoublev(GL.GL_MODELVIEW_MATRIX))
-
-    def getGLprojection(self):
-        return Matrix4(GL.glGetDoublev(GL.GL_PROJECTION_MATRIX))
-
 
     loadModelView = loadModelview
     def saveModelView(self):
@@ -1148,12 +1169,6 @@ class Camera(object):
     def set3DMatrices(self):
         self.loadProjection()
         self.loadModelView()
-        #print("MODELVIEW",self.modelview)
-        #print("MODELVIEW",self.getGLmodelview())
-        #print("PROJECTION",self.projection)
-        #print("PROJECTION",self.getGLprojection())
-
-
 
 
     def setPerspective(self,on=True):
