@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -46,6 +46,7 @@ from .drawable import Actor
 from .camera import Camera
 from .renderer import Renderer
 from .scene import Scene, ItemList
+from pyformex.gui import views
 
 
 def glVersion(mode='all'):
@@ -598,13 +599,26 @@ class Canvas(object):
         self.rendermode = None
         self.setRenderMode(pf.cfg['draw/rendermode'])
         self.resetLighting()
-        self.view_angles = views.ViewAngles()
         self.cursor = None
+        self._focus = None
         self.focus = False
         pf.debug("Canvas Setting:\n%s"% self.settings, pf.DEBUG.DRAW)
         self.makeCurrent()  # we need correct OpenGL context
 
 
+    @property
+    def focus(self):
+        return self._focus is not None
+
+    @focus.setter
+    def focus(self,onoff):
+        if onoff:
+            self.add_focus_rectangle()
+        else:
+            self.remove_focus_rectangle()
+        self.updateGL()
+
+
     @property
     def actors(self):
         return self.scene.actors
@@ -889,7 +903,7 @@ class Canvas(object):
         if self.triade:
             self.removeTriade()
         if triade:
-            from pyformex.opengl.draw import draw
+            from pyformex.gui.draw import draw
             self.triade = None
             x, y, w, h = GL.glGetIntegerv(GL.GL_VIEWPORT)
             if pos[0] == 'l':
@@ -1105,12 +1119,11 @@ class Canvas(object):
         glSmooth()
         glFill()
 
-        # draw the focus rectangle if more than one viewport
-        if len(pf.GUI.viewports.all) > 1 and pf.cfg['gui/showfocus']:
-            if self.hasFocus(): # QT focus
-                self.draw_focus_rectangle(0, color=colors.blue)
-            if self.focus:      # pyFormex DRAW focus
-                self.draw_focus_rectangle(2, color=colors.red)
+        # # Set correct focus rectangle status
+        # if self.focus:
+        #     if not self._focus in self.scene.backgrounds:
+        #         self.addAny(self._focus)
+
 
         # draw the highlighted actors
         pf.debug("draw highlights", pf.DEBUG.DRAW)
@@ -1212,7 +1225,7 @@ class Canvas(object):
         self.scene.bbox = bbox
 
 
-    def setCamera(self,bbox=None,angles=None):
+    def setCamera(self,bbox=None,angles=None,orient='xy'):
         """Sets the camera looking under angles at bbox.
 
         This function sets the camera parameters to view the specified
@@ -1259,12 +1272,21 @@ class Canvas(object):
 
         # set camera angles
         if isinstance(angles, str):
-            angles = self.view_angles.get(angles)
+            #print("canvas0: %s (%s)" % (angles, orient))
+            angles, orient = views.getAngles(angles)
+            #print("canvas1: %s (%s)" % (angles, orient))
         if angles is not None:
+            #print("canvas2: %s (%s)" % (angles, orient))
             try:
-                self.camera.setAngles(angles)
+                axes = views.getAngleAxes(orient)
+                #print("canvas3: %s" % str(axes))
+                if orient == 'xz':
+                    angles = angles + (-90.,)
+                    axes = axes + ((1.,0.,0.),)
+                    #print("canvas4: %s (%s)" % (angles, axes))
+                self.camera.setAngles(angles,axes)
             except:
-                raise ValueError('Invalid view angles specified')
+                raise ValueError("Invalid view angles specified: %s %s" % (angles,orient))
 
         # set camera distance and clipping planes
         if bbox is not None:
@@ -1401,14 +1423,21 @@ class Canvas(object):
         pass
 
 
-    def draw_focus_rectangle(self,ofs=0,color=colors.pyformex_pink):
-        """Draw the focus rectangle.
-
-        """
+    def add_focus_rectangle(self,color=colors.pyformex_pink):
+        """Draw the focus rectangle."""
         from . import decors
-        #w, h = self.width(), self.height()
-        self._focus = decors.Grid2D(-1.,-1.,1.,1., color=color, linewidth=2, rendertype=3)
-        self.addAny(self._focus)
+        if self._focus is None:
+            self._focus = decors.Grid2D(-1.,-1.,1.,1., color=color, linewidth=2, rendertype=3)
+            self._focus.sticky = True
+        if self._focus not in self.scene.backgrounds:
+            self.addAny(self._focus)
+            self.update()
+
+
+    def remove_focus_rectangle(self):
+        if self._focus:
+            self.removeAny(self._focus)
+            self._focus = None
 
 
     def draw_cursor(self, x, y):
