@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -26,13 +26,14 @@
 """
 from __future__ import absolute_import, division, print_function
 
+import numpy as np
+from numpy import int32,float32
+from OpenGL import GL
+from OpenGL.arrays.vbo import VBO
 
 import pyformex as pf
 from pyformex.opengl.sanitize import saneFloat, saneLineStipple, saneColorSet
 from pyformex.opengl import colors
-from OpenGL import GL
-from OpenGL.arrays.vbo import VBO
-#from pyformex.opengl.shader import Shader
 from pyformex.opengl.texture import Texture
 from pyformex.attributes import Attributes
 from pyformex.formex import Formex
@@ -41,8 +42,6 @@ from pyformex.elements import elementType, _default_eltype
 from pyformex import geomtools as gt
 from pyformex import arraytools as at
 from pyformex import utils
-import numpy as np
-from numpy import int32,float32
 
 
 ### Drawable Objects ###############################################
@@ -210,7 +209,7 @@ class Drawable(Attributes):
             elif self.color.ndim == 2:
                 self.useObjectColor = 0
                 self.vertexColor = at.multiplex(self.color, self.object.nplex(),axis=-2,warn=False)
-                #pf.debug("Multiplexing colors: %s -> %s " % (self.color.shape, self.vertexColor.shape),pf.DEBUG.OPENGL2)
+                #pf.debug("Multiplexing colors: %s -> %s " % (self.color.shape, self.vertexColor.shape),pf.DEBUG.OPENGL)
             elif self.color.ndim == 3:
                 self.useObjectColor = 0
                 self.vertexColor = self.color
@@ -1025,8 +1024,8 @@ class Actor(BaseActor):
             elif color.startswith('fld:'):
                 # get colors from a named field
                 fld = self.object.getField(color[4:])
-                if fld and fld.fldtype == 'node':
-                    color = fld.data
+                if fld:
+                    color = fld.convert('elemn').data
                     colormap = None
                 else:
                     pf.warning("Could not set color from field %s" % color)
