@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -37,7 +37,7 @@ class ItemList(list):
     This is used to collect the Actors, Decorations and Annotations
     in a scene.
     Currently the implementation does not check that the objects are of
-    the proper type.
+    the proper type or are not occurring multiple times.
     """
 
     def __init__(self, scene):
@@ -219,7 +219,7 @@ class Scene(object):
                 #print(type(actor))
                 self.decorations.delete(actor)
             elif actor.rendertype == 3:
-                self.backgounds.delete(actor)
+                self.backgrounds.delete(actor)
             else:
                 self.actors.delete(actor)
             self._bbox = None
