@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -28,6 +28,10 @@ It is dependent on freetype and the Python bindings freetype-py.
 """
 from __future__ import absolute_import, division, print_function
 
+from pyformex import Path
+from OpenGL import GL
+import numpy as np
+
 import pyformex as pf
 from pyformex import utils
 from pyformex import freetype as ft
@@ -36,11 +40,7 @@ from pyformex.coords import Coords
 from pyformex.formex import Formex
 from pyformex.opengl.drawable import Actor
 from pyformex.opengl.texture import Texture
-
-from OpenGL import GL
-
-import numpy as np
-
+from pyformex.plugins.imagearray import numpy2qimage
 
 class FontTexture(Texture):
     """A Texture class for text rendering.
@@ -50,15 +50,21 @@ class FontTexture(Texture):
     on geometry. In the current implementation only the characters with
     ASCII ordinal in the range 32..127 are put in the texture.
 
-    Parameters:
-
-    - `filename`: path string. The font to be used. It should be the
-      full file path of an existing monospace font on the system.
-    - `size`: float: intended font heigth. The actual height might
-      differ a bit.
-
+    Parameters
+    ----------
+    filename: str or Path
+        The name of the font file to be used. It should be the
+        full path of an existing monospace font on the system.
+    size: float
+        Intended font height. The actual height might differ a bit.
+    saveas: str or Path, optional
+        The name of an image file. If specified, the texture will
+        be saved as an image on this file.
     """
-    def __init__(self,filename,size):
+    # This is how we store the 96 character textures
+    layout = (3,32)
+
+    def __init__(self,filename,size,save=False):
         """Initialize a FontTexture"""
 
         pf.debug("Creating FontTexture(%s) in size %s" % (filename,size),pf.DEBUG.FONT)
@@ -79,19 +85,34 @@ class FontTexture(Texture):
             width     = max( width, bitmap.width )
             ascender  = max( ascender, face.glyph.bitmap_top )
             descender = max( descender, bitmap.rows-face.glyph.bitmap_top )
+            #print("chr %s; ord %s; width %s, ascender %s, descender %s" % (
+            #    chr(c), c, bitmap.width, face.glyph.bitmap_top, bitmap.rows-face.glyph.bitmap_top))
         height = ascender+descender
+        #print("width %s, ascender %s, descender %s, height %s" % (
+        #    width, ascender, descender, height ))
 
         # Generate texture data
         self.width, self.height = width,height
-        image = np.zeros((height*6, width*16), dtype=np.ubyte)
-        for j in range(6):
-            for i in range(16):
-                face.load_char(chr(32+j*16+i), ft.FT_LOAD_RENDER | ft.FT_LOAD_FORCE_AUTOHINT )
+        nrows, ncols = FontTexture.layout
+        image = np.zeros((height*nrows, width*ncols), dtype=np.ubyte)
+        for j in range(nrows):
+            for i in range(ncols):
+                k = 32+j*ncols+i
+                face.load_char(chr(k), ft.FT_LOAD_RENDER | ft.FT_LOAD_FORCE_AUTOHINT )
                 bitmap = face.glyph.bitmap
                 x = i*width  + face.glyph.bitmap_left
                 y = j*height + ascender - face.glyph.bitmap_top
+                #print("%s %s:  %s  %s, %s" % (k,chr(k),face.glyph.bitmap_left,x,y))
                 image[y:y+bitmap.rows,x:x+bitmap.width].flat = bitmap.buffer
 
+        if save and Path:
+            stem = Path(filename).stem
+            fn = Path(pf.cfg['pyformexdir']) / 'fonts' / (stem+'.%sx%s.png'%(nrows,ncols))
+            if not fn.exists():
+                im = numpy2qimage(image)
+                print("Saving Font Texture: %s" % fn)
+                im.save(str(fn))
+
         #print(image.shape,image.dtype)
         Texture.__init__(self,image,format=GL.GL_ALPHA,texformat=GL.GL_ALPHA)
 
@@ -127,10 +148,11 @@ class FontTexture(Texture):
         (ntext,4,2) holding the texture coordinates needed to display
         the given text on a grid of quad4 elements.
         """
+        nrows,ncols = FontTexture.layout
         if at.isInt(char):
-            dx,dy = 1./16,1./6
+            dx,dy = 1./ncols, 1./nrows
             k = char-32
-            x0,y0 = (k%16)*dx, (k//16)*dy
+            x0,y0 = (k%ncols)*dx, (k//ncols)*dy
             return (x0,y0+dy), (x0+dx,y0+dy), (x0+dx,y0), (x0,y0)
 
         else:
