@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -310,32 +310,30 @@ def sliceIt():
 
     nslice = sliceData('nslice')
 
-    pf.GUI.setBusy(True)
-    h = [sliceBranch(S, cp, hl[2*i], hl[2*i+1], cl[i], nslice[i]) for i in range(3) ]
+    with busyCursor():
+        h = [sliceBranch(S, cp, hl[2*i], hl[2*i+1], cl[i], nslice[i]) for i in range(3) ]
 
-    ##corrections of some points of the cross-PolyLines because sometimes, due to the cutting, different pts appear at the connections between semi-branches (0,1) and branches (at center-splines top and bottom)
-    ##merge the points between half branches
-    for ibr in [0, 1, 2]:
-        pfl0=array([hi.coords[[0, -1]] for hi in h[ibr][0]])#point first and last of each half cross section
-        pfl1=array([hi.coords[[0, -1]] for hi in h[ibr][1]])
-        temp=(pfl0+ pfl1)*0.5
-        for i in range(len(temp)):h[ibr][0][i].coords[[0, -1]]=h[ibr][1][i].coords[[0, -1]]=temp[i]
+        ##corrections of some points of the cross-PolyLines because sometimes, due to the cutting, different pts appear at the connections between semi-branches (0,1) and branches (at center-splines top and bottom)
+        ##merge the points between half branches
+        for ibr in [0, 1, 2]:
+            pfl0=array([hi.coords[[0, -1]] for hi in h[ibr][0]])#point first and last of each half cross section
+            pfl1=array([hi.coords[[0, -1]] for hi in h[ibr][1]])
+            temp=(pfl0+ pfl1)*0.5
+            for i in range(len(temp)):h[ibr][0][i].coords[[0, -1]]=h[ibr][1][i].coords[[0, -1]]=temp[i]
 
-    ##mergethe 3 points on the top  and the 3 points on the bottom (at the bif center)
-    t0= array([ h[ibr][sbr][0].coords[0] for ibr in [0, 1, 2] for sbr in [0, 1]]).mean(axis=0)
-    t1= array([ h[ibr][sbr][0].coords[-1] for ibr in [0, 1, 2] for sbr in [0, 1]]).mean(axis=0)
-    for ibr in [0, 1, 2]:
-        for sbr in [0, 1]:
-            h[ibr][sbr][0].coords[0]=t0
-            h[ibr][sbr][0].coords[-1]=t1
-
-    export({'cross_sections':olist.flatten(h)})
-    export({'cross_sections_backup':olist.flatten(h)})#to recover from overwriting when creating the outer cross sections
-    clear()
-    drawCenterLines()
-    drawCrossSections()
-    pf.GUI.setBusy(False)
+        ##mergethe 3 points on the top  and the 3 points on the bottom (at the bif center)
+        t0= array([ h[ibr][sbr][0].coords[0] for ibr in [0, 1, 2] for sbr in [0, 1]]).mean(axis=0)
+        t1= array([ h[ibr][sbr][0].coords[-1] for ibr in [0, 1, 2] for sbr in [0, 1]]).mean(axis=0)
+        for ibr in [0, 1, 2]:
+            for sbr in [0, 1]:
+                h[ibr][sbr][0].coords[0]=t0
+                h[ibr][sbr][0].coords[-1]=t1
 
+        export({'cross_sections':olist.flatten(h)})
+        export({'cross_sections_backup':olist.flatten(h)})#to recover from overwriting when creating the outer cross sections
+        clear()
+        drawCenterLines()
+        drawCrossSections()
 
 
 def splineIt():
@@ -666,14 +664,13 @@ def sweepingMesher():
     longr, longbl = eval(res['s_radial']), eval(res['s_boundary'])
 
     # Create the meshes
-    pf.GUI.setBusy(True)
-    Vmesh, Smesh=[], []
-    bifbranches = named('seededBif')
-    for branch in bifbranches:
-        vmesh, smesh=meshBranch(branch[0], branch[1], longp, longc, longr, longbl)
-        Vmesh.extend(vmesh)
-        Smesh.extend(smesh)
-    pf.GUI.setBusy(False)
+    with busyCursor():
+        Vmesh, Smesh=[], []
+        bifbranches = named('seededBif')
+        for branch in bifbranches:
+            vmesh, smesh=meshBranch(branch[0], branch[1], longp, longc, longr, longbl)
+            Vmesh.extend(vmesh)
+            Smesh.extend(smesh)
 
     if domain == 'Lumen':
         ## m=[]
@@ -701,16 +698,15 @@ def writeMeshFile():
     if fn:
         ftype = utils.fileTypeFromExt(fn)
         print("Exporting surface model to %s (%s)" % (fn, ftype.upper()))
-        pf.GUI.setBusy()
-        if ftype == 'pgf':
-            writeGeomFile(fn,[cfdmesh],sep=' ',mode='w',shortlines=False)
-        if ftype == 'inp':
-            from pyformex.plugins.fe_abq import exportMesh
-            exportMesh(fn,cfdmesh,'C3D8R')
-        if ftype == 'neu':
-            from pyformex.plugins.neu_exp import write_neu
-            write_neu(fil=fn, mesh=cfdmesh, bcsets=None, heading='generated with pyFormex')
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            if ftype == 'pgf':
+                writeGeomFile(fn,[cfdmesh],sep=' ',mode='w',shortlines=False)
+            if ftype == 'inp':
+                from pyformex.plugins.fe_abq import exportMesh
+                exportMesh(fn,cfdmesh,'C3D8R')
+            if ftype == 'neu':
+                from pyformex.plugins.neu_exp import write_neu
+                write_neu(fil=fn, mesh=cfdmesh, bcsets=None, heading='generated with pyFormex')
 
 
 def surfMesh():
@@ -787,10 +783,9 @@ def centerlines():
         divideControlLines()
         hl = named('control_lines')
 
-    pf.GUI.setBusy(True)
-    cl = [ centerline2D(S, hl[2*i], hl[2*i+1]) for i in range(3) ]
-    cl = [ extendedCenterline(cl[i], hl[2*i], hl[2*i+1], cp) for i in range(3) ]
-    pf.GUI.setBusy(False)
+    with busyCursor():
+        cl = [ centerline2D(S, hl[2*i], hl[2*i+1]) for i in range(3) ]
+        cl = [ extendedCenterline(cl[i], hl[2*i], hl[2*i+1], cp) for i in range(3) ]
 
     export({'center_lines':cl})
     #if drawOption('visual'):
