@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -80,7 +80,7 @@ def detect(trypaths=None):
 def check(trypaths=None):
     """Warn the user that calpy was not found."""
     if pf.PY3:
-        # Calpy is not ready for Python3 !!!
+        pf.warning("Calpy, can currently not yet be run from Python3.")
         return False
 
     if calpy_path is None:
