@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -32,7 +32,7 @@ from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex.gui.widgets import simpleInputItem as _I, InputDialog as Dialog
-from pyformex.utils import stuur
+from pyformex.arraytools import stuur
 
 dialog = None
 
