@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -33,6 +33,7 @@ from __future__ import absolute_import, division, print_function
 # DEVS: Try to do this without importing from pyformex
 #
 
+import os
 import re
 import numpy as np
 from pyformex import utils
@@ -357,8 +358,8 @@ def readInput(fn):
     - `elid`: int (nelems,) array: element numbers; default is arange(nelems)
     """
     global line, part, log, model
-    dirname, basename, ext = utils.splitFilename(fn,['.inp'])
-    logname = utils.buildFilename(dirname,basename+'_ccxinp.log')
+    filename, ext = os.path.splitext(fn)
+    logname = filename + '_ccxinp.log'
     model = InpModel()
     model.parts = []
     startPart('DEFAULT')
