@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -32,18 +32,22 @@ but special cases may be created for handling plane curves.
 from __future__ import absolute_import, division, print_function
 
 import math
+import numpy as np
 
 import pyformex as pf
-from pyformex.coords import *
+from pyformex import arraytools as at
+from pyformex.coords import Coords
 from pyformex.coordsys import CoordSys
 from pyformex.geometry import Geometry
 from pyformex.formex import Formex, connect
 from pyformex.mesh import Mesh
 from pyformex import geomtools as gt
-from pyformex import arraytools
 from pyformex import utils
 from pyformex.varray import Varray
 
+# TODO: Remove this
+from pyformex.coords import *
+
 ##############################################################################
 
 class Curve(Geometry):
@@ -272,7 +276,7 @@ class Curve(Geometry):
         if split is None:
             split = arange(1, self.nparts)
         else:
-            if arraytools.isInt(split):
+            if at.isInt(split):
                 split = [split]
             split = unique(split)
         if len(split) == 0:
@@ -320,6 +324,18 @@ class Curve(Geometry):
           pre-approximation. This pre-approximation is currently
           required to compute curve lengths.
 
+        Examples
+        --------
+        >>> PL = PolyLine([[0,0,0],[1,0,0],[1,1,0]])
+        >>> print(PL.atApproximate(nseg=6))
+        [ 0.    0.33  0.67  1.    1.33  1.67  2.  ]
+        >>> print(PL.atApproximate(ndiv=3))
+        [ 0.    0.33  0.67  1.    1.33  1.67  2.  ]
+        >>> print(PL.atApproximate(ndiv=(2,4)))
+        [ 0.    0.5   1.    1.25  1.5   1.75  2.  ]
+        >>> print(PL.atApproximate(ndiv=(2,)))
+        [ 0.   0.5  1. ]
+
         """
         if ndiv is not None:
             if isInt(ndiv):
@@ -333,7 +349,7 @@ class Curve(Geometry):
             at = S.atLength(nseg) / npre
 
         elif ndiv is not None:
-            at = concatenate([[ 0. ]] + [ i + unitDivisor(n,1) for i,n in enumerate(ndiv) ])
+            at = concatenate([[ 0. ]] + [ i + unitDivisor(n)[1:] for i,n in enumerate(ndiv) ])
 
         else:
             if nseg is None:
@@ -572,11 +588,11 @@ class Curve(Geometry):
         coords: Coords object
             The Coords object to be copied, possibly scaled and positioned
             at each point of the curve.
-        origin: float array-like (3,)
+        origin: float :term:`array_like` (3,)
             The local origin in the Coords. This is the point that will
             be positioned at the curve's points. It is also the center of
             scaling if `scale` is provided.
-        scale: float array-like, optional
+        scale: float :term:`array_like`, optional
             If provided, it should have the shape (npts,3). For each point
             of the curve, it specifies the three scaling factors to be used
             in the three coordinate directions on the `coords` for the copy
@@ -727,7 +743,7 @@ class PolyLine(Curve):
         .. warning:: This method changes the PolyLine inplace.
         """
         if not self.closed:
-            d = arraytools.length(self.coords[0]-self.coords[-1])
+            d = at.length(self.coords[0]-self.coords[-1])
             if d < atol:
                 self.coords = self.coords[:-1]
                 ret = True
@@ -1504,12 +1520,12 @@ class BezierSpline(Curve):
 
     Parameters:
 
-    - `coords` : array_like (npoints,3)
+    - `coords` : :term:`array_like` (npoints,3)
       The points that are on the curve. For an open curve, npoints=nparts+1,
       for a closed curve, npoints = nparts.
       If not specified, the on-curve points should be included in the
       `control` argument.
-    - `deriv` : array_like (npoints,3) or (2,3) or a list of 2 values
+    - `deriv` : :term:`array_like` (npoints,3) or (2,3) or a list of 2 values
       one of which can be None and the other is a shape(3,) arraylike.
       If specified, it gives the direction of the curve at all points or at
       the endpoints only for a shape (2,3) array or only at one of the
@@ -2013,12 +2029,13 @@ Most likely because 'python-scipy' is not installed on your system.""")
 class Contour(Curve):
     """A class for storing a contour.
 
-    The contour class stores a continuous (usually closed) curve which consists of
-    a sequence of strokes, each stroke either being a straight segment or a quadratic
-    or cubic Bezier curve. A stroke is thus defined by 2, 3 or 4 points.
-    The contour is defined by a list of points and a Varray of element connectivity.
-    This format is well suited to store contours of scalable fonts. The contours are
-    in that case usually 2D.
+    The contour class stores a continuous (usually closed) curve which consists
+    of a sequence of strokes, each stroke either being a straight segment or a
+    quadratic or cubic Bezier curve. A stroke is thus defined by 2, 3 or 4
+    points.
+    The contour is defined by a list of points and a Varray of element
+    connectivity. This format is well suited to store contours of scalable
+    fonts. The contours are in that case usually 2D.
     """
     def __init__(self,coords,elems):
         Geometry.__init__(self)
