@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -30,23 +30,23 @@ on a plane with any orientation in space. The constructed geometry always
 has 3D coordinates in the global cartesian coordinate system.
 """
 from __future__ import absolute_import, division, print_function
-from pyformex import zip
 
 from pyformex.geomtools import triangleCircumCircle
 from pyformex.plugins.curve import *
 from pyformex.plugins.nurbs import *
 from pyformex.simple import circle
 from pyformex.plugins import objects
-from pyformex.plugins.geometry_menu import autoname, autoName, geomList
+from pyformex.plugins.geometry_menu import geomList
 from pyformex.gui.draw import *
 from pyformex.opengl.decors import Grid
 
 draw_mode_2d = ['point', 'polyline', 'curve', 'nurbs', 'circle']
-autoname['point'] = autoName('coords')
-autoname['polyline'] = autoName('polyline')
-autoname['curve'] = autoName('bezierspline')
-autoname['nurbs'] = autoName('nurbscurve')
-autoname['circle'] = autoName('circle')
+autoname = {}
+autoname['point'] = utils.autoName('coords')
+autoname['polyline'] = utils.autoName('polyline')
+autoname['curve'] = utils.autoName('bezierspline')
+autoname['nurbs'] = utils.autoName('nurbscurve')
+autoname['circle'] = utils.autoName('circle')
 
 
 _preview = False
