@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -65,9 +65,8 @@ def importDxf(convert=False,keep=False):
     if not fn:
         return
 
-    pf.GUI.setBusy()
-    text = dxf.readDXF(fn)
-    pf.GUI.setBusy(False)
+    with busyCursor():
+        text = dxf.readDXF(fn)
     if text:
         if convert or keep:
             f = open(utils.changeExt(fn, '.dxftext'), 'w')
@@ -109,13 +108,12 @@ def importDxfText(text=None):
     elif '\n' not in text:
         text = open(text).read()
 
-    pf.GUI.setBusy()
-    parts = dxf.convertDXF(text)
-    print("Imported %s entities" % len(parts))
-    coll = dxf.collectByType(parts)
-    parts = [ p for p in parts if not isinstance(p, types.FunctionType) ]
-    print("Kept %s entities of type Arc, Line, PolyLine" % len(parts))
-    pf.GUI.setBusy(False)
+    with busyCursor():
+        parts = dxf.convertDXF(text)
+        print("Imported %s entities" % len(parts))
+        coll = dxf.collectByType(parts)
+        parts = [ p for p in parts if not isinstance(p, types.FunctionType) ]
+        print("Kept %s entities of type Arc, Line, PolyLine" % len(parts))
     export({'_dxf_import_':parts,'_dxf_sel_':parts})
     wireframe()
     drawDxf(zoom=True)
