@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -139,7 +139,7 @@ class UniaxialStrain(object):
 
     Parameters:
 
-    - `data`: array-like float (n,): strain values
+    - `data`: :term:`array_like` float (n,): strain values
     - `type`: one of 'stretch', 'log', 'nominal', 'green', 'almansi'.
       Defines the type of strain measure:
 
@@ -201,7 +201,7 @@ class UniaxialStress(object):
 
     Parameters:
 
-    - `data`: array-like float (n,): stress values
+    - `data`: :term:`array_like` float (n,): stress values
     - `type`: one of 'cauchy', 'nominal', 'pk2'.
       Defines the type of stress measure:
 
@@ -212,7 +212,7 @@ class UniaxialStress(object):
       The default is to interprete the data as nominal stresses.
 
     - `strain`: a :class:`UniaxialStrain` instance of matching size (n,),
-      or array-like float (n,) with the strain values. In the latter case
+      or :term:`array_like` float (n,) with the strain values. In the latter case
       also `straintype` should be specified.
     - `straintype`: if `strain` is specified as a :class:`UniaxialStrain`
       instance, this argument is not used. Else it specifies the strain type
