@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -221,7 +221,7 @@ if __name__ == '__draw__':
     chdir('/home/bene/prj/pyformex')
     name = 'FeResult-001'
     meshfile = name+'.flavia.msh'
-    resfile = utils.changeExt(meshfile, 'res')
+    resfile = utils.changeExt(meshfile, '.res')
     M = readMesh(meshfile)
     print(M.coords.shape, M.elems.shape)
     print(M.coords, M.elems)
