@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -33,15 +33,13 @@ from __future__ import absolute_import, division, print_function
 
 import pyformex as pf
 from pyformex import (
-    zip, utils, fileread, filewrite, simple, timer,
+    utils, fileread, filewrite, simple, timer,
     )
 
 from pyformex.geometry import Geometry
 from pyformex.geomfile import GeometryFile
-from pyformex.formex import Formex
 from pyformex.connectivity import Connectivity
-from pyformex.mesh import Mesh, mergeMeshes
-from pyformex.trisurface import TriSurface
+from pyformex.mesh import mergeMeshes
 from pyformex.elements import elementType
 
 from pyformex.gui import menu
@@ -50,42 +48,12 @@ from pyformex.gui.draw import *
 from pyformex.plugins import (
     objects, partition, sectionize, dxf, surface_menu,
     )
+from pyformex.plugins.saveload import savePZF, loadPZF
 
 import os
 
 _name_ = 'geometry_menu'
 
-################### automatic naming of objects ##########################
-
-_autoname = {}
-autoname = _autoname    # alias used by some other plugins that still need to be updated
-
-def autoName(clas):
-    """Return the autoname class instance for objects of type clas.
-
-    clas can be either a class instance, a class object, or a string
-    with a class name. The resulting autoname object will generate
-    strings starting with the class name in lower case.
-
-    >>> F = Formex()
-    >>> print autoName(F).next()
-    formex-000
-    """
-    if isinstance(clas, str):
-        name = clas
-    else:
-        try:
-            name = clas.__name__
-        except:
-            try:
-                name = clas.__class__.__name__
-            except:
-                raise ValueError("Expected an instance, class or string")
-    name = name.lower()
-    if not name in _autoname:
-        _autoname[name] = utils.NameSequence(name)
-    return _autoname[name]
-
 ##################### selection of objects ##########################
 
 # We put these in an init function to allow --doctest to run without GUI
@@ -173,42 +141,41 @@ def readGeometry(filename,filetype=None):
     'inp': Abaqus and CalculiX input format
     'tetgen':
     """
-    pf.GUI.setBusy(True)
-    try:
+    res = {}
+    if filetype is None:
+        filetype,compr = utils.fileTypeComprFromExt(filename)
+
+    print("Reading file %s of type '%s' (%s)" % (filename,filetype,compr))
+
+    if filetype == 'pgf':
+        res = readGeomFile(filename)
+
+    elif filetype == 'pzf':
+        res = loadPZF(filename)
+
+    elif filetype in utils.fileTypes('surface'):
+        surf = TriSurface.read(filename)
+        name = next(utils.autoName(TriSurface))
+        res = {name:surf}
+
+    elif filetype == 'inp':
+        parts = fileread.readInpFile(filename)
         res = {}
-        if filetype is None:
-            filetype,compr = utils.fileTypeComprFromExt(filename)
+        color_by_part = len(parts) > 1
+        j = 0
+        for name in parts:
+            for i, mesh in enumerate(parts[name].meshes()):
+                p = j if color_by_part else i
+                print("Color %s" % p)
+                res["%s-%s" % (name, i)] = mesh.setProp(p)
+            j += 1
 
-        print("Reading file %s of type '%s' (%s)" % (filename,filetype,compr))
+    elif filetype in utils.fileTypes('tetgen'):
+        from pyformex.plugins import tetgen
+        res = tetgen.readTetgen(filename)
 
-        if filetype == 'pgf':
-            res = readGeomFile(filename)
-
-        elif filetype in utils.fileTypes('surface'):
-            surf = TriSurface.read(filename)
-            name = next(autoName(TriSurface))
-            res = {name:surf}
-
-        elif filetype == 'inp':
-            parts = fileread.readInpFile(filename)
-            res = {}
-            color_by_part = len(parts) > 1
-            j = 0
-            for name in parts:
-                for i, mesh in enumerate(part[name].meshes()):
-                    p = j if color_by_part else i
-                    print("Color %s" % p)
-                    res["%s-%s" % (name, i)] = mesh.setProp(p)
-                j += 1
-
-        elif filetype in utils.fileTypes('tetgen'):
-            from pyformex.plugins import tetgen
-            res = tetgen.readTetgen(filename)
-
-        else:
-            error("Can not import from file %s of type %s" % (filename, filetype))
-    finally:
-        pf.GUI.setBusy(False)
+    else:
+        error("Can not import from file %s of type %s" % (filename, filetype))
 
     return res
 
@@ -221,7 +188,7 @@ def importGeometry(select=True,draw=True,ftype=None,compr=False):
     If select and draw are True (default), the selection is drawn.
     """
     if ftype is None:
-        ftype = ['pgf', 'pyf', 'surface', 'off', 'stl', 'gts', 'smesh', 'neu', 'inp', 'all']
+        ftype = ['pgf', 'pyf', 'pzf', 'surface', 'off', 'stl', 'gts', 'smesh', 'neu', 'inp', 'all']
     elif isinstance(ftype, list):
         pass
     else:
@@ -230,8 +197,9 @@ def importGeometry(select=True,draw=True,ftype=None,compr=False):
     fn = askFilename(cur=cur, filter=ftype, compr=compr)
     if fn:
         print("Reading geometry file %s" % fn)
-        res = readGeometry(fn)
-        export(res)
+        with busyCursor():
+            res = readGeometry(fn)
+            export(res)
         print("Items read: %s" % ', '.join([ "'%s'(%s)" % (k, res[k].__class__.__name__) for k in res]))
         if select:
             selection.set(list(res.keys()))
@@ -240,11 +208,32 @@ def importGeometry(select=True,draw=True,ftype=None,compr=False):
             if draw:
                 selection.draw()
                 zoomAll()
+        return res
+    return {}
 
 
 def importPgf():
     importGeometry(ftype='pgf',compr=True)
 
+def importPzf(_canvas=True,_camera=True):
+    res = importGeometry(ftype='pzf',compr=False,draw=False)
+    selection.draw()
+    # TODO:  make camera settings an optional argument of zoomAll ?
+    if '_canvas' in res:
+        if _canvas or ack("The PZF file contains canvas and camera settings.\nDo you want to apply them?"):
+            settings = res['_canvas']
+            pf.GUI.viewports.loadConfig(settings)
+            pf.GUI.viewports.update()
+    elif '_camera' in res:
+        if _camera or ack("The PZF file contains camera settings.\nDo you want to apply them?"):
+            settings = res['_camera']
+            # Force aspect to that of canvas
+            settings['aspect'] = pf.canvas.aspect
+            pf.canvas.camera.loadConfig(settings)
+            pf.canvas.update()
+    else:
+        zoomAll()
+
 def importSurface():
     importGeometry(ftype=['surface', 'pgf', 'vtk', 'all'],compr=True)
 
@@ -273,15 +262,14 @@ def importModel(fn=None):
     if isinstance(fn, str):
         fn = [fn]
 
-    pf.GUI.setBusy(True)
-    for f in fn:
-        d = fileread.readMeshFile(f)
-        modelname = os.path.basename(f).replace('.mesh', '')
-        export({modelname:d})
-        M = fileread.extractMeshes(d)
-        names = [ "%s-%d"%(modelname, i) for i in range(len(M)) ]
-        export2(names, M)
-    pf.GUI.setBusy(False)
+    with busyCursor():
+        for f in fn:
+            d = fileread.readMeshFile(f)
+            modelname = os.path.basename(f).replace('.mesh', '')
+            export({modelname:d})
+            M = fileread.extractMeshes(d)
+            names = [ "%s-%d"%(modelname, i) for i in range(len(M)) ]
+            export2(names, M)
 
 
 def readInp(fn=None):
@@ -293,14 +281,13 @@ def readInp(fn=None):
         if not fn:
             return
 
-        pf.GUI.setBusy(True)
-        for f in fn:
-            fileread.convertInp(f)
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            for f in fn:
+                fileread.convertInp(f)
         return
 
 
-def writeGeometry(obj,filename,filetype=None,sep=' ',shortlines=False,compr=False):
+def writeGeometry(obj,filename,filetype=None,compr=False,**kargs):
     """Write the geometry items in objdict to the specified file.
 
     Returns the number of objects written.
@@ -309,12 +296,25 @@ def writeGeometry(obj,filename,filetype=None,sep=' ',shortlines=False,compr=Fals
     if filetype is None:
         filetype = utils.fileTypeFromExt(filename)
 
+    if filetype in ['pzf']:
+        res = ask("Include the current camera/canvas settings?",["No","Camera only","Full Canvas Layout"])
+        if res.startswith("Camera"):
+            obj['_camera'] = True
+        elif res.startswith("Full"):
+            obj['_canvas'] = True
+
     print("Writing file of type %s" % filetype)
     ext = '.'+filetype
 
     if ext in utils.fileExtensions('pgf',compr=compr):
+        sep = '' if kargs['mode']=='binary' else ' '
+        shortlines = kargs['mode'].startswith('short')
         nobj = writeGeomFile(filename, obj, sep=sep, shortlines=shortlines)
 
+    elif ext in utils.fileExtensions('pzf',compr=compr):
+        savePZF(filename, **obj)
+        nobj = len(obj)
+
     elif ext in utils.fileExtensions('obj',compr=compr) or \
              ext in utils.fileExtensions('off',compr=compr) or \
              ext in utils.fileExtensions('ply',compr=compr) :
@@ -341,32 +341,46 @@ def writeGeometry(obj,filename,filetype=None,sep=' ',shortlines=False,compr=Fals
     return nobj
 
 
-def exportGeometry(types=['pgf', 'all'],mode='multi',sep=' ',shortlines=False,compr=False):
-    """Write geometry to file."""
-    selection.ask(mode=mode)
-    if not selection.check():
+def exportGeometry(types,selmode,compr=False,**kargs):
+    """Write geometry to file.
+
+    mode: 'multi' allows writing more than one object
+    """
+    #if not selection.check():
+    if types=='pzf':
+        from pyformex.gui.menus.Globals import database as db
+    else:
+        db = selection
+    db.ask(mode=selmode)
+    if not db.check():
         return
 
     cur = pf.cfg['workdir']
-    fn = askNewFilename(cur=cur, filter=types,compr=compr)
-    if fn:
+    res = askFile(cur=cur, filter=types, exist=False, compr=compr, **kargs)
+    if res:
+        fn = res['fn']
+        del res['fn']
         print("Writing geometry file %s" % fn)
-        res = writeGeometry(selection.odict(), fn, sep=sep, shortlines=shortlines,compr=compr)
+        res = writeGeometry(db.odict(), fn, compr=compr, **res)
         print("Contents: %s" % res)
 
 
 def exportPgf():
-    exportGeometry('pgf', compr=True)
-def exportPgfShortlines():
-    exportGeometry('pgf', shortlines=True,compr=True)
-def exportPgfBinary():
-    exportGeometry('pgf', sep='',compr=True)
+    kargs = {
+        'compr' : True,
+        'compression' : 4,
+        'mode' : 'binary',
+    }
+    exportGeometry('pgf', 'multi', **kargs)
+
+def exportPzf():
+    exportGeometry('pzf', 'multi')
 def exportOff():
-    exportGeometry(['off'], mode='single')
+    exportGeometry('off', 'single')
 def exportObj():
-    exportGeometry(['obj'], mode='single')
+    exportGeometry('obj', 'single')
 def exportPly():
-    exportGeometry(['ply'], mode='single')
+    exportGeometry('ply', 'single')
 
 
 def convertGeometryFile():
@@ -601,7 +615,7 @@ def createGrid():
         pf.PF[_data_] = res
         name = res['name']
         if name == '__auto__':
-            name = next(autoName(res['object type']))
+            name = next(utils.autoName(res['object type']))
         F = Formex(res['base']).replic2(
             n1=res['nx'], n2=res['ny'],
             t1=res['stepx'], t2=res['stepy'],
@@ -635,7 +649,7 @@ def createRectangle():
         pf.PF[_data_] = res
         name = res['name']
         if name == '__auto__':
-            name = next(autoName(res['object type']))
+            name = next(utils.autoName(res['object type']))
         F = simple.rectangle(
             nx=res['nx'], ny=res['ny'],
             b=res['width'], h=res['height'],
@@ -670,7 +684,7 @@ def createCylinder():
         pf.PF[_data_] = res
         name = res['name']
         if name == '__auto__':
-            name = next(autoName(res['object type']))
+            name = next(utils.autoName(res['object type']))
 
         F = simple.cylinder(
             L=res['height'],
@@ -721,7 +735,7 @@ def createCone():
         pf.PF[_data_] = res
         name = res['name']
         if name == '__auto__':
-            name = next(autoName(res['object type']))
+            name = next(utils.autoName(res['object type']))
 
         F = simple.sector(r=res['radius'], t=res['angle'], nr=res['div_along_radius'],
                           nt=res['div_along_circ'], h=res['height'], diag=res['diagonals'])
@@ -758,7 +772,7 @@ def createSphere():
         pf.PF[_data_] = res
         name = res['name']
         if name == '__auto__':
-            name = next(autoName(res['object type']))
+            name = next(utils.autoName(res['object type']))
         if res['method'] in [ 'icosa', 'octa' ]:
             F = simple.sphere(res['ndiv'],base=res['method'])
             print("Surface has %s vertices and %s faces" % (F.ncoords(), F.nelems()))
@@ -1166,6 +1180,7 @@ def create_menu():
     MenuData = [
         ("&Import ", [
             (utils.fileDescription('pgf'), importPgf),
+            (utils.fileDescription('pzf')+'(Experimental)', importPzf),
             (utils.fileDescription('surface'), importSurface),
             (utils.fileDescription('tetgen'), importTetgen),
             ("Abaqus/Calculix FE model (*.inp)", importInp),
@@ -1182,11 +1197,11 @@ def create_menu():
             ]),
         ("&Export ", [
             (utils.fileDescription('pgf'), exportPgf),
-            ("pyFormex Geometry File (binary)", exportPgfBinary),
-            ("pyFormex Geometry File with short lines", exportPgfShortlines),
-            (utils.fileDescription('obj'), exportObj),
+            (utils.fileDescription('pzf')+'(Experimental)', exportPzf),
             (utils.fileDescription('off'), exportOff),
-            (utils.fileDescription('ply'), exportPly),
+            (utils.fileDescription('obj'), exportObj),
+        # commented out because currently broken
+        #   (utils.fileDescription('ply'), exportPly),
             ]),
         ("&Select ", [
             ('Any', set_selection),
@@ -1197,6 +1212,7 @@ def create_menu():
             ('Curve', set_selection, {'data':'curve'}),
             ('NurbsCurve', set_selection, {'data':'nurbs'}),
             ]),
+        ("&List Selection", selection.printNames),
         ("&Draw Selection", selection.draw),
         ("&Clear Selection", selection.clear),
         ("&Forget Selection", selection.forget),
