@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -307,6 +307,26 @@ def removeAlpha(qim):
     return rgb2qimage(ar[..., :3])
 
 
+def saveGreyImage(a, f, flip=True):
+    """Save a 2D int array as a grey image.
+
+    Parameters:
+
+    - `a`: int array (nx,ny) with values in the range 0..255. These are
+      the grey values of the pixels.
+    - `f`: filename
+    - `flip`: by default, the vertical axis is flipped, so that images are
+      stored starting at the top. If your data already have the vertical axis
+      downwards, use flip=False.
+
+    """
+    a = at.checkArray(a,ndim=2,kind='u',allow='i').astype(np.uint8)
+    c = np.flipud(a)
+    c = np.dstack([c, c, c])
+    im = numpy2qimage(c)
+    im.save(f)
+
+
 ####################################################################
 # Import images using PIL
 
@@ -325,132 +345,9 @@ if utils.checkModule('pil'):
 
 
 
-# Import images using dicom
-_dicom_spacing = None
-_dicom_origin = None
-_dicom_intercept = 0
-_dicom_slope = 1
-
-#
-# The use of python-dicom is deprecated! Use python-gdcm instead
-#
-
-# if utils.checkModule('dicom'):
-
-#     def loadImage_dicom(filename):
-#         """Load a DICOM image into a numpy array.
-
-#         This function uses the python-dicom module to load a DICOM image
-#         into a numpy array. See also :func:`loadImage_gdcm` for an
-#         equivalent using python-gdcm.
-
-#         Parameters:
-
-#         - `file`: the name of a DICOM image file
-
-#         Returns a 2D array with the pixel data of all the image. The first
-#           axis is the `y` value, the last the `x`.
-
-#         As a side effect, this function sets the global variable `_dicom_spacing`
-#         to a (3,) array with the pixel/slice spacing factors, in order (x,y,z).
-#         """
-#         import dicom
-#         global _dicom_spacing
-#         _dicom_spacing = None
-#         try:
-#             dcm = dicom.read_file(filename)
-#             #print("%s %s %s %s" % (filename[-10:],dcm.PixelSpacing[0],dcm.PixelSpacing[1],dcm.SliceThickness))
-#         except:
-#             print("While reading file '%s'" % filename)
-#             raise
-#         pix = dcm.pixel_array
-#         _dicom_spacing = np.array(dcm.PixelSpacing + [dcm.SliceThickness])
-#         return pix
-
-#     readDicom = loadImage_dicom
-
-
-if utils.checkModule('gdcm') or pf.sphinx:
-
-
-    def loadImage_gdcm(filename):
-        """Load a DICOM image into a numpy array.
-
-        This function uses the python-gdcm module to load a DICOM image
-        into a numpy array. See also :func:`loadImage_dicom` for an
-        equivalent using python-dicom.
-
-        Parameters:
-
-        - `file`: the name of a DICOM image file
-
-        Returns a 2D array with the pixel data of the image. The first
-          axis is the `y` value, the last the `x`.
-
-        As a side effect, this function sets the global variables
-        `_dicom_spacing` and `_dicom_origin` to a to a (3,) array with
-        the pixel/slice spacing factors, resp. the origin, in order (x,y,z).
-        It also sets the _dicom_slope, _dicom_intercept global variables.
-        """
-        import gdcm
-
-        def get_gdcm_to_numpy_typemap():
-            """Returns the GDCM Pixel Format to numpy array type mapping."""
-            _gdcm_np = {gdcm.PixelFormat.UINT8  :np.int8,
-                        gdcm.PixelFormat.INT8   :np.uint8,
-                        #gdcm.PixelFormat.UINT12 :np.uint12,
-                        #gdcm.PixelFormat.INT12  :np.int12,
-                        gdcm.PixelFormat.UINT16 :np.uint16,
-                        gdcm.PixelFormat.INT16  :np.int16,
-                        gdcm.PixelFormat.UINT32 :np.uint32,
-                        gdcm.PixelFormat.INT32  :np.int32,
-                        #gdcm.PixelFormat.FLOAT16:np.float16,
-                        gdcm.PixelFormat.FLOAT32:np.float32,
-                        gdcm.PixelFormat.FLOAT64:np.float64 }
-            return _gdcm_np
-
-
-        def get_numpy_array_type(gdcm_pixel_format):
-            """Returns a numpy array typecode given a GDCM Pixel Format."""
-            return get_gdcm_to_numpy_typemap()[gdcm_pixel_format]
-
-
-        def gdcm_to_numpy(image):
-            """Convert a GDCM image to a numpy array.
-
-            """
-            fmt = image.GetPixelFormat()
-
-            if fmt.GetScalarType() not in get_gdcm_to_numpy_typemap():
-                raise ValueError("Unsupported Pixel Format\n%s"%fmt)
-
-            shape = (image.GetDimension(0), image.GetDimension(1))
-            if image.GetNumberOfDimensions() == 3:
-              shape = shape + (image.GetDimension(2),)
-            if fmt.GetSamplesPerPixel() != 1:
-                raise ValueError("Can not read images with multiple samples per pixel.")
-
-            dtype = get_numpy_array_type(fmt.GetScalarType())
-            gdcm_array = image.GetBuffer()
-            data = np.frombuffer(gdcm_array, dtype=dtype).reshape(shape)
-            spacing = np.array(image.GetSpacing())
-            origin = np.array(image.GetOrigin())
-            intercept = image.GetIntercept()
-            slope = image.GetSlope()
-            return data, spacing, origin, slope, intercept
-
-
-        global _dicom_spacing, _dicom_origin, _dicom_slope, _dicom_intercept
-        rdr = gdcm.ImageReader()
-        rdr.SetFileName(filename)
-
-        if not rdr.Read():
-            raise ValueError("Could not read image file '%s'" % filename)
-        pix, _dicom_spacing, _dicom_origin, _dicom_slope, _dicom_intercept = gdcm_to_numpy(rdr.GetImage())
-        return pix
-
-    readDicom = loadImage_gdcm
+if utils.checkModule('pydicom') or pf.sphinx:
 
+    import pydicom
 
     class DicomStack(object):
         """A stack of DICOM images.
@@ -491,13 +388,18 @@ if utils.checkModule('gdcm') or pf.sphinx:
             rejected = []
             for fn in files:
                 obj = DicomStack.Object()
+                dataset = pydicom.dcmread(fn)
                 try:
                     obj.fn = fn
-                    obj.image = loadImage_gdcm(fn)
-                    obj.spacing = _dicom_spacing
-                    obj.origin = _dicom_origin
-                    obj.intercept = _dicom_intercept
-                    obj.slope = _dicom_slope
+                    obj.image = dataset.pixel_array
+                    obj.spacing = dataset.PixelSpacing
+                    try:
+                        obj.spacingz = dataset.SpacingBetweenSlices
+                    except:
+                        obj.spacingz = None
+                    obj.origin = np.array(dataset.ImagePositionPatient)
+                    obj.intercept = dataset.RescaleIntercept
+                    obj.slope = dataset.RescaleSlope
                     ok.append(obj)
                 except:
                     rejected.append(obj)
@@ -509,6 +411,7 @@ if utils.checkModule('gdcm') or pf.sphinx:
             self.ok, self.rejected = ok,rejected
 
 
+
         def nfiles(self):
             """Return the number of accepted files."""
             return len(self.ok)
@@ -524,7 +427,7 @@ if utils.checkModule('gdcm') or pf.sphinx:
             return [ obj.fn for obj in self.rejected ]
 
 
-        def spacing(self):
+        def pspacing(self):
             """Return the pixel spacing and slice thickness.
 
             Return the pixel spacing (x,y) and the slice thickness (z)
@@ -545,7 +448,7 @@ if utils.checkModule('gdcm') or pf.sphinx:
             return np.array([ obj.origin for obj in self.ok ])
 
 
-        def zvalue(self):
+        def zvalues(self):
             """Return the zvalue of all accepted images.
 
             The zvalue is the z value of the origin of the image.
@@ -555,6 +458,28 @@ if utils.checkModule('gdcm') or pf.sphinx:
             return np.array([ obj.origin[2] for obj in self.ok ])
 
 
+        def zspacing(self):
+            """Check for constant slice spacing."""
+            zval = self.zvalues()
+            zdif = zval[1:] - zval[:-1]
+            if np.allclose(zdif,zdif[0]):
+                self.spacingz = zdif[0]
+            else:
+                self.spacingz = None
+            return self.spacingz
+
+
+        def spacing(self):
+            """Return uniform spacing parameters, if uniform."""
+            pspacing = self.pspacing()
+            if np.allclose(pspacing[:,0],pspacing[0,0]) and \
+               np.allclose(pspacing[:,1],pspacing[0,1]):
+                self.spacingp = pspacing[0]
+                if self.zspacing():
+                    return np.concatenate([self.spacingp,[self.spacingz]])
+            return None
+
+
         def image(self,i):
             """Return the image at index i"""
             return self.ok[i].image
@@ -569,53 +494,17 @@ if utils.checkModule('gdcm') or pf.sphinx:
             if raw:
                 data = np.dstack([ obj.image for obj in self.ok ])
             else:
-                data = np.dstack([ obj.image*obj.slope+obj.intercept for obj in self.ok ])
+                 data = np.dstack([ obj.image*obj.slope+obj.intercept for obj in self.ok ])
             return data
 
 
-def dicom2numpy(files):
-    """Read a set of DICOM image files.
+    def dicom2numpy(files):
+        """Easy conversion of a set of dicom images to a numpy array
 
-    Parameters:
-
-    - `files`: a list of file names of dicom images of the same size,
-      or a directory containing such images. In the latter case, all the
-      DICOM images in the directory will be read.
-
-    Returns a tuple of:
-
-    - `pixar`: a 3D array with the pixel data of all the images. The first
-      axis is the `z` value, the last the `x`.
-    - `scale`: a (3,) array with the scaling factors, in order (x,y,z).
-    """
-    if isinstance(files, str):
-        files = utils.listTree(files, listdirs=False, includefiles="*.dcm")
-    # read and stack the images
-    print("Using %s to read DICOM files" % readDicom.__name__)
-
-    pixar = np.dstack([ readDicom(f) for f in files ])
-    scale = _dicom_spacing
-    return pixar, scale
-
-
-def saveGreyImage(a, f, flip=True):
-    """Save a 2D int array as a grey image.
-
-    Parameters:
-
-    - `a`: int array (nx,ny) with values in the range 0..255. These are
-      the grey values of the pixels.
-    - `f`: filename
-    - `flip`: by default, the vertical axis is flipped, so that images are
-      stored starting at the top. If your data already have the vertical axis
-      downwards, use flip=False.
-
-    """
-    a = at.checkArray(a,ndim=2,kind='u',allow='i').astype(np.uint8)
-    c = np.flipud(a)
-    c = np.dstack([c, c, c])
-    im = numpy2qimage(c)
-    im.save(f)
+        Returns the picel array and the spacing.
+        """
+        ds = DicomStack(files)
+        return ds.pixar(), ds.spacing()[0]
 
 
 # End
