@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -425,11 +425,10 @@ def getResultsFromServer(jobname=None,targetdir=None,ext=['.fil']):
     if jobname and ext:
         files = [ '%s%s' % (jobname, e) for e in ext ]
         userdir = "%s/%s" % (userdir, jobname)
-        pf.GUI.setBusy(True)
-        if transferFiles(host, userdir, files, targetdir) == 0:
-            the_jobname = jobname
-            print("Files succesfully transfered")
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            if transferFiles(host, userdir, files, targetdir) == 0:
+                the_jobname = jobname
+                print("Files succesfully transfered")
 
 
 
