@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -74,7 +74,7 @@ class Coords4(np.ndarray):
 
     Parameters:
 
-    `data`: array_like
+    `data`: :term:`array_like`
       If specified, data should evaluate to an array of floats, with the
       length of its last axis not larger than 4. When equal to four, each
       tuple along the last axis represents a ingle point in homogeneous
@@ -84,7 +84,7 @@ class Coords4(np.ndarray):
       position.
       If no data are given, a single point (0.,0.,0.) will be created.
 
-    `w`: array_like
+    `w`: :term:`array_like`
       If specified, the w values are used to denormalize the homogeneous
       data such that the last component becomes w.
 
@@ -276,7 +276,7 @@ class KnotVector(object):
     >>> K[4],K[-1]
     (0.5, 1.0)
     >>> K[4:6]
-    array([ 0.5,  1. ], dtype=float32)
+    array([ 0.5,  1. ])
 
     """
 
@@ -1498,7 +1498,8 @@ def globalInterpolationCurve(Q,degree=3,strategy=0.5):
     d = PolyLine(Q).lengths()
     if (d==0.0).any():
         utils.warn("warn_nurbs_gic")
-        Q = np.concatenate([Q[d!=0.0], Q[-1:]], axis=0)
+        w = np.where(d!=0)[0]
+        Q = np.concatenate([Q[w], Q[-1:]], axis=0)
         d = PolyLine(Q).lengths()
         if (d==0.0).any():
             raise ValueError("Double points in the data set are not allowed")
