@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -28,7 +28,6 @@
 from __future__ import absolute_import, division, print_function
 
 from pyformex.gui import menu
-from pyformex.plugins import geometry_menu as gm
 
 from pyformex.plugins.draw2d import *
 from pyformex.plugins.objects import *
@@ -107,7 +106,7 @@ def createNurbsCurve(N,name=None):
 
     If no name is returned, the curve is not stored.
     """
-    an = gm.autoname['nurbscurve']
+    an = utils.autoname('nurbscurve')
     drawNurbs(N)
     if name is None:
         name = an.peek()
