@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -33,7 +33,6 @@ from pyformex import zip
 from pyformex import geomfile
 from pyformex.coords import bbox
 from pyformex.script import named
-from pyformex.gui.draw import drawBbox, _I
 from pyformex.odict import OrderedDict
 
 from copy import deepcopy
@@ -229,6 +228,10 @@ class Objects(object):
         forget([ n for n in self.listAll() if not n in self.names ])
 
 
+    def printNames(self):
+        print(self.names)
+
+
     def printval(self):
         """Print the selection."""
         objects = self.check()
@@ -290,6 +293,7 @@ def draw_free_edges(n):
 
 def draw_bbox(n):
     """Draw the bbox of an object."""
+    from pyformex.gui.draw import drawBbox
     return drawBbox(named(n))
 
 
@@ -332,14 +336,14 @@ class DrawableObjects(Objects):
 
 
     def draw(self,**kargs):
+        from pyformex.gui.draw import busyCursor
         clear()
         pf.debug("Drawing SELECTION: %s" % self.names, pf.DEBUG.DRAW)
-        pf.GUI.setBusy(True)
-        self._actors = draw(self.names,clear=False,shrink=self.shrink,wait=False,**kargs)
-        for f in self.annotations:
-            pf.debug("Drawing ANNOTATION: %s" % f, pf.DEBUG.DRAW)
-            self.drawAnnotation(f)
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            self._actors = draw(self.names,clear=False,shrink=self.shrink,wait=False,**kargs)
+            for f in self.annotations:
+                pf.debug("Drawing ANNOTATION: %s" % f, pf.DEBUG.DRAW)
+                self.drawAnnotation(f)
 
 
     def drawChanges(self):
