@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -605,10 +605,10 @@ def importCalculix(fn=None):
         chdir(fn)
         if fn.endswith('.inp'):
             meshfile = fn
-            resfile = utils.changeExt(fn, 'dat')
+            resfile = utils.changeExt(fn, '.dat')
         else:
             resfile = fn
-            meshfile = utils.changeExt(fn, 'inp')
+            meshfile = utils.changeExt(fn, '.inp')
 
         parts = readInpFile(meshfile)
         print(type(parts))
@@ -646,10 +646,10 @@ def importFlavia(fn=None):
         chdir(fn)
         if fn.endswith('.msh'):
             meshfile = fn
-            resfile = utils.changeExt(fn, 'res')
+            resfile = utils.changeExt(fn, '.res')
         else:
             resfile = fn
-            meshfile = utils.changeExt(fn, 'msh')
+            meshfile = utils.changeExt(fn, '.msh')
 
         db = readFlavia(meshfile, resfile)
         if not isinstance(db, FeResult):
@@ -686,9 +686,8 @@ I strongly recommend you to cancel the operation now.
             return
 
         # import the results DB
-        pf.GUI.setBusy(True)
-        runScript(fn)
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            runScript(fn)
 
         ### check whether the import succeeded
         name = FeResult._name_
