@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -31,13 +31,13 @@ from __future__ import absolute_import, division, print_function
 import pyformex as pf
 from pyformex import zip, simple, timer
 from pyformex.gui import widgets, menu
-from pyformex.plugins import plot2d, formex_menu, fe_abq
+from pyformex.plugins import plot2d, fe_abq
 
 from pyformex.odict import OrderedDict
 from pyformex.arraytools import niceLogSize
 from pyformex.gui.colorscale import ColorScale
 from pyformex.gui.draw import *
-from pyformex.trisurface import *
+from pyformex.trisurface import TriSurface
 from pyformex.plugins.objects import DrawableObjects
 from pyformex.plugins.tools import Plane
 from pyformex.opengl.decors import ColorLegend
@@ -123,12 +123,11 @@ def readSelection(select=True,draw=True,multi=True):
             fn = [ fn ]
         chdir(fn[0])
         names = [utils.projectName(_fn) for _fn in fn]
-        pf.GUI.setBusy()
-        surfaces = [ read_Surface(f, False) for f in fn ]
-        if len(surfaces) > 1:
-            for i, S in enumerate(surfaces):
-                S.setProp(i)
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            surfaces = [ read_Surface(f, False) for f in fn ]
+            if len(surfaces) > 1:
+                for i, S in enumerate(surfaces):
+                    S.setProp(i)
         export2(names, surfaces)
         if select:
             print("Set selection to %s" % str(names))
@@ -183,6 +182,7 @@ def toFormex(suffix=''):
     surface names plus the suffix, else, the surface names will be used
     (and the surfaces will thus be cleared from memory).
     """
+    from pyformex.plugins import formex_menu
     if not selection.check():
         selection.ask()
 
@@ -210,6 +210,7 @@ def fromFormex(suffix=''):
     Formex names plus the suffix, else, the Formex names will be used
     (and the Formices will thus be cleared from memory).
     """
+    from pyformex.plugins import formex_menu
     if not formex_menu.selection.check():
         formex_menu.selection.ask()
 
@@ -349,9 +350,8 @@ def export_surface(types=['surface', 'gts', 'stl', 'off', 'neu', 'smesh', 'vtp',
             if ftype is None:
                 ftype = utils.fileTypeFromExt(fn)
             print("Exporting surface model to %s (%s)" % (fn, ftype.upper()))
-            pf.GUI.setBusy()
-            F.write(fn, ftype)
-            pf.GUI.setBusy(False)
+            with busyCursor():
+                F.write(fn, ftype)
 
 # TODO: this should be merged with export_surface
 
@@ -377,9 +377,8 @@ def export_stl():
             color = None
         print("Stored color is %s" % color)
         print("Exporting surface model to %s (%s)" % (fn, ftype.upper()))
-        pf.GUI.setBusy()
-        F.write(fn, ftype, color)
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            F.write(fn, ftype, color)
 
 
 def export_webgl():
@@ -388,9 +387,8 @@ def export_webgl():
         fn = askNewFilename(pf.cfg['workdir'], 'stl')
         if fn:
             print("Exporting surface model to %s" % fn)
-            pf.GUI.setBusy()
-            F.webgl(fn)
-            pf.GUI.setBusy(False)
+            with busyCursor():
+                F.webgl(fn)
 
 
 def createPointsOnSurface():
@@ -403,14 +401,14 @@ def createPointsOnSurface():
     if S:
         P = tools_menu.createPointsOnSurface(S)
         draw(P,color=red)
-        pname = gm.autoName('coords').peek()
+        pname = utils.autoName('coords').peek()
         res = askItems([
             _I('name', pname, text='Name for storing the object'),
             ])
         if res:
             name = res['name']
             if name == pname:
-                gm.autoName('coords').next()
+                utils.autoName('coords').next()
             export({name:P})
         return P
 
@@ -606,7 +604,11 @@ def _show_dist():
 def _close_stats_dia():
     global _stat_dia
     if _stat_dia:
-        _stat_dia.close()
+        try:
+            _stat_dia.close()
+            # this may fail if fialog closed by window manager
+        except:
+            pass
         _stat_dia = None
 
 
@@ -616,21 +618,24 @@ def showStatisticsDialog():
         _close_stats_dia()
 
     dispmodes = ['On Domain', 'Histogram', 'Cumulative Histogram']
-    keys = SelectableStatsValues.keys()
+    keys = list(SelectableStatsValues.keys())
     _stat_dia = widgets.InputDialog(
         caption='Surface Statistics', items=[
-            _I('Value', itemtype='vradio', choices=keys),
-            _I('neighbours', text='Curvature Neighbourhood', value=1),
-            _I('curval', text='Curvature Value', itemtype='vradio', choices=CurvatureValues),
-            _I('clip', itemtype='hradio', choices=['None', 'Top', 'Bottom', 'Both']),
-            _I('Clip Mode', itemtype='hradio', choices=['Range', 'Percentile']),
-            _G('Clip Values', checkable=True, items=[
-                _I('Top', 1.0),
-                _I('Bottom', 0.0),
-                ],
-              ),
-            _I('Cumulative Distribution', False),
-            ],
+            _H('',[
+                _I('Value', itemtype='vradio', choices=keys),
+                _I('neighbours', text='Curvature Neighbourhood', value=1),
+                _I('curval', text='Curvature Value', itemtype='vradio', choices=CurvatureValues),
+            ]),
+            _H('',[
+                _I('clip', itemtype='hradio', choices=['None', 'Top', 'Bottom', 'Both']),
+                _I('Clip Mode', itemtype='hradio', choices=['Range', 'Percentile']),
+                _G('Clip Values', checkable=True, items=[
+                    _I('Top', 1.0),
+                    _I('Bottom', 0.0),
+                ]),
+                _I('Cumulative Distribution', False),
+            ]),
+        ],
         actions=[
             ('Close', _close_stats_dia),
             ('Distribution', _show_dist),
@@ -1068,11 +1073,10 @@ def slicer():
     if res:
         axis = res['Direction']
         nslices = res['# slices']
-        pf.GUI.setBusy(True)
         t = timer.Timer()
-        slices = S.slice(dir=axis, nplanes=nslices)
+        with busyCursor():
+            slices = S.slice(dir=axis, nplanes=nslices)
         print("Sliced in %s seconds" % t.seconds())
-        pf.GUI.setBusy(False)
         print([ s.nelems() for s in slices ])
         draw([ s for s in slices if s.nelems() > 0], color='red', bbox='last', view=None)
         export({'%s/slices' % selection[0]:slices})
@@ -1093,9 +1097,8 @@ def spliner():
         axis = res['Direction']
         nslices = res['# slices']
         remove_cruft = res['remove_invalid']
-        pf.GUI.setBusy(True)
-        slices = S.slice(dir=axis, nplanes=nslices)
-        pf.GUI.setBusy(False)
+        with busyCursor():
+            slices = S.slice(dir=axis, nplanes=nslices)
         print([ s.nelems() for s in slices ])
         split = [ s.splitProp() for s in slices if s.nelems() > 0 ]
         split = olist.flatten(split)
