@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -567,7 +567,7 @@ def tetMesh(surfacefile,quality=False,volume=None,outputdir=None):
     if not os.path.exists(tgt):
         os.symlink(surfacefile, tgt)
     runTetgen(tgt, options)
-    fn = utils.changeExt(tgt, '1.ele')
+    fn = utils.changeExt(tgt, '.1.ele')
     res = readTetgen(fn)
     return res
 
