@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -35,7 +35,6 @@ from pyformex.plugins import objects
 
 from pyformex.formex import *
 from pyformex.gui.draw import *
-from pyformex.plugins.geometry_menu import autoName
 from pyformex.plugins.tools import *
 from pyformex.trisurface import TriSurface
 from pyformex.geomtools import rotationAngle
@@ -96,7 +95,7 @@ def unix2dos():
 ##################### planes ##########################
 
 planes = objects.DrawableObjects(clas=Plane)
-pname = autoName(Plane)
+pname = utils.autoName(Plane)
 
 def editPlane(plane, name):
     res = askItems([('Point', list(plane.point())),
