@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -848,7 +848,7 @@ def intersectionWithLines(self,q,q2,method='line',atol=1e-5,closest=False,reorde
 
     if closest:
         d = at.length((pts-q[lineids]))
-        ind = ma.masked_values(inverseIndex(lineids.reshape(-1,1)),-1)
+        ind = ma.masked_values(at.inverseIndex(lineids.reshape(-1,1)),-1)
         d = ma.array(d[ind],mask=ind<0).argmin(axis=1)
         ind = ind[arange(ind.shape[0]),d].compressed()
         pts = pts[ind]
@@ -859,7 +859,7 @@ def intersectionWithLines(self,q,q2,method='line',atol=1e-5,closest=False,reorde
 
     # This option has been tested only with closest=True
     if reorder:
-        hitsxline = inverseIndex(lineids.reshape(-1,1))
+        hitsxline = at.inverseIndex(lineids.reshape(-1,1))
         j = j[hitsxline[where(hitsxline>-1)]]
         lineids = lineids[hitsxline[where(hitsxline>-1)]]
         cellids = cellids[hitsxline[where(hitsxline>-1)]]
@@ -1143,8 +1143,8 @@ def vtkCut(self, implicitdata, method=None):
             or a box (cuboid) defined by 4 points, a formex or a mesh. See _vtkBox.
         -  method ==  `boxplanes`  : Coords, Mesh or Formex. Coords array of shape (2,3) specifying
             minimal  and coordinates of the box. Formex or Mesh specifying one hexahedron. See _vtkPlanesBox.
-        -  method ==  `planes`  : points array-like of shape (npoints,3) and
-                normal vectors array-like of shape (npoints,3) defining the cutting planes.
+        -  method ==  `planes`  : points :term:`array_like` of shape (npoints,3) and
+                normal vectors :term:`array_like` of shape (npoints,3) defining the cutting planes.
         -  method ==  `surface`  : a closed convex manifold trisurface.
 
     - `method`: str or None. If string allowed values are `plane`, `sphere`,
@@ -1198,8 +1198,8 @@ def vtkClip(self, implicitdata, method=None, insideout=False):
             or a box (cuboid) defined by 4 points, a formex or a mesh. See _vtkBox.
         -  method ==  `boxplanes`  : Coords, Mesh or Formex. Coords array of shape (2,3) specifying
             minimal  and coordinates of the box. Formex or Mesh specifying one hexahedron. See _vtkPlanesBox.
-        -  method ==  `planes`  : points array-like of shape (npoints,3) and
-                normal vectors array-like of shape (npoints,3) defining the cutting planes.
+        -  method ==  `planes`  : points :term:`array_like` of shape (npoints,3) and
+                normal vectors :term:`array_like` of shape (npoints,3) defining the cutting planes.
         -  method ==  `surface`  : a closed convex manifold trisurface.
 
     - `method`: str or None. If string allowed values are `plane`,`planes`, `sphere`,
