@@ -1,6 +1,6 @@
-# $Id$
+#
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -697,7 +697,7 @@ def createMultiWebGL():
     combined = askNewFilename(filter=['html','js'],caption="Enter name of the combined model")
     if not combined:
         return
-    fout = open(utils.changeExt(combined,'js'),'w')
+    fout = open(utils.changeExt(combined,'.js'),'w')
 
     print("""// Script generated by %s
 var the_renderer;
@@ -714,7 +714,7 @@ show%s()
         body += "<button onclick='show%s()'>Show %s</button><br />" % (name,name)
         print('',file=fout)
         print("show%s = function() {" % name,file=fout)
-        fn = utils.changeExt(model,'js')
+        fn = utils.changeExt(model,'.js')
         f = open(fn,'r')
         s = f.readlines()
         f.close()
@@ -741,11 +741,11 @@ var r = the_renderer;
     body += "</div>"
 
     fn = createWebglHtml(
-        utils.changeExt(combined,'html'),
+        utils.changeExt(combined,'.html'),
         scripts=[
             pf.cfg['webgl/script'],
             pf.cfg['webgl/guiscript'],
-            utils.changeExt(combined,'js')
+            utils.changeExt(combined,'.js')
             ],
         body=body
         )
