@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -31,7 +31,6 @@ from __future__ import absolute_import, division, print_function
 import pyformex as pf
 from pyformex import pickle
 from pyformex import utils
-from pyformex import zip
 
 from pyformex.track import TrackedDict
 
@@ -85,20 +84,20 @@ def find_class(module, name):
 
 
 if pf.PY3:
-
+    default_protocol = pickle.DEFAULT_PROTOCOL
     class Unpickler(pickle.Unpickler):
         """Customized Unpickler class"""
 
         def __init__(self,f,try_resolve=True):
             """Initialize the Unpickler"""
-            pickle.Unpickler.__init__(self,f)
+            pickle.Unpickler.__init__(self,f,encoding='latin1')
             if try_resolve:
                 self.find_class = find_class
             else:
                 pf.debug("NOT TRYING TO RESOLVE RELOCATIONS: YOU MAY GET INTO TROUBLE", pf.DEBUG.PROJECT)
 
-
-else:
+if pf.PY2 and not pf.sphinx:
+    default_protocol = pickle.HIGHEST_PROTOCOL
     def Unpickler(f,try_resolve=True):
         """Create an Unpickler object"""
         unpickler = pickle.Unpickler(f)
@@ -152,8 +151,8 @@ class Project(TrackedDict):
 
        For a problemless long time storage of Geometry type objects you may
        consider to write them to a pyFormex Geometry file (.pgf) instead, since
-       this uses a stable ascii based format. It can (currently) not deal
-       with other data types however.
+       this uses a stable ascii based format. It can however (currently) only
+       store obects of class Geometry or one of its subclasses.
 
     Parameters:
 
@@ -235,7 +234,7 @@ class Project(TrackedDict):
     latest_format = 3
 
 
-    def __init__(self,filename=None,access='wr',convert=True,signature=_signature_,compression=5,binary=True,data={},**kargs):
+    def __init__(self,filename=None,access='wr',convert=True,signature=_signature_,compression=5,binary=True,data={},protocol=default_protocol,**kargs):
         """Create a new project."""
         if 'create' in kargs:
             utils.warn("warn_project_create")
@@ -247,6 +246,10 @@ class Project(TrackedDict):
         self.signature = str(signature)
         self.gzip = compression if compression in range(1, 10) else 0
         self.mode = 'b' if binary or compression > 0 else ''
+        if protocol is None:
+            protocol = default_protocol
+        self.protocol = min(protocol,pickle.HIGHEST_PROTOCOL) \
+            if self.mode == 'b' else 0
 
         TrackedDict.__init__(self)
         if filename and os.path.exists(filename) and 'r' in self.access:
@@ -257,7 +260,7 @@ class Project(TrackedDict):
             self.update(data)
         if filename and access=='w':
             # destroy existing contents
-            self.save()
+            open(filename,'w').close()
         pf.debug("INITIAL hits = %s" % self.hits, pf.DEBUG.PROJECT)
 
 
@@ -295,8 +298,8 @@ class Project(TrackedDict):
             self.filename = utils.tempName(prefix='pyformex_', suffix='.pyf')
         else:
             if not quiet:
-                print("Saving project %s with mode %s and compression %s" % (self.filename, self.mode, self.gzip))
-            #print("  Contents: %s" % self.keys())
+                print("Saving project %s with protocol %s, mode %s and compression %s" % (self.filename, self.protocol, self.mode, self.gzip))
+
         f = open(self.filename, 'w'+self.mode)
         # write header
         header = "%s\n" % self.header_data()
@@ -304,17 +307,12 @@ class Project(TrackedDict):
             header = header.encode('utf-8')
         f.write(header)
         f.flush()
-        if self.mode == 'b':
-            # When using binary, can as well use highest protocol
-            protocol = pickle.HIGHEST_PROTOCOL
-        else:
-            protocol = 0
         if self.gzip:
             pyf = gzip.GzipFile(mode='w'+self.mode, compresslevel=self.gzip, fileobj=f)
-            pickle.dump(self, pyf, protocol)
+            pickle.dump(self, pyf, self.protocol)
             pyf.close()
         else:
-            pickle.dump(self, f, protocol)
+            pickle.dump(self, f, self.protocol)
         f.close()
         self.hits = 0
 
