@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -48,7 +48,6 @@ import shutil
 ################ pyFormex modules
 
 import pyformex as pf
-from pyformex import zip
 from pyformex import formex
 from pyformex import geomfile
 from pyformex import utils
@@ -352,8 +351,8 @@ def playScript(scr,name=None,filename=None,argv=[],pye=False):
     exitall = False
 
     if pf.DEBUG.MEM:
-        memu = memUsed()
-        vmsiz = vmSize()
+        memu = utils.memUsed()
+        vmsiz = utils.vmSize()
         pf.debug("MemUsed = %s; vmSize = %s" % (memu, vmsiz), pf.DEBUG.MEM)
 
     if filename is None:
@@ -385,8 +384,8 @@ def playScript(scr,name=None,filename=None,argv=[],pye=False):
         if pf.GUI:
             pf.GUI.stopRun()
 
-    pf.debug("MemUsed = %s; vmSize = %s" % (memUsed(), vmSize()), pf.DEBUG.MEM)
-    pf.debug("Diff MemUsed = %s; diff vmSize = %s" % (memUsed()-memu, vmSize()-vmsiz), pf.DEBUG.MEM)
+    pf.debug("MemUsed = %s; vmSize = %s" % (utils.memUsed(), utils.vmSize()), pf.DEBUG.MEM)
+    pf.debug("Diff MemUsed = %s; diff vmSize = %s" % (utils.memUsed()-memu, utils.vmSize()-vmsiz), pf.DEBUG.MEM)
 
     if exitall:
         pf.debug("Calling quit() from playscript", pf.DEBUG.SCRIPT)
@@ -624,7 +623,7 @@ def runApp(appname,argv=[],refresh=False,lock=True,check=True):
         pf.GUI.board.write(msg, color='green')
     else:
         print(msg)
-    pf.debug("Memory: %s" % vmSize(), pf.DEBUG.MEM)
+    pf.debug("Memory: %s" % utils.vmSize(), pf.DEBUG.MEM)
     return res
 
 
@@ -731,29 +730,12 @@ def setPrefs(res,save=False):
 ########################## print information ################################
 
 
-def printall():
-    """Print all Formices in globals()"""
-    print("Formices currently in globals():\n%s" % listAll(clas=formex.Formex))
-
-
-def printglobals():
-    print(Globals())
-
-
-def printglobalnames():
-    print(sorted(Globals().keys()))
-
-
-def printconfig():
+def printConfig():
     print("Reference Configuration: " + str(pf.refcfg))
     print("Preference Configuration: " + str(pf.prefcfg))
     print("User Configuration: " + str(pf.cfg))
 
 
-def printdetected():
-    print(utils.reportSoftware())
-
-
 def printLoadedApps():
     from pyformex import apps, sys
     loaded = apps.listLoaded()
@@ -761,23 +743,6 @@ def printLoadedApps():
     print(', '.join([ "%s (%s)" % (k, r) for k, r in zip(loaded, refcnt)]))
 
 
-def printEnv():
-    """Print the environment."""
-    print(utils.formatDict(os.environ.data))
-
-
-# THis is not a good way of computing memory usage
-def vmSize():
-    import os
-    return int(os.popen('ps h o vsize %s'%os.getpid()).read().strip())
-
-def memUsed():
-    return utils.memory_report()['MemUsed']
-
-def printVMem(msg='MEMORY'):
-    print('%s: VmSize=%skB'%(msg, vmSize()))
-
-
 ### Utilities
 
 def isWritable(path):
@@ -812,7 +777,7 @@ def chdir(path,create=False):
     for persistence between pyFormex invocations.
 
     """
-    path = utils.tildeExpand(path)
+    path = os.path.expanduser(path)
     if os.path.exists(path):
         if not os.path.isdir(path):
             path = os.path.dirname(os.path.abspath(path))
@@ -872,7 +837,7 @@ def mkdir(path, clear=False, new=False):
     - `new` is True, and the path exists.
 
     """
-    path = utils.tildeExpand(path)
+    path = os.path.expanduser(path)
     if new and os.path.exists(path):
         raise OsError("Path already exists: %s" % path)
     if clear:
@@ -912,43 +877,6 @@ def startGui(args=[]):
             guimain.runGUI()
 
 
-#
-# OBSOLETE : we do not have a revision number anymore
-#
-## def checkRevision(rev,comp='>='):
-##     """Check the pyFormex revision number.
-
-##     - rev: a positive integer.
-##     - comp: a string specifying a comparison operator.
-
-##     By default, this function returns True if the pyFormex revision
-##     number is equal or larger than the specified number.
-
-##     The comp argument may specify another comparison operator.
-
-##     If pyFormex is unable to find its revision number (this is the
-##     case on very old versions) the test returns False.
-##     """
-##     try:
-##         cur = int(utils.splitStartDigits(pf.__revision__)[0])
-##         return eval("%s %s %s" % (cur, comp, rev))
-##     except:
-##         return False
-
-
-## def requireRevision(rev,comp='>='):
-##     """Require a specified pyFormex revision number.
-
-##     The arguments are like checkRevision. However, this function will
-##     raise an error if the requirement fails.
-##     """
-##     if not checkRevision(rev, comp):
-##         raise RuntimeError("Your current pyFormex revision (%s) does not pass the test %s %s" % (pf.__revision__, comp, rev))
-
-
-## print("REVISION: %s" % pf.__revision__)
-
-
 ################### read and write files #################################
 
 def writeGeomFile(filename,objects,sep=' ',mode='w',shortlines=False,**kargs):
@@ -973,6 +901,7 @@ def writeGeomFile(filename,objects,sep=' ',mode='w',shortlines=False,**kargs):
 
     Returns the number of objects written to the file.
     """
+    pf.debug("WriteGeomFile %s; sep='%s'; shortlines=%s; kargs=%s" % (filename,sep,shortlines,kargs),pf.DEBUG.PGF)
     print("Writing PGF file '%s'" % os.path.abspath(filename))
     f = geomfile.GeometryFile(filename, mode, sep=sep,**kargs)
     # TODO: shis option could goto into GeometryFile
