@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -50,9 +50,9 @@ from pyformex.odict import OrderedDict
 # If module name is an empty string, it is supposed to be equal to our alias
 known_modules = {
     'calpy': (),
-    'dicom': (),
+#    'dicom': (),    # we no longer support it
     'docutils': (),
-    'gdcm': ('', '', 'GDCM_VERSION'),
+#    'gdcm': ('', '', 'GDCM_VERSION'),  # not in buster, not working in Python3
     'gl2ps': ('', '', 'GL2PS_VERSION'),
     'gnuplot': ('Gnuplot',),
 #    'ipython': ('IPython',),
@@ -60,6 +60,7 @@ known_modules = {
     'matplotlib': (),
     'numpy': (),
     'pil': ('PIL', 'PIL', 'VERSION'),
+    'pydicom': (),
     'pyopengl': ('OpenGL',),
     'pyqt4': ('PyQt4.QtCore', 'PyQt4', 'QtCore', 'QT_VERSION_STR'),
     'pyqt4gl': ('PyQt4.QtOpenGL', 'PyQt4', 'QtCore', 'QT_VERSION_STR'),
