@@ -1,6 +1,6 @@
 #
 ##
-##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
+##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
@@ -111,7 +111,7 @@ class Varray(object):
           the rows obtained by prepending each row with the row length.
           The caller should make sure these 1D data are consistent.
 
-    ind: 1-dim int array-like, optional
+    ind: 1-dim int :term:`array_like`, optional
         This is only used when `data` is a pure concatenation of all rows.
         It holds the position in `data` of the first element of each row.
         Its length is equal to the number of rows (`nrows`) or `nrows+1`.
@@ -451,7 +451,7 @@ class Varray(object):
         self._row += 1
         return row
 
-    if not pf.PY3:
+    if pf.PY2:
         # In Python2 the next method is used instead of __next__
         next = __next__
 
@@ -551,7 +551,7 @@ class Varray(object):
 
         Parameters
         ----------
-        ind: int or int array-like
+        ind: int or int :term:
             Index in the flat data of the element(s) to remove.
 
         Returns
